/*	helpme.c

	See http://aggregate.org/HELPME/ for details.

	This program was written by Professor Hank Dietz,
	hankd@engr.uky.edu, http://aggregate.org/hankd/

	As of September 10, 2002,
	it is hereby placed in the public domain.

	By using this code, you agree to hold harmless both
	Prof. Dietz and the University of Kentucky; you accept
	full responsibility for any badness that may occur.

	Change log:

	20020910: Original version.

	20020920: The original version used the hardware
	timestamp counter to do highly-precise timing...  but
	that level of precision really isn't needed.  Using
	gettimeofday() is about 1000X less accurate, but is
	still good enough.  This change also allowed all the
	"unsigned long long" stuff to become "unsigned int".
	The Morse code support also was made more compliant with
	standards and command line options were added: -h to
	specify the Morse tone frequency in Hz, -w to specify
	the Morse speed in words per minute, and -f to set
	"Farnsworth" timing (sending dots and dashes at a higher
	rate with spaces at a lower rate).  The defaults are
	-h1500 -w5 -f5.  The -w5 default is MUCH slower than in
	20020910; a more proficient Morse user would want -w13
	or higher.  Specifying -w5 -f13 gives a novice the sound
	of 13 WPM, but with spaces enlarged for an overall speed
	of 5 WPM.  Three other options also were added:  -v adds
	the version as though "20020920 " were typed, -n adds
	the hostname up to the first ".", and -- means read the
	standard input even if there was stuff to render on the
	command line.  There also were a number of coding
	changes made to reduce size of the program.
*/


/*	Leave defined to use ioctl() sound instead of raw I/O ports */
#define	USEIOCTL

/*	Leave defined to force raw toggles of speaker bit....
	If you tried USEIOCTL and heard nothing,
	and you tried undef USEIOCTL and heard clear NATO text
	with garbled tones for everything else,
	then using this option should fix things.
	NEVER USE THIS if anything else works; it's very innefficient.
*/
#define	FORCETOGGLE
#undef	FORCETOGGLE


#define	VERSION		"20020920 "

#include <signal.h>	/* make us shutup if killed... */

#ifdef	FORCETOGGLE
#undef	USEIOCTL	/* can't use ioctl() */
#endif

#ifdef	USEIOCTL
#include <sys/ioctl.h>
#include <linux/kd.h>
#include <fcntl.h>
#endif

#define	TIMERPERSEC	1193180U		/* speaker timer ticks per second */

#define	TICKSPERSEC	1000000U		/* resolution of gettimeofday() */

#define	SAMPLERATE	8000U			/* voice recording samples per second */
#define	SAMPLETICKS	(TICKSPERSEC/SAMPLERATE)
#define	SYSTICKS	(TICKSPERSEC/50U)	/* minimum reliable time to usleep(1) */
#define	KERNTICKS	(TICKSPERSEC/8U)	/* 1/2 intercharacter (kerning) time */
#define	WORDTICKS	(TICKSPERSEC)		/* wordbreak time (1 second) */

#define	MORSEWORDSP	7	/* Morse wordspace (in morsedots) */
#define	MORSEDASH	3	/* Morse dash length (in morsedots) */
#define	MORSECHARSP	3	/* Morse charspace (in morsedots) */
#define	MORSESEP	1	/* Morse symbol separator (in morsedots) */
#define	MORSEPARIS	50	/* Morse dot length of "PARIS "...
				   should be 50, but new standard "CODEX "
				   would make it 60, and system noise is
				   always slowing-down helpme, so you might
				   want to bump this to 54 or so....
				*/
#define	MORSEWPM	5	/* Morse Words Per Minute */
#define	MORSEDOT(wpm) \
	((60000 / MORSEPARIS) / (wpm))
#define	MORSEFREQ	1500	/* Morse signal frequency in Hz */

#define	MAXINPUT	(8 * 1024)	/* Maximum number of tokens in program */

#include <sys/time.h>		/* for struct timeval */

static	unsigned int
	msecdelay = 2000;		/* default long delay of 2000ms (2 seconds) */
static	int	usenato = 1;			/* use NATO phonetic alphabet, else Morse code */
static	char	inputbuf[MAXINPUT];		/* input program memory (tokenized) */
static	int	inputlen = 0;			/* input program token length */
static	int	pc = 0;				/* "program counter" for interpreting input */
static	int	sdot = MORSEDOT(MORSEWPM);	/* Morse dot length for spaces */
static	int	dot = 0;			/* Morse dot length */
static	int	freq = MORSEFREQ;		/* Morse frequency */

#ifdef	USEIOCTL
static	int	consolefd;		/* /dev/console file descriptor for ioctl() */
#endif


/*	NATO rendering data...
*/
#define	zeroPOS		0
#define	onePOS		612
#define	twoPOS		954
#define	threePOS	1174
#define	fourPOS		1639
#define	fivePOS		2133
#define	sixPOS		2499
#define	sevenPOS	3732
#define	eightPOS	4466
#define	ninePOS		4928
#define	alphaPOS	5618
#define	bravoPOS	6089
#define	charliePOS	6859
#define	deltaPOS	7660
#define	echoPOS		8203
#define	foxtrotPOS	8741
#define	golfPOS		9703
#define	hotelPOS	10119
#define	indiaPOS	10841
#define	julietPOS	11440
#define	kiloPOS		11973
#define	limaPOS		12759
#define	mikePOS		13487
#define	novemberPOS	13944
#define	oscarPOS	14674
#define	papaPOS		15385
#define	quebecPOS	15906
#define	romeoPOS	16331
#define	sierraPOS	17051
#define	tangoPOS	18004
#define	uniformPOS	18704
#define	victorPOS	19392
#define	whiskeyPOS	19916
#define	xrayPOS		20719
#define	yankeePOS	21585
#define	zuluPOS		22267
#define	NULLPOS		22957
#define	NATOWORD	(NULLPOS+1)
#define	NATOALERT	(NULLPOS+2)

static unsigned char natodata[] = {
	0x01,0x57,0x01,0x48,0x01,0x01,0x01,0x17,0x01,0x17,
	0x01,0x19,0x01,0x2c,0x03,0x15,0x01,0x01,0x03,0x01,
	0x03,0x02,0x01,0x03,0x01,0x05,0x01,0x01,0x03,0x14,
	0x06,0x11,0x06,0x01,0x01,0x0c,0x01,0x01,0x04,0x01,
	0x01,0x0f,0x08,0x01,0x01,0x0e,0x08,0x0a,0x07,0x01,
	0x01,0x0e,0x01,0x01,0x07,0x01,0x01,0x0e,0x09,0x09,
	0x04,0x01,0x02,0x0e,0x01,0x01,0x07,0x01,0x01,0x0d,
	0x01,0x02,0x08,0x08,0x04,0x01,0x01,0x02,0x01,0x0b,
	0x09,0x01,0x01,0x0e,0x09,0x07,0x03,0x02,0x01,0x0d,
	0x09,0x10,0x0a,0x05,0x04,0x01,0x02,0x0b,0x0b,0x10,
	0x09,0x04,0x05,0x02,0x01,0x0c,0x08,0x01,0x01,0x0e,
	0x01,0x01,0x07,0x05,0x06,0x0e,0x08,0x0f,0x0a,0x04,
	0x07,0x0e,0x08,0x0f,0x03,0x01,0x02,0x04,0x0b,0x0c,
	0x0a,0x0b,0x02,0x02,0x02,0x07,0x0b,0x0d,0x09,0x0c,
	0x02,0x0a,0x0b,0x0c,0x08,0x0e,0x01,0x09,0x0e,0x0a,
	0x09,0x19,0x0d,0x0a,0x0a,0x0a,0x02,0x0b,0x09,0x01,
	0x05,0x0a,0x0a,0x0a,0x03,0x0a,0x0f,0x0b,0x09,0x0c,
	0x02,0x0a,0x0e,0x0b,0x0a,0x0c,0x02,0x09,0x08,0x01,
	0x05,0x0c,0x05,0x02,0x03,0x07,0x02,0x05,0x01,0x07,
	0x10,0x0b,0x06,0x0c,0x02,0x0d,0x0f,0x0b,0x07,0x0c,
	0x02,0x0c,0x0f,0x0c,0x07,0x0b,0x03,0x0c,0x10,0x0c,
	0x06,0x0c,0x03,0x0c,0x11,0x0b,0x07,0x0b,0x04,0x0c,
	0x0a,0x03,0x04,0x0c,0x06,0x0b,0x04,0x0c,0x0a,0x04,
	0x05,0x0c,0x05,0x0b,0x04,0x0c,0x04,0x01,0x04,0x06,
	0x06,0x0b,0x06,0x0a,0x05,0x0b,0x09,0x05,0x09,0x0b,
	0x05,0x0b,0x04,0x0b,0x09,0x05,0x0b,0x0a,0x06,0x0a,
	0x05,0x0a,0x08,0x06,0x09,0x04,0x02,0x05,0x02,0x03,
	0x05,0x04,0x01,0x05,0x04,0x0a,0x03,0x0b,0x04,0x01,
	0x04,0x04,0x04,0x0b,0x04,0x0a,0x04,0x0a,0x03,0x03,
	0x01,0x07,0x03,0x02,0x04,0x04,0x06,0x08,0x01,0x02,
	0x04,0x09,0x05,0x09,0x05,0x09,0x05,0x02,0x02,0x04,
	0x08,0x06,0x03,0x02,0x03,0x05,0x02,0x03,0x04,0x05,
	0x01,0x03,0x04,0x0b,0x04,0x09,0x08,0x05,0x04,0x02,
	0x04,0x04,0x04,0x01,0x04,0x05,0x04,0x01,0x03,0x06,
	0x03,0x02,0x03,0x05,0x02,0x03,0x04,0x03,0x01,0x06,
	0x03,0x03,0x03,0x05,0x03,0x02,0x04,0x05,0x03,0x02,
	0x03,0x05,0x03,0x04,0x02,0x05,0x03,0x03,0x03,0x02,
	0x03,0x05,0x03,0x03,0x04,0x04,0x04,0x02,0x03,0x06,
	0x03,0x0a,0x03,0x04,0x01,0x05,0x04,0x03,0x03,0x03,
	0x02,0x05,0x04,0x02,0x04,0x04,0x04,0x04,0x01,0x06,
	0x04,0x0a,0x03,0x0a,0x03,0x09,0x03,0x05,0x04,0x03,
	0x02,0x06,0x04,0x03,0x01,0x06,0x04,0x0b,0x03,0x0b,
	0x04,0x05,0x04,0x06,0x04,0x02,0x03,0x05,0x04,0x0c,
	0x04,0x0b,0x03,0x0b,0x05,0x04,0x04,0x07,0x02,0x02,
	0x04,0x06,0x04,0x0b,0x04,0x0b,0x04,0x0b,0x03,0x05,
	0x04,0x06,0x03,0x02,0x04,0x06,0x04,0x0b,0x04,0x0c,
	0x03,0x07,0x01,0x03,0x05,0x04,0x03,0x07,0x03,0x02,
	0x04,0x06,0x04,0x0b,0x04,0x0c,0x04,0x06,0x01,0x04,
	0x04,0x04,0x03,0x07,0x03,0x03,0x04,0x05,0x04,0x0c,
	0x04,0x06,0x01,0x05,0x03,0x0c,0x04,0x04,0x03,0x07,
	0x03,0x03,0x04,0x05,0x04,0x0c,0x04,0x06,0x01,0x05,
	0x04,0x0b,0x05,0x04,0x03,0x07,0x02,0x05,0x03,0x05,
	0x04,0x0d,0x04,0x0c,0x04,0x06,0x01,0x04,0x04,0x06,
	0x02,0x07,0x02,0x05,0x03,0x06,0x04,0x0c,0x04,0x0c,
	0x04,0x0c,0x04,0x06,0x02,0x08,0x01,0x05,0x03,0x07,
	0x04,0x0d,0x03,0x0d,0x03,0x0d,0x04,0x06,0x02,0x08,
	0x01,0x05,0x04,0x07,0x03,0x0d,0x04,0x0d,0x03,0x07,
	0x01,0x05,0x04,0x05,0x03,0x08,0x01,0x05,0x04,0x07,
	0x04,0x0d,0x04,0x0d,0x03,0x0d,0x04,0x07,0x02,0x0f,
	0x04,0x09,0x01,0x10,0x01,0x0f,0x03,0x0e,0x02,0x19,
	0x04,0x0b,0x01,0x80,0xa4,0x01,0x01,0x01,0x81,0x1d,
	0x01,0x00,

/* One */
	0x01,0x02,0x01,0x2f,0x01,0x11,0x05,0x2d,0x01,0x12,
	0x06,0x14,0x07,0x0e,0x05,0x10,0x07,0x11,0x08,0x0d,
	0x07,0x0d,0x07,0x12,0x02,0x02,0x01,0x0f,0x07,0x0c,
	0x07,0x1c,0x01,0x0c,0x06,0x0a,0x07,0x17,0x06,0x0c,
	0x06,0x09,0x06,0x09,0x03,0x0b,0x04,0x0d,0x08,0x08,
	0x06,0x09,0x02,0x0d,0x02,0x06,0x01,0x01,0x01,0x05,
	0x07,0x09,0x05,0x07,0x01,0x0f,0x03,0x06,0x04,0x03,
	0x08,0x08,0x04,0x07,0x01,0x06,0x02,0x07,0x04,0x05,
	0x05,0x02,0x09,0x07,0x04,0x06,0x02,0x05,0x03,0x07,
	0x04,0x05,0x04,0x04,0x0a,0x06,0x04,0x05,0x03,0x05,
	0x03,0x07,0x03,0x05,0x04,0x04,0x05,0x01,0x04,0x07,
	0x04,0x04,0x03,0x05,0x03,0x06,0x03,0x06,0x03,0x04,
	0x04,0x03,0x05,0x06,0x03,0x05,0x03,0x05,0x03,0x06,
	0x03,0x05,0x03,0x04,0x05,0x03,0x06,0x06,0x03,0x05,
	0x03,0x05,0x04,0x05,0x02,0x06,0x01,0x06,0x03,0x03,
	0x09,0x05,0x03,0x04,0x04,0x04,0x04,0x0c,0x03,0x04,
	0x04,0x04,0x09,0x05,0x04,0x04,0x03,0x04,0x04,0x05,
	0x01,0x06,0x03,0x04,0x04,0x03,0x04,0x03,0x04,0x05,
	0x03,0x04,0x04,0x04,0x04,0x04,0x02,0x05,0x03,0x04,
	0x04,0x04,0x03,0x03,0x06,0x05,0x03,0x04,0x03,0x05,
	0x03,0x05,0x01,0x05,0x02,0x06,0x02,0x05,0x01,0x05,
	0x08,0x05,0x04,0x04,0x02,0x05,0x03,0x05,0x01,0x05,
	0x02,0x07,0x01,0x03,0x01,0x07,0x02,0x01,0x07,0x05,
	0x03,0x04,0x03,0x04,0x04,0x04,0x01,0x05,0x03,0x06,
	0x01,0x03,0x02,0x06,0x02,0x02,0x07,0x06,0x03,0x04,
	0x03,0x04,0x03,0x04,0x01,0x05,0x03,0x09,0x04,0x04,
	0x02,0x03,0x08,0x05,0x04,0x03,0x03,0x04,0x03,0x04,
	0x02,0x04,0x02,0x0b,0x03,0x05,0x01,0x03,0x04,0x01,
	0x06,0x05,0x02,0x04,0x03,0x04,0x03,0x0b,0x01,0x0b,
	0x02,0x0a,0x04,0x02,0x07,0x06,0x01,0x04,0x03,0x04,
	0x03,0x03,0x01,0x14,0x01,0x0b,0x04,0x02,0x04,0x01,
	0x02,0x06,0x01,0x04,0x03,0x2a,0x05,0x01,0x02,0x01,
	0x01,0x01,0x05,0x0b,0x01,0x09,0x01,0x23,0x04,0x01,
	0x01,0x05,0x02,0x01,0x02,0x0a,0x02,0x2f,0x05,0x04,
	0x02,0x00,

/* Two */
	0x01,0x26,0x01,0x01,0x01,0x03,0x01,0x01,0x01,0x12,
	0x01,0x05,0x01,0x02,0x01,0x05,0x01,0x0e,0x01,0x0a,
	0x01,0x01,0x01,0x03,0x01,0x04,0x01,0x0c,0x01,0x05,
	0x01,0x09,0x01,0x06,0x01,0x13,0x01,0x16,0x01,0x1c,
	0x01,0x82,0x21,0x01,0x01,0x07,0x01,0x01,0x14,0x09,
	0x07,0x07,0x0f,0x07,0x0b,0x08,0x0d,0x0a,0x0a,0x0a,
	0x0c,0x0a,0x0b,0x09,0x01,0x01,0x0b,0x0a,0x0a,0x0b,
	0x0c,0x09,0x0b,0x0a,0x0c,0x09,0x0b,0x09,0x0c,0x0a,
	0x0b,0x09,0x0c,0x0a,0x0a,0x0a,0x0c,0x09,0x0b,0x09,
	0x0c,0x09,0x0b,0x09,0x0c,0x09,0x0b,0x09,0x0d,0x08,
	0x0b,0x09,0x0d,0x09,0x0b,0x09,0x0d,0x08,0x0c,0x09,
	0x0c,0x0a,0x0b,0x0a,0x0d,0x0a,0x0b,0x0b,0x0c,0x0a,
	0x0c,0x0b,0x0d,0x0a,0x0c,0x0c,0x0d,0x0b,0x0c,0x0d,
	0x0e,0x0a,0x0e,0x0e,0x0e,0x0a,0x10,0x0d,0x0f,0x0a,
	0x10,0x0f,0x0f,0x0a,0x10,0x11,0x10,0x0a,0x10,0x0a,
	0x19,0x0a,0x0f,0x0a,0x0a,0x03,0x11,0x09,0x10,0x09,
	0x0b,0x04,0x10,0x0a,0x0f,0x09,0x0c,0x05,0x11,0x09,
	0x0f,0x09,0x0c,0x07,0x10,0x0a,0x0f,0x09,0x0d,0x07,
	0x10,0x08,0x13,0x08,0x0d,0x09,0x12,0x06,0x14,0x05,
	0x10,0x06,0x13,0x02,0x01,0x06,0x15,0x05,0x2e,0x02,
	0x01,0x04,0x17,0x01,0x31,0x08,0x4b,0x09,0x4e,0x06,
	0x16,0x02,0x3d,0x02,0x18,0x01,0x80,0xa0,0x01,0x00,

/* Three */
	0x01,0x03,0x01,0x2a,0x01,0x24,0x01,0x06,0x01,0x04,
	0x01,0x03,0x01,0x11,0x01,0x05,0x01,0x01,0x01,0x02,
	0x01,0x04,0x01,0x07,0x01,0x08,0x01,0x04,0x01,0x04,
	0x01,0x01,0x01,0x02,0x01,0x02,0x01,0x05,0x01,0x0f,
	0x01,0x02,0x01,0x04,0x01,0x01,0x02,0x01,0x01,0x05,
	0x01,0x01,0x01,0x0d,0x01,0x09,0x01,0x03,0x01,0x14,
	0x01,0x02,0x01,0x04,0x01,0x07,0x01,0x06,0x01,0x04,
	0x01,0x04,0x01,0x03,0x01,0x08,0x01,0x04,0x01,0x09,
	0x01,0x09,0x01,0x21,0x01,0x02,0x01,0x0f,0x01,0x13,
	0x01,0x13,0x01,0x20,0x01,0x01,0x01,0x04,0x01,0x06,
	0x01,0x04,0x01,0x03,0x01,0x0e,0x01,0x05,0x01,0x04,
	0x01,0x09,0x01,0x0a,0x01,0x12,0x01,0x1e,0x01,0x10,
	0x01,0x80,0xa1,0x03,0x03,0x02,0x06,0x02,0x01,0x08,
	0x0e,0x08,0x0a,0x11,0x0e,0x06,0x0b,0x0a,0x01,0x06,
	0x0e,0x07,0x0b,0x09,0x02,0x06,0x0e,0x07,0x0a,0x0a,
	0x01,0x06,0x0e,0x07,0x0a,0x09,0x01,0x07,0x0e,0x06,
	0x0d,0x10,0x0e,0x06,0x02,0x01,0x0a,0x10,0x0f,0x09,
	0x09,0x0a,0x01,0x06,0x0e,0x09,0x0c,0x0f,0x0d,0x09,
	0x0c,0x10,0x02,0x01,0x0c,0x08,0x0c,0x0f,0x10,0x07,
	0x0c,0x02,0x01,0x0d,0x02,0x01,0x0c,0x08,0x0f,0x0d,
	0x02,0x02,0x0b,0x08,0x0e,0x0f,0x02,0x01,0x0c,0x0a,
	0x0d,0x0f,0x01,0x02,0x0c,0x09,0x10,0x0d,0x01,0x02,
	0x0c,0x01,0x01,0x09,0x0e,0x0e,0x02,0x01,0x0b,0x02,
	0x01,0x09,0x0e,0x0f,0x01,0x02,0x0b,0x01,0x01,0x0a,
	0x0f,0x0e,0x02,0x01,0x0e,0x0a,0x0e,0x10,0x01,0x02,
	0x01,0x01,0x09,0x01,0x01,0x0b,0x0e,0x11,0x02,0x01,
	0x02,0x01,0x0b,0x01,0x01,0x08,0x0f,0x0a,0x06,0x03,
	0x01,0x02,0x01,0x01,0x0b,0x01,0x02,0x08,0x0e,0x0a,
	0x09,0x06,0x02,0x01,0x0b,0x01,0x01,0x09,0x0f,0x08,
	0x0a,0x05,0x01,0x02,0x01,0x01,0x0b,0x01,0x01,0x09,
	0x10,0x0a,0x0b,0x09,0x01,0x01,0x0b,0x01,0x01,0x09,
	0x0f,0x01,0x01,0x08,0x0b,0x09,0x01,0x01,0x02,0x01,
	0x0b,0x01,0x01,0x06,0x01,0x01,0x0f,0x01,0x01,0x08,
	0x0d,0x0c,0x01,0x01,0x02,0x01,0x0a,0x02,0x01,0x06,
	0x01,0x01,0x11,0x01,0x02,0x02,0x02,0x01,0x10,0x09,
	0x01,0x01,0x02,0x01,0x0d,0x01,0x01,0x02,0x01,0x06,
	0x01,0x01,0x11,0x05,0x02,0x01,0x10,0x0c,0x02,0x01,
	0x02,0x01,0x0b,0x01,0x01,0x06,0x01,0x01,0x14,0x02,
	0x01,0x01,0x17,0x02,0x01,0x02,0x02,0x01,0x02,0x01,
	0x03,0x01,0x02,0x01,0x0b,0x01,0x01,0x02,0x01,0x03,
	0x01,0x01,0x02,0x01,0x0e,0x01,0x02,0x01,0x02,0x02,
	0x16,0x02,0x01,0x01,0x0f,0x01,0x02,0x01,0x0d,0x01,
	0x02,0x01,0x01,0x01,0x01,0x01,0x13,0x01,0x03,0x01,
	0x02,0x01,0x10,0x01,0x1a,0x01,0x10,0x01,0x01,0x01,
	0x02,0x01,0x03,0x01,0x45,0x01,0x02,0x01,0x0d,0x01,
	0x02,0x01,0x03,0x01,0x13,0x01,0x03,0x01,0x44,0x01,
	0x01,0x01,0x65,0x01,0x00,

/* Four */
	0x0a,0x0a,0x01,0x02,0x02,0x0b,0x0e,0x07,0x03,0x02,
	0x04,0x06,0x04,0x03,0x01,0x07,0x0a,0x07,0x09,0x05,
	0x05,0x0b,0x09,0x06,0x06,0x02,0x01,0x06,0x05,0x05,
	0x01,0x04,0x09,0x07,0x05,0x02,0x01,0x07,0x04,0x05,
	0x04,0x02,0x08,0x07,0x05,0x03,0x01,0x06,0x04,0x06,
	0x03,0x03,0x07,0x07,0x03,0x01,0x04,0x06,0x05,0x07,
	0x04,0x01,0x07,0x06,0x04,0x04,0x02,0x05,0x05,0x06,
	0x04,0x03,0x06,0x06,0x04,0x03,0x03,0x05,0x05,0x06,
	0x05,0x02,0x06,0x05,0x05,0x03,0x04,0x04,0x05,0x06,
	0x04,0x03,0x05,0x06,0x04,0x05,0x02,0x05,0x05,0x06,
	0x04,0x03,0x05,0x05,0x05,0x04,0x03,0x05,0x05,0x05,
	0x05,0x03,0x05,0x05,0x05,0x04,0x03,0x05,0x04,0x06,
	0x04,0x03,0x05,0x06,0x05,0x04,0x03,0x04,0x05,0x06,
	0x04,0x03,0x05,0x06,0x05,0x04,0x03,0x04,0x05,0x06,
	0x05,0x02,0x05,0x06,0x05,0x05,0x02,0x05,0x04,0x06,
	0x05,0x02,0x05,0x06,0x05,0x06,0x01,0x05,0x05,0x06,
	0x05,0x01,0x06,0x06,0x06,0x05,0x01,0x05,0x05,0x06,
	0x0c,0x07,0x05,0x0c,0x05,0x06,0x0c,0x07,0x06,0x0b,
	0x05,0x06,0x0c,0x07,0x07,0x0a,0x06,0x07,0x0a,0x08,
	0x07,0x0a,0x07,0x07,0x09,0x08,0x08,0x0b,0x06,0x07,
	0x07,0x0a,0x09,0x0a,0x07,0x06,0x06,0x0a,0x0a,0x0b,
	0x06,0x05,0x08,0x0a,0x0a,0x0c,0x03,0x05,0x0a,0x0b,
	0x04,0x01,0x01,0x01,0x05,0x11,0x0b,0x11,0x07,0x10,
	0x0b,0x11,0x08,0x0b,0x02,0x04,0x0c,0x0b,0x0c,0x13,
	0x0b,0x0a,0x0a,0x18,0x09,0x0a,0x09,0x0d,0x04,0x08,
	0x0b,0x0a,0x08,0x0c,0x05,0x09,0x0d,0x09,0x07,0x0e,
	0x04,0x09,0x08,0x04,0x05,0x09,0x08,0x01,0x01,0x09,
	0x05,0x09,0x07,0x06,0x07,0x09,0x07,0x0a,0x06,0x0a,
	0x06,0x07,0x08,0x09,0x07,0x09,0x07,0x08,0x08,0x08,
	0x0a,0x08,0x06,0x0b,0x05,0x07,0x06,0x01,0x02,0x08,
	0x05,0x01,0x08,0x07,0x08,0x08,0x05,0x0b,0x05,0x07,
	0x03,0x02,0x05,0x04,0x04,0x07,0x05,0x02,0x03,0x06,
	0x04,0x0b,0x05,0x06,0x03,0x04,0x03,0x05,0x06,0x07,
	0x08,0x06,0x06,0x09,0x05,0x06,0x02,0x04,0x02,0x06,
	0x0b,0x06,0x04,0x02,0x03,0x05,0x05,0x0a,0x04,0x0b,
	0x03,0x06,0x03,0x01,0x05,0x03,0x03,0x06,0x03,0x03,
	0x03,0x05,0x04,0x0a,0x04,0x09,0x04,0x0a,0x05,0x02,
	0x04,0x01,0x03,0x06,0x02,0x03,0x03,0x05,0x04,0x02,
	0x02,0x05,0x04,0x0a,0x03,0x0a,0x04,0x03,0x03,0x03,
	0x04,0x05,0x03,0x02,0x04,0x05,0x03,0x02,0x03,0x05,
	0x03,0x02,0x03,0x05,0x03,0x0a,0x03,0x04,0x02,0x04,
	0x07,0x06,0x01,0x03,0x04,0x05,0x01,0x02,0x05,0x09,
	0x04,0x09,0x04,0x09,0x04,0x08,0x06,0x0a,0x04,0x09,
	0x04,0x09,0x04,0x09,0x03,0x0b,0x02,0x0a,0x05,0x0d,
	0x04,0x09,0x03,0x0a,0x03,0x0b,0x02,0x19,0x07,0x0a,
	0x04,0x09,0x03,0x0b,0x03,0x1b,0x02,0x0e,0x01,0x02,
	0x01,0x0a,0x04,0x0a,0x03,0x0a,0x01,0x02,0x04,0x0b,
	0x01,0x0c,0x01,0x1e,0x04,0x0a,0x03,0x0e,0x03,0x0b,
	0x01,0x0f,0x01,0x1e,0x03,0x0a,0x02,0x0f,0x02,0x0d,
	0x01,0x30,0x03,0x00,

/* Five */
	0x01,0x41,0x09,0x14,0x01,0x05,0x0c,0x09,0x06,0x06,
	0x02,0x02,0x01,0x06,0x03,0x02,0x08,0x06,0x04,0x01,
	0x03,0x05,0x04,0x08,0x04,0x03,0x09,0x05,0x04,0x03,
	0x02,0x04,0x04,0x05,0x01,0x04,0x02,0x03,0x0a,0x04,
	0x04,0x04,0x02,0x04,0x04,0x04,0x02,0x04,0x02,0x03,
	0x04,0x02,0x04,0x05,0x04,0x03,0x02,0x04,0x04,0x04,
	0x03,0x04,0x03,0x01,0x03,0x04,0x04,0x04,0x04,0x03,
	0x03,0x03,0x04,0x04,0x04,0x04,0x04,0x05,0x05,0x05,
	0x04,0x04,0x02,0x03,0x04,0x04,0x04,0x04,0x04,0x04,
	0x06,0x04,0x04,0x05,0x01,0x03,0x04,0x05,0x03,0x04,
	0x04,0x04,0x06,0x05,0x04,0x04,0x02,0x02,0x04,0x05,
	0x03,0x04,0x04,0x04,0x06,0x05,0x04,0x05,0x01,0x02,
	0x04,0x05,0x04,0x03,0x04,0x04,0x07,0x05,0x04,0x04,
	0x02,0x02,0x04,0x05,0x03,0x04,0x04,0x04,0x07,0x05,
	0x04,0x05,0x01,0x02,0x04,0x05,0x03,0x04,0x04,0x04,
	0x08,0x05,0x04,0x04,0x02,0x02,0x04,0x04,0x03,0x04,
	0x04,0x05,0x09,0x04,0x05,0x04,0x02,0x02,0x04,0x03,
	0x03,0x04,0x04,0x07,0x09,0x04,0x04,0x03,0x01,0x01,
	0x01,0x02,0x03,0x04,0x04,0x04,0x05,0x05,0x05,0x01,
	0x04,0x04,0x03,0x04,0x01,0x04,0x03,0x04,0x03,0x07,
	0x04,0x05,0x05,0x01,0x04,0x04,0x03,0x04,0x01,0x04,
	0x03,0x04,0x02,0x02,0x03,0x04,0x03,0x06,0x05,0x02,
	0x04,0x04,0x02,0x02,0x01,0x01,0x02,0x03,0x03,0x03,
	0x02,0x04,0x02,0x07,0x02,0x05,0x05,0x03,0x04,0x04,
	0x02,0x02,0x03,0x04,0x08,0x05,0x01,0x02,0x02,0x05,
	0x02,0x05,0x0d,0x04,0x02,0x01,0x03,0x07,0x05,0x07,
	0x03,0x07,0x03,0x01,0x02,0x03,0x04,0x01,0x06,0x07,
	0x03,0x02,0x01,0x05,0x06,0x07,0x04,0x08,0x06,0x06,
	0x06,0x08,0x03,0x01,0x02,0x07,0x05,0x08,0x04,0x0a,
	0x04,0x06,0x07,0x08,0x01,0x01,0x03,0x07,0x02,0x01,
	0x04,0x0a,0x03,0x0a,0x06,0x03,0x06,0x09,0x01,0x01,
	0x02,0x01,0x03,0x07,0x01,0x01,0x05,0x0b,0x05,0x0a,
	0x08,0x04,0x01,0x02,0x01,0x08,0x01,0x02,0x02,0x01,
	0x01,0x0a,0x01,0x01,0x01,0x01,0x02,0x0b,0x02,0x01,
	0x01,0x0a,0x08,0x02,0x01,0x07,0x01,0x08,0x01,0x02,
	0x01,0x01,0x02,0x05,0x01,0x08,0x01,0x11,0x01,0x0f,
	0x06,0x19,0x01,0x01,0x01,0x00,

/* Six */
	0x01,0x2a,0x01,0x3d,0x01,0x08,0x01,0x01,0x01,0x05,
	0x01,0x01,0x02,0x01,0x01,0x09,0x01,0x01,0x01,0x03,
	0x01,0x27,0x01,0x0d,0x01,0x01,0x01,0x04,0x01,0x02,
	0x01,0x01,0x01,0x0a,0x01,0x01,0x01,0x02,0x01,0x09,
	0x01,0x02,0x01,0x07,0x01,0x0b,0x01,0x07,0x01,0x01,
	0x01,0x0f,0x01,0x01,0x01,0x03,0x01,0x01,0x01,0x13,
	0x01,0x03,0x01,0x01,0x01,0x01,0x01,0x05,0x01,0x05,
	0x01,0x02,0x01,0x08,0x01,0x0a,0x01,0x01,0x01,0x04,
	0x01,0x01,0x01,0x01,0x01,0x02,0x01,0x05,0x01,0x01,
	0x01,0x04,0x01,0x01,0x01,0x03,0x01,0x11,0x01,0x01,
	0x01,0x02,0x01,0x02,0x01,0x06,0x01,0x01,0x01,0x04,
	0x01,0x02,0x01,0x02,0x01,0x03,0x01,0x01,0x01,0x06,
	0x01,0x05,0x01,0x01,0x01,0x01,0x01,0x04,0x01,0x09,
	0x02,0x03,0x01,0x01,0x01,0x02,0x01,0x02,0x01,0x09,
	0x02,0x0a,0x01,0x01,0x02,0x05,0x01,0x01,0x01,0x0b,
	0x02,0x06,0x01,0x01,0x01,0x04,0x01,0x02,0x01,0x04,
	0x01,0x01,0x01,0x02,0x01,0x02,0x01,0x04,0x01,0x02,
	0x01,0x06,0x01,0x08,0x02,0x0c,0x01,0x02,0x01,0x01,
	0x01,0x01,0x01,0x02,0x01,0x07,0x01,0x07,0x01,0x09,
	0x01,0x04,0x01,0x02,0x01,0x02,0x02,0x01,0x01,0x14,
	0x01,0x07,0x02,0x04,0x01,0x02,0x01,0x0a,0x01,0x01,
	0x01,0x01,0x01,0x0d,0x03,0x09,0x01,0x07,0x01,0x08,
	0x01,0x01,0x01,0x08,0x01,0x02,0x01,0x09,0x02,0x01,
	0x01,0x04,0x01,0x03,0x01,0x01,0x01,0x01,0x01,0x0c,
	0x01,0x01,0x01,0x04,0x01,0x01,0x01,0x04,0x01,0x07,
	0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x01,0x0a,
	0x01,0x01,0x01,0x09,0x01,0x01,0x01,0x04,0x01,0x04,
	0x01,0x01,0x01,0x02,0x01,0x01,0x01,0x02,0x01,0x02,
	0x01,0x07,0x01,0x01,0x01,0x12,0x01,0x05,0x01,0x04,
	0x01,0x01,0x01,0x07,0x02,0x07,0x01,0x02,0x01,0x07,
	0x01,0x02,0x01,0x01,0x01,0x01,0x02,0x01,0x02,0x06,
	0x01,0x05,0x01,0x01,0x01,0x04,0x01,0x06,0x01,0x02,
	0x01,0x04,0x01,0x02,0x01,0x01,0x01,0x04,0x01,0x01,
	0x02,0x09,0x01,0x01,0x02,0x0b,0x03,0x05,0x01,0x05,
	0x01,0x01,0x02,0x04,0x01,0x01,0x02,0x06,0x02,0x01,
	0x01,0x09,0x01,0x14,0x06,0x01,0x01,0x06,0x01,0x01,
	0x01,0x0b,0x01,0x01,0x01,0x04,0x01,0x0a,0x03,0x07,
	0x01,0x05,0x01,0x01,0x01,0x03,0x01,0x09,0x01,0x09,
	0x01,0x07,0x01,0x02,0x01,0x03,0x02,0x0c,0x01,0x01,
	0x01,0x01,0x01,0x04,0x01,0x02,0x01,0x06,0x01,0x02,
	0x01,0x03,0x02,0x01,0x01,0x03,0x01,0x04,0x01,0x02,
	0x01,0x09,0x01,0x08,0x01,0x01,0x01,0x05,0x01,0x02,
	0x01,0x07,0x01,0x09,0x01,0x08,0x01,0x07,0x01,0x01,
	0x01,0x02,0x01,0x01,0x02,0x03,0x01,0x01,0x01,0x02,
	0x01,0x02,0x01,0x01,0x01,0x07,0x02,0x04,0x01,0x03,
	0x01,0x01,0x01,0x02,0x01,0x02,0x01,0x04,0x01,0x02,
	0x01,0x01,0x01,0x04,0x01,0x02,0x01,0x01,0x02,0x03,
	0x01,0x01,0x02,0x07,0x01,0x06,0x02,0x0e,0x01,0x07,
	0x01,0x03,0x01,0x01,0x01,0x18,0x01,0x08,0x01,0x0a,
	0x01,0x04,0x01,0x01,0x02,0x0d,0x01,0x1e,0x01,0x26,
	0x01,0x01,0x01,0x01,0x01,0x1c,0x01,0x01,0x0d,0x0d,
	0x08,0x0a,0x0b,0x0b,0x08,0x01,0x01,0x09,0x0c,0x0b,
	0x08,0x02,0x01,0x08,0x0c,0x0b,0x07,0x0c,0x0c,0x0a,
	0x08,0x02,0x01,0x08,0x0d,0x02,0x01,0x08,0x02,0x01,
	0x04,0x02,0x01,0x08,0x02,0x01,0x0a,0x02,0x01,0x08,
	0x02,0x01,0x05,0x02,0x01,0x08,0x01,0x01,0x05,0x01,
	0x05,0x02,0x01,0x08,0x02,0x01,0x05,0x01,0x01,0x08,
	0x02,0x01,0x02,0x01,0x02,0x01,0x05,0x01,0x02,0x08,
	0x01,0x01,0x05,0x02,0x01,0x08,0x01,0x02,0x02,0x01,
	0x01,0x01,0x06,0x01,0x01,0x09,0x01,0x02,0x04,0x01,
	0x02,0x08,0x01,0x02,0x02,0x04,0x01,0x01,0x04,0x01,
	0x02,0x08,0x01,0x02,0x04,0x01,0x02,0x07,0x02,0x02,
	0x02,0x07,0x05,0x01,0x01,0x0b,0x05,0x01,0x02,0x08,
	0x01,0x01,0x03,0x09,0x05,0x01,0x02,0x08,0x01,0x01,
	0x05,0x0a,0x06,0x0a,0x08,0x03,0x01,0x05,0x01,0x02,
	0x01,0x02,0x01,0x02,0x01,0x05,0x01,0x02,0x05,0x01,
	0x01,0x0a,0x07,0x04,0x02,0x02,0x01,0x02,0x01,0x06,
	0x01,0x01,0x02,0x01,0x02,0x02,0x01,0x02,0x01,0x02,
	0x01,0x02,0x02,0x01,0x01,0x0f,0x02,0x01,0x02,0x01,
	0x02,0x01,0x02,0x02,0x01,0x02,0x01,0x03,0x01,0x02,
	0x01,0x02,0x02,0x01,0x02,0x01,0x02,0x02,0x01,0x02,
	0x01,0x06,0x01,0x02,0x01,0x29,0x01,0x02,0x02,0x02,
	0x01,0x02,0x01,0x03,0x01,0x84,0x03,0x01,0x04,0x01,
	0x08,0x01,0x15,0x01,0x04,0x01,0x0e,0x01,0x16,0x01,
	0x01,0x01,0x04,0x01,0x01,0x01,0x09,0x01,0x05,0x01,
	0x02,0x01,0x01,0x01,0x04,0x01,0x01,0x01,0x03,0x01,
	0x01,0x02,0x05,0x01,0x03,0x01,0x01,0x01,0x06,0x01,
	0x01,0x01,0x03,0x01,0x02,0x01,0x04,0x01,0x01,0x01,
	0x03,0x01,0x04,0x01,0x04,0x01,0x03,0x01,0x02,0x01,
	0x01,0x01,0x07,0x01,0x04,0x01,0x01,0x01,0x0a,0x01,
	0x02,0x01,0x05,0x01,0x01,0x01,0x03,0x01,0x06,0x01,
	0x01,0x01,0x03,0x01,0x06,0x01,0x01,0x01,0x02,0x01,
	0x04,0x01,0x08,0x01,0x01,0x03,0x05,0x01,0x01,0x04,
	0x04,0x01,0x02,0x01,0x0c,0x01,0x01,0x03,0x01,0x01,
	0x01,0x01,0x08,0x01,0x01,0x01,0x01,0x02,0x05,0x01,
	0x07,0x01,0x09,0x01,0x02,0x01,0x01,0x01,0x08,0x01,
	0x06,0x01,0x03,0x02,0x04,0x01,0x02,0x01,0x08,0x01,
	0x01,0x01,0x06,0x01,0x07,0x01,0x0d,0x01,0x01,0x01,
	0x05,0x01,0x02,0x01,0x02,0x01,0x01,0x01,0x02,0x01,
	0x0e,0x01,0x08,0x01,0x01,0x01,0x05,0x01,0x03,0x01,
	0x06,0x02,0x08,0x01,0x0f,0x01,0x01,0x01,0x05,0x01,
	0x07,0x01,0x01,0x01,0x03,0x01,0x01,0x01,0x14,0x01,
	0x01,0x01,0x04,0x01,0x02,0x01,0x01,0x01,0x05,0x01,
	0x02,0x01,0x07,0x01,0x04,0x01,0x01,0x01,0x01,0x01,
	0x03,0x01,0x09,0x01,0x04,0x01,0x02,0x01,0x0a,0x01,
	0x0a,0x01,0x06,0x01,0x05,0x01,0x01,0x01,0x02,0x01,
	0x01,0x01,0x06,0x01,0x02,0x01,0x06,0x01,0x01,0x01,
	0x0f,0x01,0x01,0x01,0x07,0x01,0x06,0x01,0x02,0x01,
	0x01,0x01,0x02,0x01,0x05,0x01,0x08,0x01,0x04,0x01,
	0x02,0x01,0x01,0x01,0x02,0x01,0x03,0x01,0x07,0x01,
	0x02,0x01,0x01,0x01,0x07,0x01,0x0b,0x01,0x10,0x01,
	0x0a,0x01,0x0a,0x01,0x04,0x01,0x03,0x01,0x01,0x01,
	0x0e,0x01,0x06,0x01,0x01,0x02,0x01,0x01,0x0d,0x01,
	0x04,0x01,0x1b,0x01,0x09,0x01,0x10,0x01,0x05,0x01,
	0x01,0x01,0x0e,0x01,0x02,0x01,0x02,0x01,0x02,0x01,
	0x01,0x01,0x0d,0x01,0x0a,0x01,0x0e,0x01,0x01,0x01,
	0x01,0x01,0x02,0x01,0x1d,0x01,0x01,0x01,0x06,0x01,
	0x12,0x01,0x09,0x01,0x03,0x01,0x14,0x01,0x02,0x01,
	0x01,0x02,0x01,0x01,0x06,0x01,0x07,0x01,0x04,0x01,
	0x01,0x01,0x01,0x01,0x03,0x01,0x01,0x02,0x01,0x01,
	0x02,0x01,0x01,0x01,0x09,0x01,0x01,0x01,0x09,0x01,
	0x06,0x01,0x07,0x01,0x01,0x01,0x01,0x01,0x04,0x01,
	0x04,0x01,0x05,0x01,0x01,0x01,0x01,0x01,0x03,0x01,
	0x03,0x01,0x01,0x01,0x01,0x01,0x07,0x01,0x1a,0x01,
	0x01,0x01,0x0d,0x01,0x0e,0x01,0x18,0x01,0x23,0x01,
	0x08,0x01,0x07,0x01,0x08,0x01,0x05,0x01,0x05,0x01,
	0x04,0x01,0x09,0x01,0x05,0x01,0x0c,0x01,0x01,0x01,
	0x01,0x01,0x07,0x01,0x04,0x01,0x01,0x01,0x10,0x01,
	0x08,0x01,0x01,0x01,0x08,0x01,0x05,0x01,0x02,0x01,
	0x0b,0x01,0x01,0x01,0x08,0x01,0x07,0x01,0x05,0x01,
	0x19,0x01,0x22,0x01,0x03,0x01,0x01,0x01,0x01,0x01,
	0x06,0x01,0x18,0x01,0x08,0x01,0x03,0x01,0x01,0x01,
	0x0f,0x01,0x3d,0x01,0x08,0x01,0x1a,0x01,0x7d,0x01,
	0x01,0x01,0x00,

/* Seven */
	0x01,0x31,0x01,0x0d,0x01,0x0d,0x01,0x12,0x01,0x04,
	0x01,0x07,0x01,0x05,0x01,0x26,0x01,0x0b,0x01,0x05,
	0x01,0x1a,0x01,0x07,0x01,0x06,0x02,0x05,0x01,0x09,
	0x02,0x06,0x01,0x09,0x01,0x07,0x01,0x03,0x01,0x07,
	0x01,0x01,0x01,0x02,0x01,0x01,0x02,0x09,0x01,0x15,
	0x01,0x07,0x01,0x0b,0x01,0x01,0x02,0x02,0x01,0x0e,
	0x02,0x0d,0x01,0x09,0x01,0x02,0x01,0x02,0x01,0x01,
	0x01,0x05,0x01,0x01,0x01,0x05,0x01,0x18,0x03,0x05,
	0x01,0x01,0x02,0x01,0x01,0x02,0x02,0x0b,0x01,0x01,
	0x01,0x04,0x01,0x02,0x02,0x05,0x01,0x04,0x01,0x05,
	0x02,0x1d,0x01,0x07,0x01,0x02,0x01,0x03,0x01,0x03,
	0x01,0x01,0x01,0x05,0x01,0x0e,0x03,0x02,0x01,0x04,
	0x01,0x09,0x01,0x05,0x01,0x01,0x01,0x02,0x01,0x04,
	0x02,0x02,0x01,0x02,0x01,0x0c,0x01,0x07,0x02,0x01,
	0x01,0x05,0x02,0x09,0x01,0x01,0x02,0x10,0x01,0x01,
	0x02,0x01,0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x01,
	0x02,0x02,0x01,0x0c,0x01,0x01,0x01,0x02,0x02,0x01,
	0x02,0x0a,0x01,0x06,0x01,0x04,0x01,0x06,0x01,0x03,
	0x01,0x01,0x01,0x08,0x01,0x04,0x01,0x0a,0x01,0x05,
	0x01,0x01,0x01,0x12,0x01,0x02,0x02,0x14,0x01,0x01,
	0x02,0x01,0x03,0x0f,0x01,0x01,0x01,0x03,0x02,0x02,
	0x01,0x02,0x01,0x01,0x02,0x01,0x01,0x0c,0x01,0x02,
	0x01,0x04,0x01,0x07,0x01,0x0c,0x01,0x05,0x01,0x01,
	0x02,0x3d,0x01,0x02,0x01,0x04,0x02,0x02,0x03,0x0b,
	0x01,0x01,0x01,0x02,0x01,0x02,0x01,0x01,0x01,0x02,
	0x01,0x07,0x02,0x04,0x01,0x01,0x01,0x04,0x01,0x07,
	0x01,0x05,0x01,0x05,0x03,0x05,0x01,0x02,0x01,0x02,
	0x01,0x04,0x01,0x01,0x01,0x05,0x01,0x07,0x02,0x01,
	0x01,0x04,0x01,0x07,0x01,0x01,0x01,0x03,0x01,0x03,
	0x01,0x01,0x02,0x0a,0x01,0x09,0x01,0x02,0x01,0x09,
	0x01,0x03,0x01,0x01,0x01,0x05,0x01,0x04,0x01,0x02,
	0x01,0x37,0x0c,0x0e,0x07,0x08,0x0b,0x0b,0x05,0x01,
	0x01,0x09,0x11,0x0b,0x07,0x08,0x07,0x03,0x07,0x08,
	0x08,0x07,0x02,0x01,0x07,0x03,0x07,0x07,0x08,0x06,
	0x04,0x01,0x02,0x07,0x07,0x07,0x07,0x07,0x04,0x07,
	0x0a,0x08,0x04,0x07,0x06,0x07,0x0b,0x05,0x01,0x01,
	0x04,0x07,0x05,0x08,0x0a,0x08,0x03,0x07,0x05,0x07,
	0x0c,0x05,0x01,0x01,0x04,0x07,0x05,0x06,0x06,0x01,
	0x06,0x04,0x01,0x02,0x03,0x04,0x01,0x02,0x04,0x07,
	0x03,0x01,0x02,0x01,0x06,0x05,0x01,0x02,0x02,0x04,
	0x01,0x02,0x05,0x07,0x02,0x01,0x03,0x01,0x05,0x04,
	0x01,0x02,0x03,0x04,0x01,0x02,0x04,0x08,0x02,0x01,
	0x09,0x04,0x01,0x02,0x03,0x04,0x01,0x02,0x05,0x07,
	0x0c,0x04,0x01,0x02,0x03,0x04,0x01,0x02,0x04,0x08,
	0x0c,0x07,0x03,0x04,0x01,0x03,0x04,0x01,0x01,0x05,
	0x0d,0x08,0x02,0x04,0x01,0x03,0x04,0x01,0x01,0x05,
	0x0d,0x08,0x03,0x08,0x06,0x05,0x05,0x01,0x07,0x07,
	0x03,0x01,0x01,0x02,0x01,0x03,0x01,0x01,0x02,0x01,
	0x01,0x06,0x01,0x01,0x0b,0x08,0x05,0x07,0x03,0x01,
	0x01,0x08,0x01,0x01,0x09,0x09,0x04,0x01,0x02,0x05,
	0x01,0x02,0x01,0x01,0x02,0x08,0x09,0x08,0x01,0x01,
	0x02,0x01,0x04,0x03,0x01,0x05,0x02,0x02,0x01,0x02,
	0x01,0x02,0x01,0x01,0x08,0x03,0x01,0x0b,0x04,0x01,
	0x02,0x12,0x08,0x03,0x02,0x0d,0x01,0x01,0x02,0x18,
	0x09,0x28,0x09,0x01,0x02,0x2a,0x0c,0x2c,0x07,0x01,
	0x01,0x01,0x01,0x2e,0x07,0x01,0x01,0x31,0x01,0x01,
	0x01,0x01,0x04,0x33,0x01,0x02,0x01,0x01,0x05,0x3c,
	0x01,0x01,0x02,0x3a,0x01,0x03,0x03,0x34,0x01,0x03,
	0x02,0x04,0x04,0x35,0x01,0x01,0x0c,0x0d,0x03,0x01,
	0x04,0x08,0x01,0x0e,0x02,0x01,0x06,0x01,0x08,0x0b,
	0x06,0x01,0x01,0x0a,0x02,0x0b,0x08,0x06,0x05,0x09,
	0x01,0x01,0x06,0x01,0x01,0x08,0x04,0x0b,0x04,0x01,
	0x02,0x08,0x09,0x08,0x02,0x01,0x04,0x08,0x02,0x01,
	0x04,0x08,0x01,0x02,0x03,0x0a,0x05,0x01,0x01,0x05,
	0x04,0x08,0x01,0x02,0x05,0x01,0x01,0x06,0x01,0x01,
	0x02,0x01,0x01,0x09,0x01,0x02,0x01,0x01,0x02,0x08,
	0x01,0x01,0x05,0x0b,0x01,0x01,0x02,0x09,0x02,0x01,
	0x02,0x01,0x01,0x02,0x01,0x05,0x02,0x01,0x02,0x01,
	0x01,0x06,0x01,0x02,0x01,0x02,0x01,0x08,0x01,0x02,
	0x01,0x01,0x02,0x02,0x01,0x05,0x02,0x0c,0x02,0x09,
	0x01,0x02,0x01,0x02,0x01,0x02,0x01,0x05,0x02,0x01,
	0x02,0x01,0x01,0x0c,0x01,0x0b,0x01,0x02,0x01,0x02,
	0x01,0x05,0x01,0x10,0x02,0x02,0x01,0x09,0x01,0x05,
	0x01,0x0f,0x01,0x00,

/* Eight */
	0x01,0x0d,0x01,0x81,0xf7,0x01,0x04,0x02,0x0b,0x01,
	0x0f,0x01,0x07,0x01,0x02,0x01,0x09,0x01,0x05,0x01,
	0x02,0x01,0x81,0x2c,0x04,0x1b,0x09,0x0b,0x01,0x01,
	0x01,0x01,0x02,0x0a,0x03,0x01,0x01,0x0a,0x0b,0x0b,
	0x04,0x01,0x01,0x0a,0x02,0x0d,0x08,0x0b,0x06,0x0a,
	0x04,0x0b,0x08,0x0a,0x07,0x09,0x06,0x09,0x08,0x0a,
	0x07,0x09,0x08,0x08,0x07,0x01,0x01,0x08,0x08,0x09,
	0x07,0x08,0x05,0x01,0x02,0x08,0x01,0x01,0x07,0x09,
	0x07,0x07,0x04,0x01,0x01,0x02,0x01,0x08,0x08,0x0b,
	0x05,0x06,0x04,0x01,0x02,0x01,0x01,0x08,0x08,0x09,
	0x01,0x01,0x06,0x05,0x05,0x01,0x01,0x02,0x01,0x06,
	0x01,0x01,0x08,0x0b,0x05,0x06,0x05,0x01,0x01,0x02,
	0x01,0x08,0x01,0x01,0x06,0x08,0x01,0x02,0x05,0x01,
	0x01,0x03,0x06,0x01,0x01,0x02,0x01,0x08,0x01,0x01,
	0x06,0x01,0x01,0x09,0x05,0x01,0x01,0x04,0x05,0x01,
	0x02,0x01,0x01,0x06,0x01,0x02,0x07,0x0b,0x05,0x02,
	0x01,0x03,0x06,0x01,0x02,0x01,0x01,0x06,0x01,0x01,
	0x01,0x01,0x06,0x01,0x01,0x09,0x02,0x01,0x02,0x01,
	0x02,0x03,0x01,0x01,0x04,0x01,0x02,0x01,0x01,0x06,
	0x01,0x01,0x08,0x01,0x01,0x0d,0x01,0x01,0x03,0x02,
	0x01,0x01,0x05,0x01,0x02,0x01,0x01,0x06,0x01,0x01,
	0x01,0x01,0x08,0x02,0x01,0x08,0x01,0x01,0x03,0x01,
	0x0b,0x01,0x01,0x01,0x02,0x05,0x01,0x02,0x01,0x01,
	0x01,0x01,0x06,0x01,0x01,0x0c,0x02,0x01,0x0b,0x01,
	0x02,0x01,0x01,0x06,0x01,0x01,0x01,0x01,0x04,0x01,
	0x05,0x0d,0x01,0x02,0x0c,0x01,0x01,0x02,0x01,0x08,
	0x01,0x01,0x01,0x01,0x06,0x01,0x01,0x0f,0x0d,0x01,
	0x02,0x01,0x01,0x06,0x01,0x01,0x01,0x02,0x03,0x01,
	0x05,0x02,0x01,0x0c,0x01,0x01,0x0d,0x01,0x01,0x02,
	0x01,0x08,0x01,0x01,0x01,0x01,0x04,0x01,0x03,0x01,
	0x02,0x01,0x01,0x0d,0x0d,0x01,0x02,0x01,0x01,0x02,
	0x01,0x03,0x01,0x01,0x01,0x02,0x03,0x01,0x01,0x01,
	0x03,0x02,0x01,0x01,0x01,0x0c,0x02,0x01,0x0e,0x01,
	0x01,0x02,0x01,0x08,0x01,0x01,0x01,0x01,0x01,0x01,
	0x02,0x01,0x03,0x01,0x01,0x01,0x02,0x0e,0x0c,0x01,
	0x01,0x01,0x01,0x02,0x01,0x02,0x01,0x01,0x01,0x03,
	0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x02,
	0x03,0x01,0x01,0x01,0x01,0x0f,0x02,0x01,0x05,0x02,
	0x01,0x02,0x01,0x02,0x01,0x02,0x01,0x01,0x01,0x02,
	0x01,0x01,0x01,0x03,0x01,0x02,0x01,0x01,0x01,0x01,
	0x01,0x01,0x01,0x01,0x02,0x01,0x03,0x01,0x01,0x0f,
	0x01,0x02,0x01,0x02,0x01,0x02,0x02,0x01,0x01,0x06,
	0x01,0x01,0x02,0x02,0x01,0x01,0x01,0x02,0x01,0x05,
	0x01,0x04,0x01,0x01,0x01,0x01,0x05,0x01,0x01,0x12,
	0x02,0x11,0x06,0x01,0x01,0x02,0x01,0x0e,0x09,0x01,
	0x01,0x11,0x02,0x01,0x01,0x14,0x04,0x01,0x01,0x15,
	0x01,0x00,

/* Nine */
	0x01,0x01,0x01,0x3e,0x01,0x02,0x01,0x01,0x02,0x3d,
	0x07,0x3b,0x06,0x32,0x01,0x02,0x01,0x01,0x02,0x01,
	0x05,0x33,0x01,0x02,0x01,0x04,0x04,0x33,0x04,0x01,
	0x07,0x30,0x03,0x01,0x09,0x30,0x0b,0x01,0x01,0x12,
	0x01,0x1a,0x01,0x01,0x08,0x15,0x02,0x16,0x0d,0x0a,
	0x02,0x02,0x01,0x05,0x01,0x05,0x01,0x0e,0x0e,0x09,
	0x03,0x05,0x01,0x02,0x03,0x09,0x01,0x08,0x0d,0x05,
	0x02,0x04,0x01,0x05,0x02,0x02,0x03,0x10,0x0e,0x05,
	0x02,0x04,0x02,0x04,0x03,0x03,0x02,0x04,0x03,0x09,
	0x0d,0x04,0x03,0x04,0x02,0x03,0x03,0x04,0x02,0x04,
	0x03,0x04,0x01,0x04,0x03,0x01,0x08,0x05,0x03,0x03,
	0x02,0x04,0x03,0x03,0x03,0x04,0x02,0x05,0x01,0x03,
	0x04,0x01,0x07,0x05,0x03,0x04,0x01,0x04,0x03,0x04,
	0x02,0x04,0x03,0x04,0x01,0x04,0x03,0x01,0x06,0x05,
	0x03,0x04,0x02,0x04,0x02,0x04,0x02,0x04,0x04,0x04,
	0x01,0x03,0x09,0x05,0x03,0x04,0x02,0x03,0x03,0x04,
	0x03,0x04,0x02,0x04,0x02,0x03,0x09,0x05,0x02,0x04,
	0x02,0x04,0x03,0x03,0x03,0x04,0x03,0x07,0x0b,0x04,
	0x03,0x04,0x02,0x03,0x03,0x03,0x03,0x04,0x02,0x04,
	0x02,0x04,0x09,0x05,0x02,0x04,0x02,0x03,0x03,0x04,
	0x02,0x04,0x03,0x04,0x01,0x04,0x0a,0x04,0x03,0x03,
	0x02,0x03,0x03,0x04,0x02,0x0f,0x04,0x01,0x06,0x05,
	0x03,0x03,0x01,0x04,0x03,0x03,0x02,0x09,0x02,0x06,
	0x0a,0x04,0x03,0x02,0x02,0x04,0x02,0x04,0x02,0x09,
	0x01,0x08,0x09,0x06,0x01,0x02,0x01,0x0b,0x01,0x09,
	0x01,0x09,0x09,0x08,0x02,0x08,0x02,0x0d,0x01,0x08,
	0x08,0x08,0x02,0x08,0x01,0x02,0x02,0x08,0x01,0x04,
	0x01,0x04,0x09,0x08,0x02,0x01,0x02,0x08,0x02,0x0d,
	0x01,0x06,0x07,0x08,0x02,0x01,0x02,0x08,0x01,0x02,
	0x02,0x08,0x01,0x02,0x01,0x04,0x08,0x09,0x01,0x01,
	0x02,0x02,0x01,0x08,0x02,0x0b,0x01,0x04,0x09,0x02,
	0x01,0x07,0x02,0x02,0x01,0x08,0x02,0x01,0x02,0x0b,
	0x01,0x02,0x09,0x01,0x01,0x08,0x02,0x01,0x02,0x02,
	0x01,0x06,0x01,0x01,0x02,0x0e,0x09,0x0b,0x01,0x01,
	0x02,0x01,0x02,0x08,0x03,0x0d,0x09,0x01,0x01,0x09,
	0x01,0x01,0x02,0x02,0x01,0x08,0x01,0x02,0x01,0x0c,
	0x09,0x02,0x01,0x08,0x01,0x02,0x02,0x01,0x01,0x09,
	0x01,0x01,0x02,0x0b,0x0a,0x01,0x01,0x09,0x01,0x01,
	0x02,0x01,0x02,0x08,0x01,0x02,0x01,0x0e,0x09,0x01,
	0x01,0x02,0x01,0x05,0x01,0x02,0x01,0x02,0x01,0x02,
	0x01,0x06,0x01,0x01,0x02,0x0d,0x09,0x02,0x01,0x08,
	0x01,0x02,0x02,0x01,0x01,0x02,0x01,0x03,0x02,0x01,
	0x01,0x13,0x0d,0x10,0x04,0x01,0x01,0x14,0x0c,0x13,
	0x01,0x02,0x04,0x13,0x0b,0x14,0x01,0x01,0x06,0x10,
	0x0d,0x12,0x09,0x12,0x0c,0x12,0x08,0x01,0x01,0x16,
	0x0b,0x11,0x06,0x01,0x01,0x1b,0x0c,0x11,0x01,0x02,
	0x01,0x03,0x01,0x02,0x01,0x18,0x01,0x01,0x08,0x02,
	0x01,0x0b,0x02,0x01,0x02,0x01,0x01,0x06,0x01,0x02,
	0x01,0x19,0x0b,0x02,0x01,0x05,0x01,0x02,0x02,0x02,
	0x01,0x01,0x01,0x07,0x03,0x1c,0x01,0x01,0x0b,0x0b,
	0x03,0x08,0x02,0x01,0x04,0x1c,0x0e,0x08,0x02,0x01,
	0x03,0x08,0x04,0x02,0x01,0x09,0x02,0x12,0x03,0x02,
	0x09,0x08,0x04,0x02,0x01,0x08,0x04,0x22,0x01,0x02,
	0x0a,0x09,0x03,0x09,0x02,0x02,0x03,0x0a,0x01,0x0c,
	0x01,0x0c,0x0d,0x08,0x03,0x0a,0x02,0x02,0x02,0x0b,
	0x01,0x14,0x02,0x03,0x06,0x01,0x03,0x01,0x02,0x09,
	0x03,0x0a,0x02,0x02,0x03,0x0a,0x02,0x1a,0x04,0x04,
	0x05,0x09,0x02,0x0a,0x03,0x02,0x02,0x0b,0x02,0x10,
	0x01,0x0a,0x03,0x02,0x07,0x09,0x03,0x0a,0x02,0x03,
	0x02,0x0a,0x02,0x0f,0x02,0x0a,0x03,0x03,0x04,0x01,
	0x03,0x0a,0x03,0x03,0x01,0x06,0x01,0x03,0x03,0x0a,
	0x02,0x0f,0x02,0x0c,0x01,0x03,0x02,0x04,0x03,0x0a,
	0x03,0x03,0x01,0x0b,0x03,0x0a,0x01,0x10,0x01,0x10,
	0x02,0x09,0x01,0x0a,0x02,0x03,0x03,0x0a,0x03,0x0a,
	0x01,0x03,0x01,0x0c,0x01,0x0d,0x01,0x0e,0x01,0x0a,
	0x03,0x02,0x03,0x0a,0x03,0x0a,0x01,0x04,0x01,0x1c,
	0x02,0x0b,0x01,0x0b,0x02,0x03,0x02,0x0b,0x02,0x0f,
	0x02,0x36,0x02,0x03,0x02,0x0b,0x02,0x0f,0x02,0x39,
	0x02,0x03,0x02,0x0b,0x02,0x0f,0x01,0x40,0x01,0x00,

/* Alpha */
	0x03,0x0a,0x02,0x08,0x02,0x08,0x04,0x1a,0x04,0x04,
	0x05,0x05,0x01,0x02,0x01,0x02,0x01,0x03,0x04,0x08,
	0x03,0x09,0x02,0x08,0x01,0x06,0x04,0x04,0x02,0x05,
	0x02,0x04,0x01,0x03,0x04,0x08,0x03,0x09,0x02,0x04,
	0x04,0x06,0x04,0x01,0x03,0x05,0x02,0x04,0x01,0x04,
	0x03,0x05,0x01,0x03,0x03,0x05,0x01,0x09,0x03,0x04,
	0x09,0x05,0x02,0x04,0x01,0x04,0x04,0x04,0x02,0x03,
	0x02,0x05,0x03,0x06,0x05,0x04,0x06,0x05,0x04,0x08,
	0x03,0x04,0x04,0x01,0x03,0x04,0x04,0x04,0x06,0x04,
	0x05,0x04,0x05,0x02,0x01,0x04,0x04,0x04,0x03,0x03,
	0x02,0x04,0x04,0x04,0x07,0x02,0x05,0x05,0x03,0x03,
	0x02,0x04,0x04,0x04,0x03,0x09,0x03,0x04,0x04,0x03,
	0x06,0x04,0x04,0x09,0x05,0x04,0x02,0x0a,0x02,0x04,
	0x05,0x02,0x04,0x05,0x04,0x04,0x02,0x03,0x04,0x04,
	0x04,0x09,0x03,0x03,0x09,0x05,0x04,0x05,0x02,0x03,
	0x04,0x05,0x03,0x05,0x01,0x04,0x02,0x02,0x08,0x05,
	0x05,0x09,0x05,0x05,0x04,0x05,0x04,0x03,0x07,0x06,
	0x04,0x09,0x06,0x05,0x03,0x06,0x04,0x03,0x06,0x06,
	0x04,0x0a,0x04,0x06,0x04,0x04,0x04,0x03,0x07,0x05,
	0x04,0x0a,0x05,0x05,0x04,0x05,0x04,0x03,0x06,0x05,
	0x06,0x09,0x05,0x05,0x04,0x04,0x04,0x04,0x06,0x05,
	0x05,0x0a,0x05,0x05,0x04,0x04,0x04,0x04,0x05,0x06,
	0x05,0x0a,0x05,0x05,0x04,0x04,0x04,0x03,0x06,0x05,
	0x05,0x0b,0x05,0x05,0x03,0x04,0x04,0x03,0x06,0x06,
	0x06,0x0a,0x05,0x05,0x03,0x03,0x05,0x03,0x06,0x06,
	0x06,0x0a,0x05,0x0a,0x05,0x05,0x06,0x06,0x07,0x0a,
	0x05,0x0a,0x0c,0x07,0x05,0x03,0x01,0x08,0x09,0x06,
	0x05,0x0d,0x07,0x0f,0x01,0x1e,0x06,0x64,0x01,0x83,
	0x87,0x06,0x0c,0x03,0x1d,0x04,0x03,0x09,0x0b,0x05,
	0x0a,0x04,0x0b,0x04,0x0a,0x0d,0x08,0x01,0x02,0x04,
	0x0b,0x04,0x0b,0x02,0x0c,0x04,0x06,0x09,0x07,0x02,
	0x01,0x05,0x07,0x07,0x07,0x07,0x07,0x08,0x06,0x02,
	0x02,0x03,0x04,0x06,0x07,0x01,0x02,0x04,0x06,0x01,
	0x01,0x02,0x01,0x03,0x07,0x01,0x02,0x04,0x07,0x02,
	0x04,0x01,0x06,0x01,0x05,0x02,0x04,0x09,0x07,0x02,
	0x01,0x04,0x05,0x04,0x02,0x02,0x07,0x04,0x09,0x03,
	0x0b,0x02,0x0b,0x04,0x01,0x06,0x08,0x02,0x01,0x02,
	0x01,0x01,0x05,0x04,0x02,0x02,0x07,0x02,0x0a,0x04,
	0x0b,0x02,0x0b,0x03,0x05,0x01,0x03,0x02,0x07,0x02,
	0x02,0x01,0x01,0x02,0x05,0x04,0x02,0x01,0x07,0x03,
	0x0a,0x04,0x0a,0x03,0x0b,0x03,0x09,0x03,0x05,0x01,
	0x02,0x01,0x02,0x04,0x05,0x04,0x02,0x01,0x07,0x03,
	0x0a,0x03,0x0b,0x02,0x0b,0x03,0x0a,0x04,0x09,0x02,
	0x01,0x02,0x01,0x01,0x06,0x04,0x02,0x01,0x07,0x02,
	0x0b,0x03,0x0a,0x03,0x0b,0x01,0x0d,0x02,0x0d,0x01,
	0x0b,0x02,0x01,0x01,0x02,0x01,0x06,0x03,0x0b,0x02,
	0x0c,0x01,0x2e,0x01,0x0b,0x02,0x60,0x01,0x08,0x01,
	0x00,

/* Bravo */
	0x04,0x04,0x0b,0x0b,0x08,0x18,0x09,0x02,0x07,0x0b,
	0x07,0x0d,0x02,0x09,0x08,0x05,0x07,0x0b,0x07,0x0c,
	0x03,0x08,0x08,0x06,0x07,0x0a,0x06,0x07,0x02,0x03,
	0x03,0x08,0x09,0x04,0x08,0x07,0x09,0x06,0x05,0x0a,
	0x09,0x05,0x08,0x06,0x09,0x06,0x05,0x0a,0x03,0x02,
	0x04,0x05,0x08,0x06,0x09,0x05,0x05,0x09,0x04,0x04,
	0x03,0x03,0x0a,0x05,0x05,0x02,0x02,0x05,0x05,0x0a,
	0x03,0x03,0x04,0x03,0x0a,0x05,0x05,0x03,0x02,0x04,
	0x05,0x06,0x01,0x09,0x04,0x03,0x0a,0x05,0x04,0x05,
	0x01,0x04,0x04,0x05,0x03,0x09,0x03,0x03,0x06,0x01,
	0x03,0x05,0x04,0x04,0x02,0x04,0x04,0x05,0x03,0x05,
	0x02,0x08,0x05,0x02,0x03,0x05,0x04,0x04,0x03,0x03,
	0x04,0x05,0x03,0x04,0x04,0x07,0x04,0x03,0x03,0x05,
	0x04,0x03,0x03,0x03,0x04,0x05,0x03,0x05,0x03,0x06,
	0x06,0x02,0x03,0x05,0x04,0x04,0x03,0x03,0x04,0x04,
	0x03,0x05,0x03,0x07,0x05,0x02,0x03,0x05,0x04,0x03,
	0x04,0x03,0x04,0x04,0x03,0x05,0x02,0x07,0x05,0x03,
	0x03,0x05,0x04,0x03,0x03,0x03,0x04,0x04,0x04,0x04,
	0x03,0x06,0x06,0x02,0x04,0x04,0x04,0x04,0x03,0x02,
	0x05,0x04,0x03,0x04,0x04,0x06,0x06,0x01,0x03,0x05,
	0x04,0x04,0x03,0x03,0x03,0x05,0x03,0x04,0x04,0x05,
	0x06,0x02,0x03,0x05,0x04,0x04,0x03,0x02,0x04,0x05,
	0x03,0x04,0x03,0x07,0x05,0x02,0x03,0x04,0x04,0x05,
	0x02,0x03,0x04,0x04,0x04,0x04,0x03,0x07,0x05,0x02,
	0x03,0x04,0x04,0x04,0x03,0x03,0x04,0x04,0x03,0x05,
	0x03,0x07,0x04,0x03,0x03,0x04,0x04,0x04,0x02,0x04,
	0x04,0x04,0x03,0x04,0x03,0x08,0x04,0x03,0x02,0x05,
	0x04,0x04,0x02,0x04,0x03,0x04,0x04,0x04,0x02,0x03,
	0x02,0x04,0x04,0x03,0x02,0x05,0x04,0x04,0x02,0x03,
	0x04,0x04,0x04,0x04,0x02,0x03,0x02,0x04,0x05,0x01,
	0x04,0x04,0x04,0x04,0x02,0x03,0x04,0x04,0x04,0x03,
	0x03,0x03,0x03,0x03,0x09,0x05,0x04,0x04,0x01,0x04,
	0x04,0x04,0x03,0x04,0x02,0x04,0x03,0x03,0x08,0x05,
	0x04,0x0a,0x04,0x0a,0x03,0x05,0x01,0x03,0x09,0x05,
	0x04,0x02,0x01,0x07,0x05,0x08,0x05,0x08,0x08,0x06,
	0x04,0x02,0x03,0x05,0x06,0x01,0x01,0x07,0x03,0x09,
	0x08,0x07,0x01,0x03,0x05,0x06,0x03,0x02,0x04,0x0b,
	0x05,0x01,0x0a,0x0c,0x03,0x04,0x04,0x15,0x01,0x02,
	0x01,0x02,0x09,0x13,0x02,0x01,0x01,0x22,0x06,0x38,
	0x09,0x3e,0x03,0x3e,0x01,0x01,0x05,0x45,0x01,0x42,
	0x01,0x01,0x05,0x3e,0x0a,0x0d,0x02,0x0e,0x01,0x0f,
	0x01,0x04,0x01,0x06,0x01,0x01,0x08,0x0b,0x06,0x0b,
	0x04,0x0b,0x05,0x08,0x09,0x0a,0x07,0x09,0x06,0x09,
	0x07,0x08,0x0a,0x07,0x03,0x01,0x05,0x07,0x08,0x07,
	0x03,0x01,0x01,0x01,0x03,0x07,0x02,0x01,0x05,0x04,
	0x04,0x08,0x01,0x02,0x05,0x07,0x01,0x02,0x05,0x07,
	0x02,0x01,0x02,0x01,0x02,0x07,0x02,0x01,0x05,0x05,
	0x07,0x07,0x02,0x01,0x05,0x08,0x07,0x07,0x05,0x0a,
	0x03,0x01,0x01,0x03,0x01,0x04,0x0a,0x07,0x03,0x01,
	0x01,0x02,0x01,0x07,0x03,0x01,0x01,0x09,0x04,0x0b,
	0x04,0x05,0x01,0x01,0x02,0x01,0x05,0x04,0x03,0x07,
	0x02,0x02,0x01,0x01,0x02,0x07,0x03,0x01,0x01,0x02,
	0x01,0x07,0x03,0x0c,0x03,0x05,0x03,0x03,0x01,0x01,
	0x02,0x04,0x05,0x07,0x01,0x02,0x02,0x01,0x02,0x07,
	0x02,0x04,0x02,0x06,0x04,0x0c,0x03,0x06,0x02,0x02,
	0x04,0x05,0x06,0x07,0x02,0x01,0x02,0x01,0x02,0x07,
	0x05,0x0a,0x05,0x0b,0x01,0x08,0x01,0x02,0x01,0x01,
	0x02,0x07,0x05,0x07,0x02,0x01,0x01,0x02,0x02,0x07,
	0x05,0x0a,0x05,0x0a,0x04,0x06,0x01,0x05,0x04,0x05,
	0x04,0x08,0x01,0x02,0x01,0x01,0x02,0x08,0x02,0x01,
	0x01,0x02,0x01,0x08,0x05,0x0a,0x05,0x0b,0x04,0x05,
	0x01,0x01,0x03,0x07,0x02,0x01,0x02,0x01,0x02,0x08,
	0x01,0x01,0x02,0x02,0x01,0x08,0x05,0x0a,0x04,0x0b,
	0x02,0x01,0x02,0x07,0x04,0x08,0x01,0x01,0x02,0x01,
	0x02,0x08,0x05,0x01,0x01,0x08,0x05,0x0b,0x04,0x0b,
	0x05,0x07,0x01,0x01,0x02,0x08,0x01,0x02,0x02,0x01,
	0x02,0x01,0x01,0x06,0x01,0x01,0x02,0x01,0x02,0x0a,
	0x02,0x01,0x02,0x0a,0x05,0x08,0x01,0x02,0x04,0x08,
	0x03,0x0b,0x01,0x01,0x05,0x08,0x01,0x02,0x01,0x02,
	0x01,0x08,0x05,0x0b,0x04,0x0e,0x01,0x08,0x02,0x01,
	0x01,0x0b,0x01,0x01,0x05,0x08,0x02,0x01,0x02,0x01,
	0x01,0x09,0x01,0x01,0x02,0x0d,0x03,0x0d,0x04,0x08,
	0x01,0x0c,0x01,0x01,0x02,0x01,0x02,0x08,0x01,0x02,
	0x01,0x0e,0x02,0x0e,0x01,0x01,0x02,0x17,0x01,0x0b,
	0x02,0x01,0x02,0x01,0x02,0x0b,0x01,0x0f,0x01,0x01,
	0x01,0x0f,0x01,0x02,0x01,0x22,0x01,0x01,0x05,0x0b,
	0x01,0x01,0x02,0x46,0x04,0x01,0x01,0x0e,0x02,0x00,

/* Charlie */
	0x01,0x0b,0x01,0x02,0x01,0x01,0x01,0x13,0x01,0x02,
	0x01,0x07,0x01,0x03,0x01,0x03,0x01,0x04,0x01,0x05,
	0x01,0x04,0x01,0x0a,0x01,0x07,0x01,0x01,0x01,0x02,
	0x01,0x07,0x01,0x10,0x01,0x06,0x01,0x01,0x01,0x04,
	0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x02,
	0x01,0x01,0x01,0x01,0x01,0x02,0x01,0x04,0x01,0x03,
	0x01,0x0b,0x02,0x02,0x01,0x08,0x01,0x02,0x01,0x02,
	0x01,0x05,0x01,0x08,0x01,0x05,0x01,0x01,0x01,0x01,
	0x01,0x02,0x01,0x06,0x01,0x01,0x01,0x04,0x01,0x01,
	0x01,0x02,0x01,0x01,0x01,0x02,0x01,0x01,0x01,0x01,
	0x01,0x01,0x01,0x04,0x01,0x01,0x01,0x0a,0x01,0x0a,
	0x01,0x01,0x01,0x01,0x01,0x04,0x01,0x06,0x01,0x07,
	0x01,0x03,0x01,0x01,0x02,0x02,0x01,0x08,0x01,0x01,
	0x01,0x06,0x01,0x01,0x02,0x01,0x01,0x03,0x01,0x08,
	0x01,0x01,0x01,0x02,0x01,0x01,0x01,0x03,0x01,0x06,
	0x01,0x1b,0x01,0x11,0x01,0x21,0x01,0x01,0x01,0x05,
	0x01,0x09,0x01,0x01,0x01,0x10,0x04,0x07,0x0e,0x10,
	0x02,0x09,0x04,0x05,0x0c,0x0b,0x03,0x0a,0x04,0x09,
	0x0a,0x0a,0x04,0x06,0x03,0x02,0x02,0x03,0x02,0x04,
	0x0a,0x05,0x03,0x04,0x03,0x04,0x04,0x03,0x03,0x03,
	0x03,0x03,0x05,0x01,0x04,0x05,0x03,0x03,0x03,0x04,
	0x04,0x04,0x03,0x04,0x02,0x03,0x08,0x06,0x03,0x03,
	0x03,0x05,0x04,0x04,0x04,0x05,0x05,0x03,0x04,0x05,
	0x04,0x03,0x03,0x04,0x04,0x05,0x04,0x05,0x05,0x03,
	0x04,0x05,0x04,0x03,0x02,0x05,0x04,0x05,0x04,0x05,
	0x05,0x03,0x04,0x04,0x04,0x04,0x02,0x05,0x04,0x05,
	0x04,0x05,0x05,0x02,0x04,0x05,0x04,0x04,0x03,0x04,
	0x04,0x05,0x04,0x05,0x05,0x02,0x04,0x05,0x04,0x04,
	0x02,0x04,0x05,0x04,0x04,0x05,0x05,0x02,0x04,0x05,
	0x04,0x05,0x02,0x04,0x04,0x05,0x04,0x04,0x06,0x01,
	0x04,0x05,0x04,0x04,0x03,0x04,0x04,0x05,0x04,0x04,
	0x05,0x02,0x04,0x05,0x04,0x04,0x02,0x04,0x05,0x05,
	0x03,0x05,0x05,0x01,0x04,0x05,0x04,0x04,0x03,0x04,
	0x04,0x05,0x03,0x05,0x04,0x02,0x05,0x05,0x04,0x03,
	0x03,0x04,0x04,0x05,0x03,0x05,0x05,0x01,0x05,0x04,
	0x05,0x03,0x03,0x04,0x04,0x05,0x04,0x04,0x0b,0x05,
	0x04,0x03,0x03,0x04,0x04,0x05,0x04,0x05,0x0a,0x05,
	0x04,0x03,0x03,0x04,0x04,0x06,0x03,0x05,0x0b,0x05,
	0x04,0x03,0x02,0x05,0x04,0x05,0x04,0x06,0x0a,0x05,
	0x04,0x02,0x03,0x05,0x04,0x06,0x01,0x02,0x02,0x04,
	0x05,0x01,0x04,0x05,0x03,0x03,0x03,0x05,0x04,0x09,
	0x03,0x04,0x04,0x02,0x03,0x05,0x04,0x02,0x03,0x05,
	0x04,0x03,0x01,0x05,0x03,0x04,0x04,0x02,0x04,0x04,
	0x04,0x03,0x03,0x04,0x04,0x03,0x02,0x05,0x03,0x03,
	0x04,0x03,0x04,0x04,0x03,0x03,0x03,0x05,0x04,0x02,
	0x03,0x04,0x03,0x04,0x04,0x02,0x04,0x05,0x02,0x03,
	0x04,0x04,0x04,0x02,0x04,0x04,0x03,0x04,0x03,0x03,
	0x05,0x04,0x02,0x03,0x04,0x05,0x02,0x03,0x04,0x04,
	0x03,0x03,0x04,0x03,0x05,0x05,0x02,0x02,0x05,0x05,
	0x02,0x02,0x04,0x05,0x03,0x03,0x04,0x02,0x07,0x05,
	0x02,0x02,0x04,0x05,0x02,0x02,0x05,0x04,0x03,0x03,
	0x03,0x03,0x07,0x05,0x02,0x03,0x04,0x04,0x02,0x02,
	0x05,0x05,0x02,0x04,0x03,0x02,0x08,0x05,0x03,0x02,
	0x04,0x04,0x02,0x03,0x04,0x05,0x01,0x05,0x03,0x02,
	0x09,0x05,0x01,0x04,0x04,0x09,0x04,0x0b,0x04,0x02,
	0x08,0x0b,0x04,0x0a,0x04,0x0c,0x0c,0x0c,0x04,0x0b,
	0x04,0x0b,0x0d,0x0c,0x05,0x0b,0x04,0x0b,0x0d,0x0c,
	0x07,0x0b,0x03,0x0b,0x0e,0x0c,0x07,0x18,0x0a,0x01,
	0x04,0x0e,0x07,0x1b,0x05,0x01,0x07,0x0c,0x09,0x1d,
	0x01,0x01,0x09,0x0f,0x06,0x24,0x07,0x0e,0x01,0x01,
	0x01,0x01,0x02,0x01,0x01,0x01,0x01,0x1c,0x02,0x04,
	0x06,0x0e,0x01,0x01,0x04,0x0d,0x01,0x0d,0x01,0x0c,
	0x07,0x0b,0x04,0x01,0x01,0x02,0x01,0x06,0x06,0x01,
	0x01,0x0a,0x04,0x09,0x0b,0x09,0x06,0x01,0x01,0x07,
	0x06,0x01,0x01,0x09,0x05,0x01,0x01,0x08,0x0c,0x0b,
	0x02,0x01,0x02,0x01,0x01,0x09,0x04,0x01,0x01,0x0a,
	0x05,0x0a,0x0d,0x0a,0x06,0x01,0x01,0x08,0x02,0x01,
	0x02,0x01,0x01,0x0a,0x06,0x09,0x0d,0x08,0x01,0x02,
	0x05,0x01,0x01,0x09,0x01,0x01,0x02,0x01,0x01,0x0b,
	0x07,0x08,0x01,0x01,0x08,0x01,0x03,0x02,0x01,0x08,
	0x01,0x01,0x05,0x02,0x01,0x08,0x02,0x01,0x01,0x01,
	0x02,0x0a,0x07,0x0a,0x07,0x01,0x03,0x03,0x01,0x08,
	0x01,0x02,0x04,0x02,0x01,0x0b,0x01,0x02,0x01,0x0d,
	0x05,0x0c,0x01,0x02,0x01,0x04,0x02,0x01,0x01,0x02,
	0x01,0x08,0x01,0x02,0x02,0x01,0x02,0x01,0x02,0x0d,
	0x02,0x01,0x01,0x0f,0x05,0x0f,0x03,0x01,0x01,0x02,
	0x01,0x0c,0x01,0x01,0x02,0x02,0x02,0x01,0x01,0x0e,
	0x01,0x02,0x01,0x11,0x02,0x2a,0x01,0x01,0x02,0x01,
	0x02,0x53,0x02,0x01,0x02,0x28,0x01,0x2d,0x01,0x01,
	0x02,0x29,0x01,0x30,0x01,0x02,0x01,0x80,0xc8,0x01,
	0x00,

/* Delta */
	0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0a,0x01,0x03,
	0x01,0x08,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x14,
	0x01,0x1b,0x01,0x01,0x01,0x01,0x01,0x02,0x01,0x01,
	0x03,0x01,0x09,0x10,0x07,0x11,0x01,0x02,0x03,0x01,
	0x0d,0x0e,0x09,0x0b,0x07,0x02,0x01,0x04,0x09,0x0c,
	0x09,0x09,0x08,0x07,0x0a,0x0b,0x08,0x09,0x06,0x08,
	0x0b,0x08,0x08,0x09,0x08,0x07,0x0b,0x08,0x08,0x07,
	0x07,0x09,0x0d,0x08,0x07,0x08,0x07,0x07,0x0f,0x04,
	0x01,0x02,0x08,0x07,0x06,0x07,0x10,0x06,0x01,0x01,
	0x05,0x07,0x08,0x07,0x04,0x02,0x09,0x08,0x04,0x08,
	0x08,0x06,0x01,0x01,0x04,0x02,0x07,0x07,0x01,0x01,
	0x04,0x08,0x04,0x09,0x03,0x03,0x09,0x07,0x01,0x01,
	0x04,0x08,0x05,0x09,0x02,0x04,0x09,0x04,0x01,0x04,
	0x04,0x06,0x01,0x01,0x04,0x0a,0x03,0x03,0x09,0x04,
	0x01,0x01,0x07,0x05,0x08,0x05,0x01,0x04,0x03,0x03,
	0x08,0x06,0x08,0x05,0x08,0x06,0x04,0x06,0x07,0x06,
	0x08,0x05,0x09,0x05,0x04,0x04,0x0a,0x06,0x08,0x05,
	0x09,0x05,0x04,0x04,0x0a,0x06,0x04,0x01,0x04,0x04,
	0x06,0x01,0x01,0x07,0x03,0x03,0x0b,0x05,0x04,0x01,
	0x05,0x05,0x05,0x09,0x04,0x03,0x0a,0x06,0x04,0x01,
	0x05,0x05,0x05,0x0a,0x03,0x02,0x0a,0x08,0x08,0x06,
	0x05,0x0b,0x0e,0x08,0x09,0x06,0x05,0x0b,0x0e,0x08,
	0x08,0x07,0x04,0x03,0x01,0x09,0x0d,0x08,0x09,0x0d,
	0x03,0x08,0x01,0x01,0x0a,0x0e,0x05,0x0c,0x04,0x0a,
	0x0b,0x0f,0x05,0x0b,0x03,0x0b,0x0e,0x2e,0x01,0x01,
	0x01,0x32,0x01,0x01,0x01,0x30,0x01,0x82,0xb1,0x01,
	0x14,0x01,0x1e,0x01,0x01,0x01,0x1d,0x01,0x3a,0x01,
	0x08,0x01,0x01,0x09,0x0e,0x08,0x0e,0x04,0x05,0x0c,
	0x0b,0x07,0x09,0x05,0x0b,0x07,0x06,0x07,0x09,0x08,
	0x08,0x05,0x09,0x07,0x08,0x0b,0x08,0x01,0x01,0x04,
	0x09,0x02,0x01,0x04,0x0a,0x02,0x04,0x01,0x05,0x01,
	0x03,0x03,0x02,0x0a,0x05,0x01,0x02,0x01,0x01,0x04,
	0x08,0x07,0x08,0x04,0x0a,0x01,0x04,0x02,0x08,0x08,
	0x04,0x01,0x02,0x01,0x01,0x04,0x08,0x05,0x01,0x01,
	0x06,0x02,0x01,0x03,0x0a,0x02,0x0a,0x04,0x01,0x07,
	0x04,0x01,0x02,0x01,0x02,0x02,0x09,0x05,0x02,0x01,
	0x06,0x02,0x02,0x02,0x07,0x01,0x02,0x01,0x0a,0x05,
	0x04,0x01,0x02,0x04,0x07,0x01,0x01,0x04,0x08,0x05,
	0x08,0x04,0x02,0x01,0x06,0x02,0x0a,0x01,0x04,0x02,
	0x04,0x04,0x02,0x06,0x04,0x01,0x02,0x01,0x01,0x02,
	0x01,0x01,0x08,0x03,0x0a,0x03,0x09,0x03,0x0a,0x03,
	0x08,0x04,0x04,0x01,0x03,0x04,0x04,0x01,0x02,0x01,
	0x01,0x04,0x08,0x04,0x09,0x03,0x0a,0x03,0x09,0x03,
	0x09,0x03,0x04,0x02,0x04,0x03,0x05,0x01,0x02,0x01,
	0x01,0x04,0x08,0x04,0x09,0x03,0x09,0x04,0x0a,0x02,
	0x0a,0x02,0x04,0x01,0x06,0x02,0x01,0x01,0x05,0x01,
	0x02,0x01,0x01,0x02,0x08,0x01,0x01,0x04,0x09,0x03,
	0x09,0x04,0x0a,0x02,0x0b,0x01,0x0b,0x05,0x05,0x01,
	0x02,0x01,0x01,0x02,0x01,0x01,0x06,0x01,0x02,0x03,
	0x0a,0x03,0x0a,0x02,0x23,0x04,0x07,0x01,0x01,0x02,
	0x01,0x01,0x01,0x02,0x04,0x01,0x01,0x01,0x02,0x03,
	0x0b,0x02,0x06,0x01,0x29,0x02,0x05,0x01,0x05,0x01,
	0x01,0x01,0x02,0x01,0x01,0x01,0x06,0x02,0x01,0x01,
	0x01,0x01,0x06,0x01,0x05,0x01,0x06,0x01,0x4f,0x01,
	0x26,0x01,0x00,

/* Echo */
	0x03,0x05,0x01,0x01,0x02,0x11,0x01,0x01,0x03,0x09,
	0x02,0x0b,0x01,0x08,0x08,0x05,0x01,0x02,0x02,0x02,
	0x01,0x05,0x05,0x08,0x01,0x08,0x0a,0x04,0x02,0x01,
	0x03,0x07,0x02,0x01,0x02,0x08,0x01,0x08,0x09,0x05,
	0x01,0x02,0x02,0x07,0x06,0x07,0x02,0x05,0x01,0x01,
	0x02,0x01,0x07,0x05,0x01,0x01,0x02,0x08,0x02,0x01,
	0x02,0x08,0x01,0x05,0x01,0x02,0x09,0x05,0x01,0x01,
	0x03,0x07,0x05,0x08,0x01,0x01,0x01,0x06,0x08,0x05,
	0x01,0x01,0x03,0x07,0x06,0x07,0x03,0x06,0x08,0x07,
	0x04,0x07,0x05,0x07,0x03,0x02,0x01,0x02,0x0a,0x07,
	0x04,0x01,0x01,0x05,0x05,0x07,0x05,0x02,0x04,0x01,
	0x06,0x07,0x06,0x07,0x04,0x06,0x03,0x02,0x01,0x01,
	0x0b,0x08,0x06,0x07,0x05,0x05,0x02,0x02,0x09,0x01,
	0x04,0x0a,0x05,0x09,0x02,0x01,0x05,0x06,0x0c,0x0b,
	0x02,0x0c,0x07,0x09,0x02,0x02,0x06,0x16,0x01,0x05,
	0x01,0x83,0x08,0x02,0x04,0x01,0x3b,0x01,0x08,0x01,
	0x09,0x01,0x03,0x03,0x02,0x03,0x0b,0x03,0x02,0x03,
	0x0a,0x02,0x0e,0x04,0x09,0x0b,0x0d,0x07,0x0c,0x01,
	0x01,0x01,0x06,0x0b,0x0b,0x07,0x09,0x04,0x0b,0x0e,
	0x0a,0x05,0x08,0x05,0x01,0x01,0x0b,0x10,0x09,0x06,
	0x08,0x05,0x09,0x03,0x02,0x04,0x04,0x09,0x09,0x06,
	0x08,0x05,0x09,0x04,0x04,0x02,0x03,0x0b,0x04,0x01,
	0x01,0x02,0x01,0x05,0x05,0x02,0x01,0x05,0x05,0x01,
	0x01,0x01,0x02,0x03,0x06,0x02,0x02,0x06,0x01,0x05,
	0x04,0x01,0x01,0x02,0x01,0x05,0x05,0x02,0x01,0x04,
	0x06,0x03,0x04,0x01,0x05,0x04,0x03,0x04,0x01,0x06,
	0x07,0x01,0x02,0x04,0x05,0x05,0x01,0x02,0x06,0x03,
	0x01,0x01,0x08,0x03,0x04,0x03,0x03,0x06,0x07,0x07,
	0x06,0x04,0x01,0x02,0x06,0x05,0x08,0x04,0x08,0x09,
	0x06,0x08,0x05,0x05,0x01,0x01,0x01,0x01,0x05,0x05,
	0x08,0x04,0x05,0x01,0x02,0x09,0x07,0x02,0x01,0x05,
	0x05,0x04,0x04,0x01,0x05,0x04,0x09,0x04,0x04,0x03,
	0x02,0x09,0x06,0x08,0x06,0x04,0x01,0x01,0x01,0x01,
	0x06,0x04,0x09,0x04,0x04,0x02,0x04,0x08,0x06,0x08,
	0x06,0x04,0x01,0x01,0x01,0x01,0x07,0x04,0x09,0x04,
	0x05,0x03,0x01,0x09,0x07,0x07,0x06,0x06,0x09,0x04,
	0x09,0x04,0x05,0x04,0x02,0x07,0x07,0x08,0x06,0x04,
	0x01,0x01,0x09,0x04,0x0a,0x03,0x05,0x04,0x03,0x06,
	0x07,0x08,0x06,0x06,0x09,0x05,0x09,0x04,0x06,0x02,
	0x03,0x08,0x06,0x08,0x06,0x06,0x09,0x05,0x0a,0x04,
	0x05,0x04,0x01,0x09,0x07,0x05,0x01,0x02,0x07,0x05,
	0x0a,0x05,0x0a,0x04,0x05,0x0e,0x06,0x05,0x02,0x01,
	0x08,0x04,0x0b,0x05,0x0b,0x04,0x06,0x03,0x02,0x08,
	0x07,0x02,0x01,0x02,0x01,0x02,0x08,0x04,0x0b,0x05,
	0x0c,0x04,0x06,0x01,0x01,0x02,0x01,0x07,0x08,0x04,
	0x01,0x04,0x07,0x06,0x0b,0x04,0x0b,0x05,0x07,0x0b,
	0x07,0x0a,0x07,0x06,0x0b,0x05,0x0b,0x06,0x06,0x0a,
	0x07,0x0b,0x07,0x06,0x0b,0x06,0x0a,0x07,0x07,0x08,
	0x09,0x08,0x09,0x06,0x0c,0x05,0x09,0x08,0x08,0x07,
	0x0a,0x08,0x0a,0x06,0x0c,0x05,0x08,0x01,0x01,0x07,
	0x08,0x07,0x0a,0x08,0x0a,0x06,0x0c,0x04,0x0c,0x03,
	0x0d,0x07,0x0b,0x07,0x0b,0x05,0x1e,0x06,0x0c,0x01,
	0x01,0x03,0x0b,0x05,0x01,0x01,0x0c,0x04,0x1d,0x01,
	0x01,0x01,0x01,0x01,0x81,0x4d,0x01,0x00,

/* Foxtrot */
	0x06,0x1a,0x0c,0x09,0x05,0x06,0x02,0x01,0x05,0x05,
	0x01,0x03,0x04,0x02,0x0a,0x05,0x04,0x01,0x04,0x04,
	0x04,0x0a,0x02,0x04,0x03,0x03,0x09,0x04,0x04,0x02,
	0x03,0x04,0x05,0x09,0x03,0x04,0x03,0x03,0x09,0x05,
	0x04,0x09,0x04,0x04,0x02,0x03,0x03,0x04,0x03,0x04,
	0x09,0x05,0x04,0x04,0x01,0x03,0x04,0x05,0x03,0x04,
	0x01,0x03,0x03,0x04,0x05,0x02,0x03,0x05,0x04,0x03,
	0x03,0x02,0x04,0x04,0x04,0x04,0x04,0x01,0x02,0x04,
	0x04,0x03,0x03,0x05,0x03,0x04,0x03,0x03,0x03,0x04,
	0x03,0x05,0x04,0x06,0x04,0x04,0x04,0x03,0x04,0x03,
	0x04,0x02,0x04,0x04,0x03,0x05,0x01,0x01,0x03,0x05,
	0x04,0x03,0x04,0x04,0x04,0x03,0x04,0x02,0x04,0x03,
	0x04,0x04,0x01,0x02,0x03,0x04,0x04,0x04,0x04,0x04,
	0x04,0x03,0x03,0x03,0x04,0x03,0x03,0x06,0x01,0x01,
	0x03,0x04,0x04,0x03,0x05,0x04,0x04,0x02,0x04,0x02,
	0x04,0x04,0x03,0x05,0x05,0x04,0x05,0x02,0x05,0x04,
	0x04,0x03,0x03,0x03,0x03,0x04,0x03,0x05,0x01,0x02,
	0x03,0x04,0x04,0x03,0x04,0x04,0x04,0x03,0x02,0x04,
	0x03,0x03,0x04,0x04,0x02,0x02,0x03,0x04,0x04,0x03,
	0x04,0x04,0x04,0x03,0x02,0x04,0x04,0x02,0x04,0x03,
	0x03,0x03,0x03,0x04,0x04,0x01,0x05,0x04,0x03,0x04,
	0x02,0x04,0x03,0x03,0x03,0x04,0x02,0x04,0x03,0x04,
	0x04,0x01,0x05,0x05,0x03,0x03,0x02,0x05,0x03,0x03,
	0x02,0x05,0x02,0x03,0x03,0x05,0x03,0x02,0x05,0x01,
	0x01,0x06,0x01,0x04,0x03,0x04,0x02,0x04,0x03,0x04,
	0x02,0x05,0x02,0x04,0x01,0x05,0x01,0x05,0x01,0x4b,
	0x01,0x82,0x4f,0x02,0x0a,0x01,0x03,0x02,0x2f,0x01,
	0x15,0x01,0x16,0x01,0x0c,0x01,0x01,0x01,0x07,0x03,
	0x01,0x01,0x0c,0x01,0x02,0x02,0x01,0x01,0x0a,0x01,
	0x01,0x02,0x05,0x01,0x01,0x01,0x02,0x01,0x0a,0x01,
	0x01,0x03,0x03,0x01,0x01,0x01,0x05,0x01,0x03,0x01,
	0x01,0x01,0x08,0x01,0x01,0x01,0x01,0x01,0x05,0x02,
	0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x04,0x01,
	0x09,0x01,0x01,0x01,0x02,0x01,0x08,0x01,0x05,0x01,
	0x01,0x01,0x0a,0x01,0x01,0x01,0x01,0x01,0x03,0x01,
	0x03,0x01,0x02,0x01,0x05,0x01,0x01,0x01,0x02,0x01,
	0x05,0x01,0x03,0x01,0x02,0x01,0x08,0x02,0x01,0x01,
	0x02,0x02,0x01,0x01,0x06,0x02,0x07,0x01,0x01,0x01,
	0x0c,0x01,0x01,0x02,0x09,0x01,0x01,0x01,0x02,0x01,
	0x0a,0x01,0x01,0x02,0x07,0x02,0x05,0x01,0x05,0x01,
	0x01,0x02,0x03,0x01,0x05,0x01,0x04,0x01,0x05,0x01,
	0x04,0x01,0x05,0x01,0x05,0x01,0x07,0x01,0x02,0x01,
	0x01,0x02,0x01,0x01,0x02,0x01,0x01,0x01,0x05,0x01,
	0x04,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x08,0x01,
	0x01,0x01,0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x01,
	0x01,0x01,0x0e,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
	0x03,0x01,0x04,0x01,0x04,0x01,0x0a,0x01,0x0b,0x01,
	0x02,0x01,0x01,0x01,0x01,0x01,0x02,0x02,0x01,0x01,
	0x07,0x02,0x03,0x01,0x01,0x02,0x01,0x01,0x03,0x01,
	0x01,0x01,0x01,0x01,0x09,0x01,0x01,0x02,0x04,0x01,
	0x08,0x01,0x02,0x01,0x01,0x02,0x02,0x01,0x02,0x01,
	0x03,0x01,0x01,0x02,0x02,0x01,0x04,0x01,0x03,0x01,
	0x02,0x01,0x01,0x01,0x04,0x01,0x01,0x01,0x05,0x01,
	0x01,0x01,0x02,0x01,0x04,0x01,0x01,0x01,0x02,0x01,
	0x01,0x01,0x03,0x01,0x04,0x01,0x01,0x01,0x02,0x01,
	0x02,0x02,0x01,0x01,0x03,0x01,0x01,0x01,0x01,0x01,
	0x06,0x01,0x06,0x01,0x08,0x01,0x04,0x01,0x0f,0x01,
	0x0f,0x01,0x04,0x01,0x01,0x01,0x05,0x01,0x81,0xa1,
	0x01,0x07,0x01,0x08,0x01,0x01,0x01,0x0a,0x01,0x01,
	0x01,0x1b,0x01,0x04,0x01,0x0a,0x01,0x21,0x01,0x04,
	0x01,0x12,0x01,0x12,0x01,0x5b,0x01,0x04,0x03,0x04,
	0x03,0x11,0x03,0x0a,0x04,0x02,0x03,0x04,0x0a,0x0b,
	0x06,0x09,0x02,0x03,0x03,0x09,0x06,0x02,0x02,0x03,
	0x03,0x0b,0x04,0x18,0x09,0x05,0x07,0x07,0x01,0x03,
	0x05,0x05,0x03,0x02,0x01,0x07,0x03,0x04,0x05,0x02,
	0x01,0x04,0x09,0x06,0x09,0x05,0x05,0x09,0x04,0x05,
	0x02,0x04,0x01,0x04,0x04,0x01,0x01,0x01,0x05,0x05,
	0x05,0x01,0x03,0x05,0x05,0x0a,0x03,0x05,0x03,0x0d,
	0x07,0x06,0x04,0x0a,0x04,0x1a,0x02,0x07,0x0b,0x05,
	0x04,0x09,0x05,0x05,0x04,0x08,0x03,0x05,0x03,0x06,
	0x05,0x04,0x04,0x05,0x04,0x04,0x01,0x05,0x04,0x05,
	0x04,0x08,0x03,0x05,0x03,0x06,0x05,0x04,0x05,0x05,
	0x04,0x0a,0x04,0x05,0x03,0x13,0x01,0x06,0x04,0x05,
	0x06,0x06,0x04,0x05,0x01,0x03,0x04,0x04,0x04,0x10,
	0x03,0x07,0x04,0x05,0x08,0x05,0x04,0x04,0x04,0x01,
	0x04,0x04,0x04,0x06,0x02,0x08,0x03,0x06,0x04,0x06,
	0x09,0x05,0x04,0x04,0x03,0x02,0x04,0x04,0x04,0x05,
	0x02,0x09,0x03,0x06,0x04,0x06,0x04,0x02,0x04,0x05,
	0x04,0x04,0x03,0x03,0x03,0x05,0x03,0x10,0x04,0x05,
	0x05,0x05,0x04,0x04,0x04,0x05,0x04,0x05,0x01,0x03,
	0x04,0x04,0x03,0x0a,0x02,0x05,0x04,0x05,0x05,0x05,
	0x04,0x04,0x05,0x05,0x04,0x05,0x01,0x03,0x04,0x04,
	0x03,0x09,0x03,0x05,0x04,0x05,0x04,0x06,0x04,0x05,
	0x06,0x05,0x04,0x05,0x01,0x03,0x04,0x04,0x04,0x08,
	0x03,0x05,0x03,0x07,0x04,0x05,0x04,0x06,0x05,0x01,
	0x02,0x05,0x04,0x04,0x02,0x02,0x04,0x04,0x02,0x06,
	0x01,0x01,0x01,0x02,0x02,0x05,0x03,0x09,0x02,0x06,
	0x02,0x09,0x03,0x04,0x02,0x05,0x04,0x02,0x01,0x02,
	0x01,0x02,0x03,0x04,0x01,0x01,0x02,0x09,0x03,0x0b,
	0x01,0x05,0x03,0x07,0x04,0x04,0x04,0x07,0x05,0x05,
	0x02,0x01,0x01,0x02,0x01,0x05,0x02,0x07,0x01,0x02,
	0x02,0x05,0x04,0x08,0x02,0x06,0x02,0x09,0x03,0x05,
	0x02,0x12,0x01,0x05,0x02,0x01,0x01,0x02,0x01,0x05,
	0x02,0x0a,0x02,0x05,0x01,0x0b,0x01,0x0b,0x01,0x10,
	0x02,0x0f,0x01,0x05,0x02,0x01,0x01,0x02,0x01,0x04,
	0x03,0x04,0x01,0x05,0x01,0x0b,0x01,0x54,0x01,0x33,
	0x01,0x00,

/* Golf */
	0x01,0x03,0x03,0x04,0x02,0x0e,0x01,0x05,0x01,0x03,
	0x03,0x02,0x01,0x07,0x01,0x01,0x01,0x05,0x02,0x02,
	0x01,0x02,0x01,0x06,0x01,0x01,0x01,0x03,0x01,0x05,
	0x01,0x06,0x01,0x16,0x02,0x01,0x01,0x01,0x08,0x10,
	0x06,0x0d,0x02,0x01,0x01,0x05,0x0c,0x0a,0x08,0x09,
	0x06,0x09,0x0d,0x0a,0x06,0x09,0x05,0x0b,0x0f,0x09,
	0x05,0x08,0x06,0x08,0x02,0x03,0x0e,0x08,0x06,0x06,
	0x07,0x08,0x03,0x04,0x05,0x01,0x06,0x06,0x01,0x01,
	0x06,0x05,0x08,0x06,0x02,0x09,0x0b,0x05,0x08,0x05,
	0x07,0x07,0x02,0x06,0x01,0x04,0x0a,0x05,0x05,0x08,
	0x05,0x09,0x02,0x05,0x03,0x04,0x09,0x05,0x04,0x04,
	0x01,0x04,0x04,0x05,0x03,0x09,0x03,0x03,0x08,0x05,
	0x05,0x08,0x05,0x04,0x04,0x06,0x03,0x05,0x07,0x06,
	0x05,0x08,0x04,0x05,0x04,0x05,0x04,0x04,0x0a,0x05,
	0x04,0x04,0x02,0x03,0x04,0x05,0x03,0x05,0x03,0x05,
	0x0b,0x04,0x04,0x05,0x03,0x02,0x04,0x04,0x04,0x04,
	0x04,0x05,0x0a,0x05,0x04,0x05,0x03,0x03,0x03,0x04,
	0x04,0x04,0x04,0x05,0x0b,0x04,0x04,0x05,0x03,0x03,
	0x04,0x04,0x04,0x04,0x04,0x04,0x0b,0x05,0x05,0x04,
	0x03,0x03,0x04,0x04,0x03,0x05,0x03,0x05,0x0c,0x05,
	0x04,0x04,0x03,0x04,0x03,0x05,0x03,0x05,0x03,0x05,
	0x06,0x01,0x05,0x05,0x04,0x04,0x03,0x03,0x04,0x04,
	0x04,0x05,0x03,0x05,0x0c,0x05,0x04,0x05,0x02,0x03,
	0x04,0x05,0x04,0x04,0x04,0x04,0x07,0x01,0x04,0x05,
	0x04,0x05,0x03,0x03,0x04,0x05,0x03,0x05,0x03,0x05,
	0x0c,0x05,0x05,0x04,0x04,0x02,0x04,0x04,0x04,0x05,
	0x04,0x04,0x0c,0x05,0x05,0x04,0x04,0x01,0x05,0x05,
	0x04,0x04,0x04,0x05,0x06,0x01,0x05,0x05,0x05,0x04,
	0x04,0x03,0x03,0x05,0x04,0x04,0x04,0x05,0x05,0x03,
	0x05,0x06,0x04,0x04,0x04,0x01,0x01,0x01,0x03,0x06,
	0x03,0x05,0x04,0x04,0x05,0x04,0x06,0x05,0x05,0x06,
	0x04,0x01,0x04,0x05,0x04,0x05,0x03,0x05,0x05,0x04,
	0x06,0x07,0x04,0x06,0x04,0x01,0x04,0x06,0x04,0x05,
	0x04,0x04,0x04,0x05,0x07,0x07,0x05,0x06,0x09,0x06,
	0x04,0x06,0x04,0x05,0x03,0x05,0x0a,0x07,0x05,0x05,
	0x06,0x02,0x01,0x07,0x04,0x06,0x04,0x06,0x03,0x05,
	0x0b,0x07,0x06,0x06,0x04,0x02,0x01,0x08,0x04,0x07,
	0x04,0x09,0x02,0x01,0x01,0x05,0x04,0x02,0x03,0x07,
	0x06,0x06,0x02,0x01,0x01,0x02,0x01,0x01,0x02,0x06,
	0x04,0x08,0x04,0x08,0x05,0x06,0x04,0x01,0x04,0x08,
	0x04,0x07,0x04,0x01,0x01,0x01,0x02,0x08,0x04,0x08,
	0x04,0x09,0x02,0x0f,0x02,0x00,

/* Hotel */
	0x02,0x27,0x0d,0x07,0x04,0x01,0x03,0x06,0x03,0x03,
	0x02,0x05,0x01,0x04,0x0a,0x06,0x03,0x02,0x04,0x05,
	0x03,0x02,0x03,0x05,0x02,0x03,0x06,0x01,0x05,0x05,
	0x03,0x02,0x04,0x06,0x02,0x02,0x04,0x0a,0x0b,0x05,
	0x04,0x01,0x04,0x06,0x02,0x02,0x04,0x0a,0x0b,0x05,
	0x04,0x01,0x05,0x05,0x03,0x02,0x04,0x05,0x01,0x04,
	0x0b,0x05,0x03,0x02,0x05,0x05,0x03,0x01,0x05,0x05,
	0x02,0x03,0x0a,0x06,0x03,0x02,0x05,0x05,0x03,0x01,
	0x01,0x01,0x03,0x06,0x02,0x02,0x0a,0x07,0x02,0x02,
	0x05,0x05,0x05,0x01,0x03,0x06,0x02,0x02,0x0b,0x06,
	0x03,0x01,0x05,0x06,0x04,0x01,0x04,0x06,0x01,0x03,
	0x09,0x08,0x08,0x07,0x08,0x09,0x0a,0x08,0x08,0x09,
	0x06,0x09,0x09,0x08,0x01,0x01,0x06,0x0a,0x06,0x09,
	0x09,0x09,0x07,0x0a,0x06,0x09,0x08,0x09,0x08,0x09,
	0x08,0x07,0x08,0x0a,0x08,0x09,0x08,0x07,0x07,0x0a,
	0x0a,0x09,0x06,0x09,0x06,0x0a,0x09,0x0a,0x09,0x05,
	0x08,0x0a,0x0a,0x0a,0x08,0x06,0x08,0x0c,0x09,0x0a,
	0x09,0x04,0x08,0x0e,0x05,0x1a,0x07,0x0c,0x02,0x21,
	0x02,0x01,0x01,0x82,0xbb,0x01,0x09,0x01,0x08,0x01,
	0x0c,0x01,0x0f,0x01,0x03,0x01,0x05,0x02,0x01,0x01,
	0x07,0x01,0x01,0x01,0x01,0x01,0x03,0x01,0x09,0x01,
	0x04,0x01,0x02,0x01,0x01,0x01,0x03,0x01,0x01,0x01,
	0x01,0x01,0x01,0x01,0x02,0x01,0x01,0x01,0x03,0x01,
	0x01,0x01,0x01,0x01,0x0d,0x01,0x05,0x01,0x06,0x01,
	0x01,0x01,0x01,0x01,0x08,0x01,0x17,0x01,0x0c,0x01,
	0x3a,0x01,0x17,0x01,0x81,0x05,0x02,0x02,0x01,0x01,
	0x01,0x01,0x0a,0x1b,0x01,0x01,0x02,0x02,0x01,0x01,
	0x01,0x02,0x0a,0x01,0x01,0x0a,0x01,0x0d,0x01,0x02,
	0x01,0x08,0x0b,0x09,0x02,0x01,0x04,0x07,0x03,0x0a,
	0x0c,0x08,0x05,0x08,0x05,0x08,0x01,0x01,0x02,0x01,
	0x02,0x01,0x08,0x08,0x06,0x07,0x05,0x07,0x05,0x02,
	0x01,0x01,0x07,0x08,0x06,0x07,0x06,0x06,0x05,0x04,
	0x08,0x07,0x05,0x08,0x05,0x07,0x05,0x04,0x07,0x08,
	0x05,0x08,0x05,0x07,0x05,0x04,0x07,0x08,0x05,0x07,
	0x05,0x08,0x04,0x05,0x07,0x07,0x05,0x08,0x05,0x07,
	0x05,0x05,0x07,0x07,0x05,0x07,0x05,0x08,0x04,0x05,
	0x08,0x07,0x05,0x07,0x05,0x08,0x04,0x05,0x08,0x07,
	0x05,0x06,0x07,0x06,0x05,0x05,0x08,0x05,0x01,0x02,
	0x04,0x07,0x06,0x06,0x05,0x06,0x08,0x05,0x01,0x01,
	0x05,0x06,0x07,0x05,0x06,0x06,0x08,0x05,0x01,0x01,
	0x05,0x07,0x05,0x07,0x05,0x06,0x08,0x05,0x01,0x01,
	0x05,0x07,0x05,0x07,0x04,0x07,0x09,0x04,0x02,0x01,
	0x04,0x08,0x04,0x08,0x03,0x08,0x09,0x04,0x01,0x02,
	0x04,0x08,0x04,0x08,0x04,0x08,0x08,0x05,0x01,0x01,
	0x05,0x07,0x05,0x08,0x03,0x08,0x08,0x05,0x08,0x04,
	0x02,0x01,0x05,0x08,0x02,0x0a,0x08,0x04,0x08,0x05,
	0x07,0x05,0x02,0x04,0x01,0x09,0x08,0x04,0x04,0x01,
	0x03,0x05,0x03,0x01,0x04,0x04,0x03,0x0d,0x09,0x05,
	0x03,0x01,0x01,0x01,0x02,0x04,0x08,0x05,0x03,0x09,
	0x02,0x01,0x01,0x01,0x09,0x05,0x03,0x03,0x02,0x04,
	0x05,0x01,0x02,0x05,0x04,0x09,0x03,0x02,0x05,0x01,
	0x04,0x04,0x04,0x02,0x03,0x04,0x04,0x03,0x02,0x04,
	0x04,0x08,0x04,0x03,0x04,0x02,0x05,0x05,0x03,0x02,
	0x03,0x04,0x04,0x04,0x01,0x04,0x04,0x09,0x03,0x04,
	0x03,0x03,0x07,0x05,0x05,0x01,0x01,0x06,0x04,0x09,
	0x04,0x06,0x01,0x03,0x01,0x01,0x01,0x05,0x02,0x03,
	0x09,0x06,0x04,0x09,0x04,0x09,0x04,0x05,0x03,0x03,
	0x03,0x05,0x02,0x02,0x05,0x03,0x04,0x05,0x04,0x04,
	0x01,0x04,0x05,0x0a,0x03,0x06,0x01,0x0c,0x02,0x03,
	0x04,0x05,0x05,0x06,0x04,0x09,0x05,0x06,0x01,0x01,
	0x01,0x01,0x03,0x06,0x03,0x12,0x03,0x05,0x07,0x06,
	0x03,0x0a,0x04,0x06,0x01,0x01,0x01,0x0b,0x04,0x19,
	0x03,0x03,0x02,0x07,0x04,0x0a,0x04,0x06,0x03,0x0b,
	0x04,0x07,0x02,0x1a,0x02,0x07,0x04,0x0b,0x04,0x06,
	0x03,0x0d,0x02,0x07,0x02,0x08,0x01,0x06,0x02,0x0e,
	0x01,0x07,0x04,0x0c,0x03,0x07,0x04,0x15,0x03,0x10,
	0x01,0x0e,0x01,0x08,0x04,0x0c,0x03,0x07,0x04,0x17,
	0x02,0x1f,0x02,0x07,0x04,0x0e,0x01,0x08,0x04,0x37,
	0x01,0x08,0x05,0x18,0x03,0x38,0x01,0x09,0x04,0x19,
	0x02,0x43,0x05,0x0b,0x01,0x0c,0x03,0x40,0x05,0x0e,
	0x01,0x09,0x03,0x39,0x01,0x09,0x03,0x0d,0x03,0x0b,
	0x02,0x39,0x02,0x08,0x04,0x01,0x01,0x0b,0x03,0x1b,
	0x01,0x00,

/* India */
	0x07,0x01,0x02,0x0d,0x08,0x0d,0x0a,0x01,0x01,0x0b,
	0x01,0x01,0x09,0x0d,0x0a,0x02,0x01,0x02,0x01,0x08,
	0x0a,0x0e,0x0b,0x01,0x01,0x02,0x01,0x08,0x02,0x01,
	0x07,0x0c,0x0c,0x02,0x01,0x0b,0x09,0x0c,0x0d,0x01,
	0x01,0x0b,0x09,0x0c,0x0c,0x02,0x01,0x0b,0x09,0x0b,
	0x0d,0x01,0x02,0x0b,0x09,0x0b,0x0c,0x02,0x01,0x0b,
	0x09,0x0b,0x0c,0x01,0x01,0x0b,0x07,0x01,0x01,0x0b,
	0x0b,0x01,0x01,0x0b,0x08,0x0c,0x0d,0x0b,0x07,0x01,
	0x01,0x0a,0x0d,0x0b,0x07,0x01,0x01,0x0b,0x0c,0x0b,
	0x07,0x01,0x02,0x0a,0x0c,0x11,0x07,0x0d,0x0b,0x11,
	0x06,0x01,0x01,0x08,0x0b,0x10,0x09,0x08,0x0b,0x10,
	0x09,0x07,0x0c,0x11,0x01,0x01,0x02,0x02,0x03,0x06,
	0x0c,0x11,0x01,0x01,0x02,0x01,0x01,0x02,0x01,0x07,
	0x0b,0x13,0x01,0x03,0x03,0x07,0x0c,0x10,0x01,0x01,
	0x04,0x02,0x01,0x08,0x0c,0x10,0x06,0x01,0x02,0x09,
	0x0b,0x10,0x07,0x01,0x02,0x09,0x0b,0x10,0x07,0x01,
	0x02,0x08,0x0c,0x12,0x05,0x01,0x01,0x09,0x0d,0x11,
	0x09,0x08,0x0d,0x18,0x03,0x06,0x02,0x04,0x0a,0x17,
	0x01,0x02,0x01,0x0b,0x0d,0x19,0x03,0x10,0x08,0x17,
	0x01,0x01,0x03,0x10,0x09,0x2f,0x07,0x32,0x07,0x2d,
	0x05,0x01,0x02,0x01,0x01,0x10,0x04,0x01,0x02,0x10,
	0x0c,0x01,0x01,0x0b,0x0a,0x02,0x01,0x0b,0x0d,0x01,
	0x01,0x0b,0x0b,0x0c,0x0d,0x0d,0x0b,0x0c,0x0e,0x02,
	0x01,0x0a,0x0b,0x0d,0x0b,0x01,0x02,0x01,0x01,0x0b,
	0x0b,0x0e,0x0d,0x0d,0x02,0x01,0x08,0x0e,0x0e,0x02,
	0x01,0x0b,0x0b,0x0d,0x0f,0x01,0x01,0x0b,0x0b,0x0f,
	0x0e,0x0d,0x0c,0x0e,0x0f,0x02,0x01,0x0b,0x01,0x01,
	0x07,0x01,0x01,0x0d,0x01,0x01,0x0d,0x01,0x01,0x02,
	0x01,0x0b,0x01,0x01,0x07,0x01,0x01,0x0e,0x0f,0x01,
	0x02,0x01,0x01,0x0b,0x02,0x01,0x08,0x0e,0x10,0x02,
	0x01,0x01,0x02,0x0a,0x09,0x10,0x12,0x01,0x01,0x02,
	0x01,0x0a,0x0a,0x0f,0x0a,0x01,0x08,0x01,0x01,0x02,
	0x01,0x08,0x0b,0x0d,0x0a,0x07,0x06,0x01,0x01,0x02,
	0x01,0x08,0x0a,0x0c,0x08,0x09,0x09,0x01,0x02,0x0a,
	0x08,0x0b,0x01,0x01,0x05,0x0b,0x0d,0x02,0x01,0x02,
	0x01,0x06,0x01,0x01,0x05,0x01,0x01,0x09,0x01,0x01,
	0x05,0x0a,0x09,0x06,0x04,0x01,0x02,0x08,0x01,0x01,
	0x07,0x09,0x08,0x09,0x07,0x08,0x07,0x01,0x01,0x08,
	0x08,0x08,0x07,0x0a,0x07,0x08,0x0a,0x09,0x06,0x01,
	0x01,0x08,0x07,0x0a,0x05,0x0a,0x08,0x04,0x05,0x02,
	0x01,0x05,0x01,0x02,0x05,0x08,0x07,0x08,0x06,0x09,
	0x07,0x05,0x08,0x08,0x06,0x08,0x07,0x08,0x05,0x08,
	0x07,0x08,0x0a,0x08,0x06,0x06,0x02,0x01,0x04,0x08,
	0x05,0x07,0x05,0x07,0x09,0x02,0x06,0x08,0x04,0x08,
	0x06,0x07,0x01,0x01,0x03,0x08,0x06,0x05,0x01,0x01,
	0x04,0x07,0x08,0x05,0x01,0x01,0x04,0x08,0x05,0x07,
	0x06,0x09,0x03,0x08,0x03,0x08,0x0a,0x05,0x01,0x02,
	0x04,0x08,0x04,0x07,0x03,0x09,0x02,0x0f,0x02,0x09,
	0x0a,0x05,0x01,0x01,0x04,0x08,0x04,0x07,0x04,0x08,
	0x03,0x09,0x02,0x04,0x03,0x08,0x0b,0x05,0x01,0x03,
	0x02,0x05,0x03,0x03,0x01,0x05,0x02,0x03,0x01,0x05,
	0x03,0x09,0x03,0x08,0x03,0x04,0x01,0x02,0x04,0x03,
	0x04,0x05,0x02,0x02,0x03,0x06,0x02,0x01,0x03,0x05,
	0x02,0x09,0x03,0x09,0x02,0x09,0x03,0x04,0x03,0x03,
	0x01,0x03,0x05,0x06,0x02,0x01,0x01,0x07,0x04,0x08,
	0x03,0x09,0x03,0x08,0x03,0x08,0x02,0x06,0x02,0x06,
	0x05,0x09,0x03,0x08,0x04,0x08,0x03,0x0a,0x02,0x11,
	0x02,0x08,0x02,0x06,0x03,0x05,0x01,0x07,0x02,0x09,
	0x04,0x09,0x02,0x0a,0x01,0x11,0x02,0x07,0x01,0x09,
	0x01,0x0b,0x03,0x11,0x01,0x80,0x8c,0x01,0x00,

/* Juliet */
	0x01,0x02,0x01,0x22,0x01,0x0c,0x01,0x08,0x01,0x01,
	0x01,0x1a,0x01,0x0a,0x01,0x1b,0x01,0x0a,0x01,0x06,
	0x01,0x05,0x01,0x05,0x01,0x0a,0x01,0x04,0x01,0x03,
	0x01,0x04,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x05,
	0x01,0x12,0x01,0x0e,0x01,0x05,0x01,0x16,0x01,0x28,
	0x01,0x03,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
	0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x13,0x01,0x0f,
	0x01,0x01,0x0d,0x10,0x09,0x0d,0x0e,0x0e,0x09,0x0c,
	0x0f,0x0e,0x08,0x0b,0x0e,0x0c,0x08,0x0b,0x0f,0x0c,
	0x0a,0x0a,0x0f,0x0c,0x09,0x0a,0x10,0x0c,0x09,0x0b,
	0x0e,0x0c,0x0a,0x0a,0x0f,0x0c,0x09,0x0b,0x0e,0x0c,
	0x09,0x0b,0x10,0x0b,0x09,0x0a,0x10,0x0c,0x09,0x0a,
	0x10,0x0c,0x09,0x0a,0x10,0x0b,0x09,0x0b,0x0f,0x0c,
	0x09,0x0a,0x11,0x0b,0x08,0x0b,0x10,0x0b,0x09,0x0a,
	0x11,0x0b,0x08,0x0b,0x10,0x0c,0x08,0x0b,0x10,0x0d,
	0x09,0x09,0x11,0x0d,0x0a,0x08,0x12,0x0c,0x0a,0x09,
	0x09,0x01,0x08,0x0c,0x0a,0x0b,0x11,0x0b,0x0a,0x0b,
	0x10,0x0c,0x09,0x0a,0x09,0x03,0x06,0x0c,0x07,0x0a,
	0x09,0x03,0x07,0x0c,0x08,0x0a,0x08,0x02,0x01,0x01,
	0x06,0x0c,0x08,0x0a,0x11,0x0d,0x08,0x0a,0x10,0x02,
	0x01,0x0b,0x08,0x0b,0x10,0x01,0x01,0x0c,0x07,0x0b,
	0x0f,0x02,0x01,0x0b,0x08,0x0c,0x0f,0x01,0x01,0x0c,
	0x0a,0x0b,0x0e,0x01,0x01,0x0e,0x08,0x0b,0x0e,0x02,
	0x01,0x0d,0x09,0x0d,0x0c,0x01,0x01,0x0d,0x0a,0x0d,
	0x0c,0x01,0x01,0x0d,0x0a,0x0d,0x0b,0x01,0x01,0x0e,
	0x0a,0x0c,0x0c,0x01,0x01,0x0d,0x0a,0x0c,0x0c,0x01,
	0x01,0x0d,0x09,0x0c,0x0d,0x01,0x01,0x0b,0x01,0x01,
	0x08,0x0c,0x0d,0x02,0x01,0x0b,0x01,0x01,0x06,0x01,
	0x01,0x0a,0x01,0x01,0x0d,0x01,0x02,0x0a,0x08,0x01,
	0x01,0x0a,0x0f,0x01,0x02,0x08,0x01,0x01,0x08,0x0b,
	0x0a,0x01,0x05,0x02,0x01,0x08,0x01,0x02,0x07,0x0b,
	0x08,0x03,0x05,0x01,0x02,0x08,0x01,0x01,0x08,0x0a,
	0x06,0x06,0x05,0x01,0x01,0x08,0x02,0x01,0x05,0x0b,
	0x07,0x06,0x06,0x01,0x01,0x08,0x08,0x09,0x07,0x07,
	0x07,0x0a,0x07,0x08,0x06,0x09,0x09,0x08,0x07,0x08,
	0x07,0x08,0x0b,0x08,0x06,0x09,0x05,0x09,0x0c,0x08,
	0x02,0x01,0x04,0x08,0x05,0x07,0x0f,0x08,0x06,0x06,
	0x01,0x01,0x06,0x06,0x06,0x02,0x07,0x08,0x07,0x06,
	0x07,0x07,0x06,0x03,0x07,0x07,0x03,0x01,0x03,0x07,
	0x07,0x06,0x06,0x04,0x07,0x07,0x06,0x07,0x07,0x07,
	0x04,0x06,0x08,0x06,0x06,0x08,0x05,0x07,0x05,0x07,
	0x08,0x07,0x03,0x01,0x02,0x07,0x04,0x08,0x04,0x09,
	0x0a,0x06,0x04,0x01,0x01,0x06,0x01,0x01,0x04,0x08,
	0x03,0x09,0x03,0x01,0x08,0x07,0x03,0x02,0x01,0x05,
	0x02,0x01,0x04,0x07,0x04,0x08,0x03,0x04,0x08,0x07,
	0x03,0x01,0x01,0x06,0x01,0x01,0x04,0x08,0x05,0x07,
	0x05,0x06,0x07,0x07,0x03,0x01,0x01,0x06,0x01,0x01,
	0x04,0x08,0x05,0x08,0x04,0x07,0x09,0x06,0x03,0x01,
	0x02,0x08,0x04,0x08,0x05,0x09,0x03,0x0a,0x0a,0x08,
	0x02,0x01,0x03,0x07,0x04,0x09,0x01,0x01,0x04,0x08,
	0x01,0x0e,0x01,0x01,0x03,0x06,0x02,0x09,0x01,0x01,
	0x01,0x02,0x02,0x0b,0x01,0x02,0x01,0x0f,0x01,0x19,
	0x01,0x83,0x04,0x01,0x02,0x01,0x0b,0x01,0x18,0x01,
	0x10,0x01,0x00,

/* Kilo */
	0x01,0x30,0x01,0x01,0x01,0x03,0x01,0x1c,0x01,0x20,
	0x01,0x80,0xc3,0x01,0x2c,0x01,0x02,0x01,0x80,0xed,
	0x0d,0x13,0x11,0x01,0x01,0x02,0x01,0x0d,0x02,0x01,
	0x06,0x01,0x02,0x04,0x05,0x01,0x01,0x02,0x01,0x0d,
	0x02,0x01,0x06,0x01,0x02,0x01,0x07,0x01,0x02,0x01,
	0x01,0x0e,0x01,0x01,0x09,0x04,0x04,0x01,0x02,0x01,
	0x02,0x0d,0x01,0x02,0x05,0x01,0x02,0x02,0x01,0x01,
	0x04,0x01,0x02,0x01,0x01,0x0e,0x01,0x01,0x06,0x01,
	0x02,0x03,0x05,0x01,0x01,0x02,0x01,0x0d,0x02,0x01,
	0x06,0x01,0x01,0x02,0x01,0x01,0x04,0x01,0x01,0x02,
	0x01,0x02,0x01,0x0b,0x01,0x01,0x06,0x01,0x01,0x02,
	0x02,0x01,0x03,0x01,0x02,0x01,0x01,0x02,0x01,0x0b,
	0x01,0x01,0x02,0x01,0x03,0x01,0x01,0x02,0x02,0x01,
	0x03,0x01,0x02,0x01,0x01,0x02,0x01,0x0a,0x02,0x01,
	0x02,0x01,0x03,0x01,0x01,0x02,0x08,0x01,0x02,0x0d,
	0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x02,0x01,0x02,
	0x05,0x01,0x01,0x02,0x01,0x02,0x01,0x0b,0x01,0x01,
	0x06,0x01,0x01,0x02,0x05,0x01,0x02,0x01,0x02,0x01,
	0x01,0x0b,0x01,0x01,0x03,0x02,0x01,0x04,0x05,0x01,
	0x02,0x01,0x02,0x01,0x01,0x0b,0x01,0x01,0x02,0x01,
	0x03,0x04,0x01,0x01,0x03,0x01,0x02,0x01,0x02,0x0d,
	0x01,0x01,0x04,0x01,0x01,0x05,0x07,0x02,0x01,0x0d,
	0x01,0x02,0x03,0x01,0x01,0x06,0x04,0x01,0x01,0x02,
	0x01,0x0d,0x02,0x01,0x03,0x01,0x01,0x06,0x04,0x01,
	0x02,0x01,0x01,0x0e,0x01,0x01,0x06,0x05,0x02,0x01,
	0x02,0x01,0x02,0x01,0x01,0x02,0x01,0x08,0x01,0x01,
	0x02,0x01,0x03,0x01,0x02,0x05,0x07,0x01,0x02,0x01,
	0x01,0x0b,0x01,0x01,0x04,0x01,0x01,0x06,0x01,0x01,
	0x02,0x01,0x02,0x01,0x02,0x0d,0x01,0x01,0x03,0x01,
	0x02,0x05,0x01,0x02,0x02,0x01,0x01,0x02,0x01,0x0b,
	0x01,0x02,0x05,0x01,0x02,0x05,0x01,0x01,0x03,0x01,
	0x04,0x0b,0x01,0x01,0x06,0x01,0x02,0x07,0x03,0x01,
	0x02,0x01,0x02,0x0d,0x08,0x07,0x06,0x02,0x01,0x0b,
	0x01,0x01,0x03,0x01,0x02,0x01,0x01,0x08,0x09,0x0b,
	0x08,0x0a,0x07,0x01,0x02,0x0b,0x08,0x0a,0x08,0x0e,
	0x08,0x0b,0x09,0x0e,0x07,0x0a,0x0a,0x0d,0x07,0x0a,
	0x09,0x01,0x01,0x0b,0x08,0x0a,0x0a,0x01,0x01,0x0b,
	0x08,0x0b,0x09,0x02,0x01,0x0b,0x08,0x0b,0x0a,0x01,
	0x01,0x0b,0x08,0x01,0x01,0x0a,0x09,0x02,0x01,0x0b,
	0x08,0x01,0x01,0x0a,0x0a,0x01,0x01,0x0d,0x06,0x01,
	0x02,0x0b,0x09,0x02,0x01,0x0d,0x09,0x0d,0x08,0x01,
	0x02,0x0d,0x08,0x0e,0x09,0x01,0x01,0x0d,0x06,0x01,
	0x01,0x0d,0x0c,0x10,0x05,0x02,0x01,0x0e,0x0a,0x0c,
	0x01,0x01,0x01,0x01,0x05,0x0a,0x01,0x01,0x01,0x04,
	0x0b,0x0a,0x09,0x0b,0x05,0x07,0x07,0x0a,0x07,0x08,
	0x08,0x08,0x09,0x09,0x06,0x09,0x06,0x09,0x0c,0x07,
	0x08,0x08,0x06,0x0a,0x10,0x06,0x01,0x03,0x04,0x05,
	0x02,0x01,0x06,0x0a,0x04,0x03,0x03,0x02,0x05,0x0a,
	0x04,0x05,0x01,0x03,0x05,0x06,0x01,0x02,0x05,0x03,
	0x03,0x02,0x06,0x0a,0x05,0x05,0x01,0x01,0x06,0x07,
	0x07,0x04,0x0c,0x08,0x07,0x05,0x08,0x06,0x05,0x01,
	0x02,0x05,0x05,0x01,0x08,0x07,0x08,0x05,0x07,0x07,
	0x04,0x08,0x0f,0x07,0x08,0x05,0x07,0x07,0x04,0x09,
	0x04,0x03,0x04,0x02,0x05,0x06,0x08,0x05,0x08,0x07,
	0x04,0x08,0x05,0x03,0x02,0x03,0x06,0x07,0x08,0x05,
	0x07,0x08,0x04,0x08,0x04,0x05,0x01,0x03,0x07,0x07,
	0x07,0x06,0x07,0x08,0x04,0x09,0x03,0x06,0x01,0x02,
	0x08,0x07,0x08,0x06,0x04,0x0a,0x04,0x0a,0x03,0x05,
	0x03,0x03,0x07,0x08,0x08,0x06,0x04,0x0a,0x04,0x0b,
	0x03,0x05,0x02,0x03,0x08,0x08,0x05,0x01,0x02,0x06,
	0x04,0x0a,0x04,0x0b,0x04,0x04,0x02,0x04,0x05,0x02,
	0x03,0x07,0x04,0x02,0x02,0x06,0x04,0x0b,0x03,0x0c,
	0x03,0x05,0x03,0x03,0x04,0x03,0x03,0x07,0x02,0x01,
	0x01,0x02,0x02,0x07,0x05,0x0a,0x03,0x06,0x01,0x05,
	0x03,0x05,0x03,0x03,0x04,0x03,0x04,0x07,0x02,0x03,
	0x03,0x06,0x05,0x0a,0x04,0x0c,0x04,0x0b,0x04,0x03,
	0x04,0x07,0x02,0x01,0x01,0x02,0x02,0x07,0x05,0x0a,
	0x04,0x0c,0x04,0x0b,0x04,0x04,0x04,0x07,0x04,0x02,
	0x03,0x06,0x05,0x0b,0x04,0x0d,0x04,0x0b,0x05,0x05,
	0x01,0x07,0x04,0x03,0x03,0x06,0x04,0x0d,0x04,0x0c,
	0x04,0x0b,0x05,0x06,0x01,0x08,0x04,0x02,0x04,0x06,
	0x04,0x0d,0x04,0x0c,0x04,0x0b,0x06,0x07,0x02,0x0d,
	0x04,0x08,0x04,0x0d,0x04,0x0c,0x04,0x0d,0x04,0x07,
	0x01,0x10,0x04,0x0b,0x01,0x0e,0x04,0x0e,0x02,0x0d,
	0x04,0x15,0x02,0x01,0x04,0x0b,0x02,0x11,0x01,0x1d,
	0x01,0x1a,0x01,0x01,0x02,0x01,0x01,0x0c,0x01,0x02,
	0x01,0x11,0x01,0x1d,0x01,0x1a,0x01,0x01,0x02,0x01,
	0x01,0x0e,0x01,0x01,0x02,0x4b,0x05,0x0f,0x02,0x4f,
	0x05,0x10,0x02,0x14,0x01,0x00,

/* Lima */
	0x07,0x0f,0x08,0x0f,0x0f,0x01,0x01,0x0e,0x09,0x10,
	0x0c,0x01,0x07,0x0f,0x09,0x0f,0x0b,0x04,0x06,0x01,
	0x01,0x0e,0x09,0x0e,0x0b,0x07,0x01,0x01,0x02,0x11,
	0x07,0x0e,0x09,0x08,0x05,0x11,0x06,0x0d,0x09,0x08,
	0x05,0x12,0x06,0x0e,0x01,0x01,0x05,0x01,0x0a,0x11,
	0x01,0x01,0x04,0x01,0x01,0x11,0x01,0x01,0x01,0x01,
	0x0a,0x13,0x02,0x02,0x01,0x01,0x02,0x0e,0x01,0x02,
	0x0a,0x11,0x02,0x02,0x01,0x02,0x01,0x12,0x01,0x01,
	0x09,0x0f,0x07,0x0b,0x01,0x01,0x11,0x0d,0x08,0x0c,
	0x11,0x02,0x01,0x0b,0x07,0x0b,0x11,0x02,0x01,0x0b,
	0x07,0x0a,0x01,0x01,0x10,0x01,0x01,0x0b,0x09,0x0a,
	0x0f,0x02,0x01,0x0b,0x09,0x0a,0x0e,0x02,0x01,0x0b,
	0x09,0x0a,0x0e,0x02,0x01,0x0c,0x08,0x0a,0x0e,0x02,
	0x01,0x0c,0x0a,0x0a,0x0c,0x01,0x02,0x0c,0x09,0x0b,
	0x0b,0x02,0x01,0x0c,0x09,0x0b,0x0b,0x01,0x01,0x0c,
	0x07,0x01,0x01,0x09,0x01,0x01,0x0d,0x01,0x01,0x0a,
	0x06,0x01,0x02,0x0b,0x0c,0x01,0x01,0x09,0x07,0x01,
	0x02,0x0b,0x0b,0x02,0x01,0x09,0x01,0x01,0x07,0x0c,
	0x0b,0x02,0x01,0x09,0x01,0x01,0x04,0x02,0x01,0x0b,
	0x09,0x01,0x02,0x01,0x01,0x0a,0x01,0x01,0x01,0x01,
	0x02,0x01,0x02,0x0a,0x01,0x02,0x06,0x01,0x02,0x01,
	0x02,0x0b,0x01,0x01,0x02,0x01,0x02,0x02,0x01,0x08,
	0x01,0x01,0x09,0x02,0x01,0x0b,0x01,0x02,0x01,0x02,
	0x01,0x02,0x01,0x08,0x01,0x01,0x07,0x01,0x02,0x01,
	0x01,0x0c,0x01,0x01,0x02,0x01,0x02,0x0a,0x09,0x01,
	0x02,0x0e,0x01,0x01,0x02,0x01,0x01,0x09,0x01,0x01,
	0x0c,0x02,0x01,0x0b,0x02,0x01,0x01,0x0e,0x0b,0x02,
	0x01,0x09,0x01,0x01,0x02,0x01,0x02,0x0e,0x0b,0x0b,
	0x01,0x02,0x04,0x01,0x01,0x0d,0x0b,0x0c,0x01,0x01,
	0x06,0x0d,0x09,0x01,0x01,0x0c,0x01,0x01,0x07,0x10,
	0x0b,0x10,0x02,0x0f,0x0d,0x0f,0x04,0x0f,0x0c,0x10,
	0x03,0x10,0x0c,0x0f,0x03,0x12,0x0b,0x10,0x02,0x12,
	0x0b,0x10,0x01,0x14,0x0c,0x25,0x0c,0x26,0x0c,0x18,
	0x01,0x0d,0x0c,0x0f,0x01,0x07,0x02,0x0d,0x0d,0x17,
	0x03,0x0d,0x0c,0x17,0x03,0x0d,0x08,0x0d,0x01,0x06,
	0x01,0x01,0x01,0x0c,0x01,0x07,0x0a,0x0b,0x03,0x05,
	0x02,0x01,0x01,0x02,0x04,0x05,0x02,0x04,0x02,0x04,
	0x09,0x07,0x01,0x04,0x02,0x05,0x04,0x02,0x04,0x04,
	0x03,0x05,0x01,0x04,0x0a,0x05,0x01,0x01,0x01,0x04,
	0x02,0x05,0x03,0x04,0x02,0x06,0x02,0x05,0x01,0x04,
	0x04,0x02,0x07,0x04,0x02,0x01,0x01,0x02,0x01,0x01,
	0x02,0x05,0x05,0x01,0x02,0x06,0x02,0x0a,0x04,0x03,
	0x09,0x05,0x03,0x04,0x02,0x05,0x03,0x03,0x02,0x05,
	0x03,0x05,0x02,0x04,0x03,0x04,0x03,0x02,0x06,0x04,
	0x04,0x02,0x01,0x01,0x01,0x04,0x04,0x04,0x01,0x05,
	0x03,0x05,0x03,0x03,0x04,0x03,0x03,0x03,0x07,0x05,
	0x01,0x01,0x02,0x04,0x01,0x05,0x04,0x05,0x01,0x04,
	0x02,0x05,0x03,0x04,0x03,0x04,0x04,0x01,0x09,0x05,
	0x03,0x04,0x02,0x05,0x04,0x05,0x01,0x04,0x02,0x06,
	0x03,0x04,0x01,0x05,0x03,0x02,0x05,0x02,0x04,0x05,
	0x03,0x04,0x02,0x05,0x03,0x04,0x01,0x01,0x01,0x04,
	0x02,0x05,0x03,0x05,0x01,0x04,0x03,0x04,0x03,0x03,
	0x07,0x05,0x04,0x04,0x01,0x05,0x03,0x06,0x01,0x04,
	0x02,0x07,0x02,0x0a,0x02,0x04,0x02,0x04,0x08,0x05,
	0x04,0x04,0x02,0x04,0x03,0x05,0x03,0x02,0x01,0x01,
	0x02,0x04,0x01,0x05,0x03,0x05,0x02,0x04,0x03,0x03,
	0x0a,0x05,0x04,0x04,0x01,0x05,0x03,0x04,0x03,0x03,
	0x03,0x05,0x02,0x04,0x03,0x05,0x02,0x04,0x02,0x04,
	0x04,0x02,0x05,0x05,0x03,0x0a,0x04,0x04,0x01,0x05,
	0x03,0x05,0x02,0x05,0x02,0x05,0x01,0x05,0x03,0x04,
	0x03,0x03,0x05,0x05,0x04,0x0a,0x03,0x0a,0x01,0x01,
	0x01,0x05,0x02,0x07,0x01,0x0a,0x02,0x06,0x0c,0x05,
	0x04,0x0a,0x03,0x06,0x01,0x03,0x03,0x05,0x03,0x11,
	0x02,0x06,0x07,0x03,0x04,0x05,0x03,0x05,0x01,0x04,
	0x04,0x05,0x02,0x04,0x02,0x04,0x03,0x0b,0x02,0x05,
	0x01,0x06,0x02,0x03,0x04,0x03,0x04,0x05,0x04,0x0a,
	0x02,0x0b,0x03,0x05,0x02,0x0b,0x02,0x05,0x02,0x0a,
	0x04,0x03,0x04,0x07,0x01,0x01,0x02,0x0a,0x02,0x0a,
	0x01,0x08,0x01,0x1f,0x02,0x05,0x04,0x02,0x01,0x05,
	0x04,0x0a,0x03,0x0c,0x01,0x05,0x01,0x0c,0x01,0x13,
	0x02,0x04,0x02,0x01,0x01,0x03,0x01,0x06,0x03,0x0a,
	0x04,0x0b,0x02,0x05,0x01,0x13,0x01,0x13,0x01,0x0b,
	0x01,0x06,0x03,0x0a,0x03,0x0b,0x01,0x00,

/* Mike */
	0x01,0x47,0x01,0x3b,0x02,0x05,0x01,0x02,0x02,0x38,
	0x01,0x04,0x02,0x01,0x02,0x37,0x01,0x01,0x01,0x04,
	0x05,0x35,0x01,0x01,0x08,0x35,0x09,0x01,0x01,0x32,
	0x0b,0x32,0x08,0x02,0x01,0x17,0x01,0x18,0x09,0x01,
	0x02,0x16,0x01,0x17,0x08,0x02,0x01,0x17,0x02,0x13,
	0x0d,0x15,0x04,0x11,0x0d,0x15,0x04,0x0b,0x02,0x02,
	0x07,0x0c,0x03,0x05,0x02,0x06,0x02,0x05,0x01,0x05,
	0x0b,0x06,0x03,0x03,0x03,0x05,0x04,0x0a,0x02,0x05,
	0x0b,0x04,0x04,0x04,0x02,0x05,0x04,0x05,0x02,0x04,
	0x01,0x05,0x0a,0x04,0x04,0x04,0x03,0x04,0x03,0x04,
	0x04,0x04,0x02,0x03,0x04,0x01,0x05,0x04,0x04,0x04,
	0x02,0x04,0x04,0x04,0x03,0x04,0x03,0x03,0x09,0x04,
	0x04,0x04,0x03,0x03,0x03,0x04,0x04,0x04,0x02,0x03,
	0x09,0x04,0x04,0x03,0x03,0x03,0x04,0x04,0x03,0x03,
	0x04,0x03,0x09,0x04,0x03,0x04,0x03,0x03,0x04,0x04,
	0x02,0x04,0x03,0x04,0x08,0x04,0x04,0x03,0x03,0x03,
	0x03,0x05,0x02,0x03,0x04,0x03,0x08,0x05,0x03,0x04,
	0x02,0x03,0x04,0x03,0x04,0x03,0x03,0x04,0x07,0x05,
	0x03,0x03,0x02,0x04,0x03,0x04,0x03,0x03,0x03,0x03,
	0x03,0x02,0x04,0x04,0x04,0x03,0x02,0x04,0x03,0x03,
	0x02,0x04,0x02,0x04,0x04,0x02,0x04,0x05,0x03,0x03,
	0x01,0x05,0x02,0x04,0x02,0x04,0x02,0x04,0x02,0x02,
	0x07,0x04,0x03,0x03,0x02,0x04,0x03,0x04,0x01,0x04,
	0x02,0x05,0x01,0x02,0x07,0x05,0x01,0x03,0x03,0x04,
	0x03,0x01,0x02,0x07,0x01,0x02,0x01,0x03,0x01,0x01,
	0x08,0x05,0x01,0x02,0x03,0x06,0x06,0x08,0x03,0x02,
	0x01,0x04,0x06,0x07,0x03,0x01,0x01,0x06,0x04,0x01,
	0x01,0x06,0x01,0x01,0x02,0x01,0x01,0x05,0x06,0x07,
	0x03,0x01,0x01,0x01,0x02,0x03,0x01,0x01,0x04,0x08,
	0x05,0x04,0x07,0x08,0x02,0x01,0x03,0x06,0x07,0x07,
	0x06,0x03,0x06,0x08,0x01,0x02,0x01,0x01,0x01,0x01,
	0x01,0x04,0x01,0x02,0x05,0x09,0x0d,0x02,0x01,0x06,
	0x01,0x01,0x01,0x01,0x04,0x07,0x06,0x0b,0x0c,0x01,
	0x01,0x06,0x01,0x01,0x06,0x01,0x01,0x08,0x01,0x01,
	0x02,0x0c,0x01,0x01,0x0b,0x06,0x01,0x01,0x01,0x01,
	0x01,0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x08,
	0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x0b,0x0c,0x02,
	0x01,0x01,0x01,0x08,0x01,0x01,0x06,0x01,0x01,0x0a,
	0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0d,0x01,0x01,
	0x09,0x02,0x01,0x01,0x01,0x06,0x01,0x01,0x01,0x01,
	0x06,0x01,0x01,0x01,0x01,0x08,0x01,0x05,0x02,0x01,
	0x01,0x12,0x01,0x01,0x09,0x01,0x01,0x02,0x01,0x05,
	0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x03,0x02,
	0x01,0x03,0x01,0x0c,0x01,0x05,0x01,0x12,0x01,0x03,
	0x01,0x08,0x01,0x02,0x01,0x01,0x01,0x12,0x01,0x01,
	0x01,0x83,0x47,0x01,0x02,0x01,0x00,

/* November */
	0x01,0x37,0x01,0x01,0x04,0x36,0x09,0x35,0x01,0x01,
	0x08,0x32,0x01,0x01,0x0a,0x32,0x0a,0x34,0x0b,0x2c,
	0x0b,0x0d,0x03,0x01,0x02,0x0b,0x01,0x0c,0x0e,0x0d,
	0x04,0x0c,0x01,0x01,0x01,0x0a,0x10,0x09,0x01,0x01,
	0x05,0x09,0x02,0x0c,0x11,0x08,0x05,0x01,0x02,0x05,
	0x02,0x02,0x03,0x0a,0x08,0x01,0x08,0x09,0x05,0x02,
	0x01,0x05,0x03,0x01,0x01,0x01,0x01,0x0a,0x08,0x01,
	0x08,0x09,0x05,0x08,0x05,0x09,0x01,0x02,0x06,0x03,
	0x07,0x0a,0x04,0x09,0x04,0x09,0x04,0x01,0x05,0x03,
	0x07,0x09,0x05,0x08,0x05,0x0a,0x09,0x03,0x06,0x0a,
	0x04,0x0a,0x04,0x0a,0x09,0x03,0x05,0x0a,0x05,0x0a,
	0x04,0x0a,0x10,0x0b,0x05,0x0a,0x04,0x0a,0x06,0x01,
	0x01,0x01,0x07,0x0b,0x05,0x0b,0x05,0x09,0x06,0x04,
	0x06,0x0b,0x06,0x0a,0x05,0x09,0x07,0x04,0x05,0x0b,
	0x06,0x0b,0x04,0x07,0x0a,0x02,0x05,0x0c,0x06,0x0b,
	0x04,0x06,0x0b,0x03,0x05,0x0c,0x06,0x0c,0x04,0x06,
	0x04,0x01,0x0c,0x0c,0x07,0x0b,0x04,0x06,0x03,0x02,
	0x07,0x02,0x05,0x0c,0x07,0x0d,0x01,0x05,0x04,0x0b,
	0x06,0x0d,0x08,0x22,0x07,0x35,0x01,0x02,0x01,0x07,
	0x03,0x41,0x01,0x01,0x01,0x42,0x01,0x01,0x01,0x01,
	0x01,0x40,0x02,0x01,0x01,0x45,0x03,0x43,0x03,0x3b,
	0x07,0x2f,0x01,0x01,0x0b,0x0b,0x02,0x01,0x05,0x16,
	0x01,0x02,0x0c,0x0b,0x08,0x09,0x05,0x09,0x0d,0x09,
	0x08,0x08,0x01,0x01,0x04,0x09,0x0d,0x09,0x08,0x08,
	0x04,0x0b,0x0d,0x09,0x04,0x01,0x02,0x06,0x06,0x09,
	0x01,0x02,0x0d,0x08,0x05,0x01,0x01,0x06,0x05,0x01,
	0x01,0x06,0x01,0x01,0x02,0x05,0x09,0x08,0x04,0x02,
	0x01,0x05,0x06,0x08,0x03,0x06,0x08,0x08,0x04,0x08,
	0x06,0x08,0x04,0x05,0x08,0x07,0x05,0x08,0x06,0x07,
	0x02,0x01,0x01,0x05,0x08,0x04,0x01,0x02,0x05,0x07,
	0x06,0x07,0x02,0x07,0x07,0x05,0x01,0x02,0x04,0x08,
	0x05,0x07,0x03,0x07,0x07,0x05,0x01,0x02,0x04,0x05,
	0x01,0x02,0x04,0x08,0x03,0x07,0x07,0x04,0x01,0x03,
	0x04,0x04,0x01,0x03,0x04,0x08,0x02,0x07,0x07,0x04,
	0x01,0x03,0x04,0x04,0x01,0x03,0x04,0x08,0x02,0x01,
	0x01,0x04,0x07,0x05,0x01,0x03,0x03,0x05,0x01,0x03,
	0x04,0x09,0x03,0x02,0x09,0x04,0x01,0x04,0x03,0x04,
	0x02,0x04,0x03,0x0a,0x02,0x03,0x07,0x0b,0x02,0x01,
	0x01,0x02,0x01,0x01,0x01,0x18,0x0c,0x14,0x02,0x02,
	0x01,0x0b,0x0b,0x24,0x0c,0x14,0x01,0x11,0x0a,0x14,
	0x02,0x10,0x0b,0x26,0x0a,0x27,0x0a,0x27,0x0a,0x27,
	0x0b,0x14,0x01,0x04,0x01,0x0e,0x0a,0x14,0x01,0x02,
	0x01,0x02,0x01,0x0d,0x0b,0x14,0x01,0x04,0x02,0x0d,
	0x0c,0x14,0x01,0x01,0x05,0x0e,0x0b,0x14,0x07,0x10,
	0x0a,0x16,0x06,0x12,0x09,0x17,0x05,0x13,0x09,0x32,
	0x09,0x1a,0x01,0x18,0x07,0x39,0x01,0x01,0x01,0x02,
	0x01,0x39,0x08,0x36,0x07,0x11,0x04,0x19,0x01,0x03,
	0x0b,0x0b,0x09,0x0a,0x04,0x0a,0x09,0x02,0x07,0x0a,
	0x09,0x09,0x04,0x0a,0x08,0x04,0x08,0x0a,0x09,0x09,
	0x04,0x0a,0x08,0x08,0x05,0x0a,0x09,0x08,0x06,0x09,
	0x08,0x08,0x08,0x09,0x09,0x05,0x09,0x09,0x08,0x07,
	0x0b,0x09,0x06,0x08,0x09,0x0a,0x04,0x0a,0x0d,0x0a,
	0x04,0x03,0x02,0x05,0x02,0x03,0x03,0x0a,0x04,0x0a,
	0x09,0x02,0x04,0x0a,0x05,0x02,0x02,0x05,0x03,0x02,
	0x04,0x0a,0x04,0x0a,0x08,0x03,0x05,0x0a,0x04,0x02,
	0x02,0x06,0x02,0x03,0x03,0x0a,0x04,0x0a,0x03,0x01,
	0x04,0x04,0x07,0x0a,0x05,0x01,0x02,0x06,0x03,0x02,
	0x03,0x0b,0x03,0x03,0x02,0x05,0x02,0x03,0x03,0x05,
	0x07,0x0a,0x04,0x02,0x02,0x06,0x03,0x02,0x03,0x0b,
	0x03,0x04,0x01,0x05,0x03,0x03,0x02,0x06,0x08,0x0a,
	0x04,0x03,0x02,0x05,0x03,0x02,0x04,0x0a,0x04,0x04,
	0x01,0x05,0x02,0x04,0x02,0x05,0x03,0x01,0x06,0x0b,
	0x04,0x01,0x03,0x05,0x03,0x02,0x04,0x0a,0x04,0x0a,
	0x02,0x03,0x02,0x09,0x02,0x01,0x06,0x0b,0x04,0x0a,
	0x03,0x02,0x03,0x0a,0x04,0x0a,0x02,0x0e,0x06,0x03,
	0x03,0x0b,0x03,0x03,0x02,0x05,0x02,0x04,0x02,0x0b,
	0x03,0x0b,0x02,0x04,0x01,0x0b,0x03,0x05,0x01,0x0e,
	0x04,0x02,0x01,0x0c,0x03,0x0b,0x03,0x0c,0x01,0x03,
	0x01,0x0d,0x02,0x0a,0x02,0x0b,0x04,0x03,0x01,0x0c,
	0x02,0x0b,0x03,0x1d,0x02,0x0e,0x02,0x0a,0x04,0x0f,
	0x03,0x0c,0x02,0x0f,0x01,0x13,0x01,0x0c,0x02,0x0a,
	0x04,0x0a,0x02,0x03,0x03,0x0b,0x02,0x11,0x01,0x0d,
	0x01,0x21,0x03,0x0b,0x01,0x05,0x01,0x0c,0x01,0x00,

/* Oscar */
	0x01,0x07,0x02,0x09,0x03,0x1a,0x02,0x04,0x06,0x04,
	0x04,0x05,0x01,0x05,0x02,0x05,0x03,0x11,0x02,0x06,
	0x03,0x02,0x01,0x02,0x05,0x05,0x04,0x04,0x02,0x04,
	0x03,0x04,0x04,0x10,0x03,0x04,0x08,0x04,0x04,0x05,
	0x02,0x03,0x03,0x05,0x03,0x05,0x02,0x08,0x04,0x04,
	0x06,0x05,0x04,0x04,0x02,0x04,0x02,0x05,0x04,0x06,
	0x02,0x06,0x04,0x04,0x05,0x05,0x04,0x04,0x02,0x03,
	0x04,0x04,0x04,0x08,0x01,0x06,0x04,0x03,0x05,0x04,
	0x04,0x04,0x02,0x04,0x03,0x05,0x03,0x06,0x01,0x08,
	0x04,0x03,0x04,0x04,0x04,0x04,0x03,0x04,0x03,0x04,
	0x03,0x05,0x02,0x08,0x04,0x03,0x04,0x04,0x04,0x04,
	0x02,0x04,0x03,0x04,0x04,0x04,0x02,0x08,0x04,0x03,
	0x04,0x04,0x04,0x04,0x02,0x03,0x04,0x04,0x03,0x04,
	0x03,0x07,0x05,0x02,0x02,0x05,0x04,0x04,0x02,0x04,
	0x03,0x03,0x04,0x04,0x04,0x06,0x05,0x01,0x03,0x04,
	0x04,0x04,0x03,0x03,0x03,0x04,0x03,0x05,0x03,0x07,
	0x05,0x01,0x02,0x04,0x04,0x04,0x02,0x03,0x04,0x04,
	0x03,0x07,0x04,0x04,0x07,0x05,0x04,0x08,0x04,0x04,
	0x03,0x08,0x03,0x04,0x08,0x04,0x05,0x02,0x01,0x04,
	0x04,0x05,0x01,0x03,0x02,0x05,0x03,0x04,0x07,0x04,
	0x05,0x01,0x02,0x04,0x05,0x02,0x01,0x05,0x03,0x04,
	0x01,0x05,0x07,0x05,0x03,0x01,0x04,0x04,0x03,0x01,
	0x04,0x04,0x03,0x04,0x01,0x03,0x01,0x04,0x05,0x06,
	0x06,0x06,0x06,0x06,0x02,0x04,0x05,0x04,0x06,0x08,
	0x04,0x0a,0x01,0x01,0x01,0x09,0x06,0x04,0x07,0x0b,
	0x02,0x01,0x01,0x08,0x05,0x08,0x04,0x06,0x09,0x16,
	0x05,0x06,0x01,0x0b,0x01,0x02,0x02,0x06,0x01,0x01,
	0x05,0x22,0x01,0x01,0x01,0x0e,0x01,0x01,0x01,0x01,
	0x01,0x04,0x01,0x01,0x02,0x03,0x01,0x01,0x01,0x09,
	0x01,0x0b,0x01,0x07,0x01,0x01,0x01,0x0a,0x01,0x09,
	0x01,0x01,0x01,0x02,0x04,0x01,0x01,0x07,0x01,0x01,
	0x01,0x01,0x01,0x06,0x01,0x08,0x01,0x01,0x01,0x02,
	0x01,0x09,0x01,0x02,0x01,0x06,0x04,0x04,0x02,0x01,
	0x01,0x06,0x01,0x06,0x04,0x01,0x01,0x0e,0x02,0x02,
	0x01,0x11,0x01,0x02,0x01,0x03,0x01,0x01,0x01,0x06,
	0x01,0x04,0x01,0x03,0x01,0x02,0x01,0x04,0x03,0x04,
	0x01,0x01,0x02,0x03,0x01,0x01,0x01,0x03,0x01,0x02,
	0x01,0x01,0x01,0x0f,0x01,0x05,0x01,0x06,0x01,0x01,
	0x03,0x01,0x01,0x01,0x01,0x04,0x01,0x0d,0x01,0x05,
	0x01,0x07,0x01,0x0b,0x01,0x0c,0x01,0x06,0x01,0x01,
	0x01,0x02,0x01,0x01,0x01,0x08,0x01,0x01,0x01,0x01,
	0x01,0x01,0x01,0x01,0x01,0x03,0x01,0x02,0x01,0x0b,
	0x01,0x03,0x01,0x06,0x01,0x0e,0x01,0x01,0x01,0x02,
	0x01,0x06,0x01,0x08,0x01,0x01,0x01,0x01,0x01,0x01,
	0x01,0x01,0x01,0x04,0x01,0x09,0x01,0x06,0x01,0x01,
	0x03,0x0d,0x01,0x04,0x01,0x02,0x01,0x01,0x02,0x07,
	0x01,0x01,0x02,0x01,0x01,0x04,0x01,0x02,0x01,0x02,
	0x02,0x0b,0x01,0x14,0x01,0x04,0x01,0x0c,0x01,0x03,
	0x01,0x08,0x01,0x05,0x01,0x01,0x01,0x01,0x01,0x08,
	0x01,0x09,0x01,0x0c,0x01,0x01,0x01,0x02,0x01,0x01,
	0x01,0x01,0x01,0x09,0x01,0x01,0x01,0x03,0x01,0x04,
	0x01,0x09,0x01,0x01,0x01,0x04,0x01,0x01,0x01,0x03,
	0x01,0x06,0x02,0x03,0x01,0x04,0x01,0x01,0x01,0x01,
	0x01,0x09,0x01,0x01,0x01,0x01,0x01,0x0f,0x02,0x08,
	0x01,0x0b,0x01,0x07,0x01,0x06,0x01,0x05,0x01,0x24,
	0x01,0x81,0xe1,0x01,0x27,0x01,0x34,0x05,0x0e,0x07,
	0x1b,0x09,0x0c,0x08,0x0b,0x03,0x0b,0x08,0x01,0x06,
	0x0c,0x07,0x09,0x01,0x01,0x04,0x0a,0x07,0x07,0x07,
	0x0a,0x07,0x09,0x07,0x0a,0x05,0x09,0x0c,0x09,0x06,
	0x01,0x01,0x08,0x06,0x08,0x03,0x01,0x03,0x0a,0x08,
	0x05,0x05,0x09,0x08,0x0a,0x05,0x09,0x01,0x03,0x02,
	0x0b,0x04,0x01,0x01,0x07,0x07,0x09,0x09,0x09,0x05,
	0x09,0x02,0x02,0x03,0x0a,0x04,0x01,0x02,0x09,0x07,
	0x09,0x08,0x0a,0x04,0x0b,0x01,0x01,0x03,0x0a,0x05,
	0x0b,0x09,0x0a,0x03,0x01,0x03,0x0a,0x04,0x0c,0x05,
	0x0a,0x03,0x01,0x01,0x09,0x01,0x01,0x04,0x04,0x01,
	0x01,0x02,0x09,0x03,0x02,0x03,0x0a,0x03,0x0e,0x03,
	0x0a,0x01,0x04,0x01,0x0b,0x04,0x09,0x04,0x09,0x03,
	0x01,0x04,0x09,0x04,0x0d,0x04,0x0a,0x02,0x0f,0x03,
	0x0c,0x05,0x0a,0x03,0x02,0x02,0x0b,0x03,0x0a,0x01,
	0x03,0x02,0x0b,0x02,0x26,0x02,0x0a,0x02,0x0f,0x03,
	0x00,

/* Papa */
	0x1a,0x06,0x01,0x01,0x01,0x20,0x02,0x03,0x03,0x02,
	0x07,0x17,0x0b,0x1c,0x01,0x15,0x01,0x01,0x01,0x0a,
	0x01,0x01,0x01,0x11,0x01,0x05,0x01,0x01,0x02,0x24,
	0x01,0x0e,0x01,0x07,0x01,0x13,0x01,0x05,0x01,0x17,
	0x0d,0x06,0x03,0x04,0x02,0x04,0x03,0x04,0x03,0x04,
	0x09,0x05,0x04,0x04,0x03,0x04,0x03,0x04,0x02,0x04,
	0x05,0x01,0x04,0x06,0x03,0x04,0x02,0x04,0x03,0x04,
	0x03,0x04,0x04,0x03,0x04,0x05,0x04,0x04,0x02,0x04,
	0x03,0x04,0x03,0x04,0x04,0x03,0x04,0x05,0x03,0x04,
	0x02,0x04,0x03,0x04,0x04,0x03,0x05,0x03,0x04,0x05,
	0x03,0x04,0x02,0x04,0x03,0x04,0x03,0x04,0x04,0x03,
	0x05,0x04,0x04,0x03,0x03,0x04,0x03,0x04,0x03,0x04,
	0x04,0x04,0x04,0x05,0x03,0x04,0x03,0x03,0x03,0x04,
	0x04,0x03,0x04,0x04,0x05,0x04,0x04,0x03,0x03,0x03,
	0x04,0x03,0x04,0x04,0x03,0x04,0x05,0x04,0x04,0x03,
	0x03,0x04,0x03,0x04,0x03,0x03,0x04,0x04,0x05,0x04,
	0x04,0x04,0x03,0x03,0x03,0x04,0x03,0x04,0x04,0x03,
	0x05,0x04,0x04,0x04,0x03,0x03,0x03,0x04,0x03,0x04,
	0x04,0x04,0x05,0x04,0x04,0x04,0x02,0x04,0x03,0x03,
	0x04,0x03,0x04,0x04,0x06,0x04,0x04,0x03,0x03,0x03,
	0x03,0x04,0x03,0x04,0x04,0x04,0x05,0x05,0x03,0x04,
	0x03,0x03,0x03,0x04,0x03,0x04,0x04,0x04,0x06,0x04,
	0x04,0x04,0x02,0x03,0x04,0x03,0x04,0x04,0x04,0x04,
	0x05,0x04,0x04,0x04,0x02,0x04,0x03,0x04,0x03,0x04,
	0x03,0x04,0x06,0x04,0x04,0x04,0x02,0x04,0x03,0x04,
	0x03,0x04,0x04,0x03,0x06,0x04,0x04,0x04,0x02,0x04,
	0x03,0x04,0x04,0x03,0x0d,0x04,0x04,0x04,0x03,0x03,
	0x03,0x05,0x03,0x04,0x03,0x01,0x08,0x05,0x04,0x04,
	0x02,0x04,0x03,0x09,0x04,0x03,0x04,0x01,0x04,0x05,
	0x03,0x03,0x04,0x04,0x01,0x04,0x02,0x0d,0x01,0x04,
	0x04,0x22,0x01,0x14,0x01,0x16,0x02,0x82,0x9e,0x0b,
	0x0b,0x05,0x0b,0x02,0x0b,0x09,0x07,0x09,0x05,0x08,
	0x07,0x04,0x02,0x01,0x05,0x08,0x06,0x09,0x05,0x05,
	0x09,0x04,0x09,0x04,0x03,0x09,0x06,0x03,0x02,0x04,
	0x04,0x05,0x09,0x04,0x09,0x04,0x04,0x03,0x03,0x06,
	0x06,0x04,0x01,0x04,0x05,0x04,0x09,0x04,0x0a,0x03,
	0x0a,0x04,0x02,0x06,0x05,0x03,0x02,0x04,0x04,0x04,
	0x09,0x04,0x05,0x01,0x04,0x03,0x05,0x02,0x04,0x03,
	0x03,0x08,0x05,0x04,0x04,0x01,0x04,0x04,0x09,0x04,
	0x05,0x01,0x04,0x03,0x04,0x04,0x03,0x03,0x04,0x02,
	0x03,0x05,0x05,0x04,0x02,0x03,0x05,0x04,0x02,0x01,
	0x05,0x04,0x0a,0x03,0x05,0x01,0x04,0x03,0x04,0x03,
	0x03,0x05,0x01,0x02,0x05,0x03,0x05,0x01,0x04,0x04,
	0x09,0x04,0x05,0x01,0x03,0x03,0x05,0x03,0x0a,0x03,
	0x03,0x04,0x02,0x04,0x05,0x04,0x02,0x01,0x01,0x01,
	0x05,0x03,0x03,0x01,0x05,0x04,0x05,0x01,0x04,0x03,
	0x05,0x02,0x0a,0x03,0x04,0x03,0x03,0x06,0x06,0x03,
	0x03,0x01,0x06,0x04,0x08,0x04,0x05,0x01,0x04,0x03,
	0x06,0x01,0x0b,0x02,0x04,0x02,0x06,0x01,0x02,0x04,
	0x05,0x04,0x03,0x01,0x06,0x03,0x0a,0x03,0x0a,0x03,
	0x12,0x02,0x04,0x01,0x0c,0x02,0x0a,0x02,0x03,0x01,
	0x06,0x04,0x09,0x03,0x0a,0x02,0x0c,0x01,0x0c,0x02,
	0x00,

/* Quebec */
	0x02,0x0d,0x01,0x13,0x04,0x80,0x83,0x03,0x81,0x5c,
	0x01,0x02,0x01,0x18,0x04,0x08,0x0d,0x0b,0x08,0x0b,
	0x06,0x07,0x09,0x0b,0x07,0x0a,0x07,0x07,0x09,0x0a,
	0x07,0x0a,0x06,0x09,0x07,0x0a,0x07,0x09,0x07,0x09,
	0x08,0x08,0x08,0x08,0x07,0x09,0x0a,0x08,0x08,0x07,
	0x08,0x0a,0x0c,0x0a,0x05,0x0a,0x04,0x0a,0x05,0x02,
	0x08,0x09,0x06,0x08,0x05,0x0a,0x0f,0x0a,0x05,0x08,
	0x05,0x0a,0x05,0x01,0x04,0x01,0x05,0x0a,0x04,0x09,
	0x05,0x09,0x06,0x01,0x03,0x03,0x04,0x0a,0x05,0x09,
	0x05,0x0a,0x09,0x03,0x05,0x0a,0x05,0x0a,0x05,0x0b,
	0x09,0x02,0x04,0x0d,0x05,0x01,0x05,0x1f,0x08,0x36,
	0x01,0x01,0x01,0x23,0x04,0x16,0x01,0x01,0x07,0x3b,
	0x01,0x41,0x03,0x01,0x04,0x3f,0x01,0x4a,0x01,0x80,
	0xcd,0x02,0x01,0x08,0x0e,0x04,0x15,0x01,0x02,0x0a,
	0x0a,0x08,0x09,0x06,0x09,0x0d,0x09,0x07,0x08,0x06,
	0x09,0x09,0x02,0x06,0x08,0x07,0x08,0x05,0x0a,0x07,
	0x04,0x06,0x08,0x07,0x08,0x05,0x08,0x08,0x04,0x06,
	0x08,0x07,0x06,0x07,0x08,0x05,0x01,0x02,0x01,0x01,
	0x02,0x05,0x08,0x07,0x06,0x07,0x08,0x05,0x05,0x06,
	0x07,0x08,0x06,0x07,0x06,0x06,0x05,0x06,0x08,0x06,
	0x07,0x07,0x05,0x05,0x01,0x01,0x05,0x06,0x07,0x06,
	0x07,0x05,0x08,0x05,0x01,0x01,0x05,0x05,0x07,0x06,
	0x06,0x06,0x08,0x05,0x01,0x01,0x04,0x06,0x07,0x06,
	0x06,0x06,0x07,0x05,0x05,0x08,0x07,0x05,0x06,0x07,
	0x06,0x03,0x08,0x08,0x07,0x04,0x06,0x08,0x06,0x04,
	0x08,0x07,0x08,0x03,0x01,0x01,0x05,0x05,0x01,0x02,
	0x04,0x01,0x03,0x01,0x04,0x01,0x05,0x07,0x05,0x01,
	0x01,0x04,0x07,0x07,0x06,0x01,0x08,0x01,0x04,0x08,
	0x05,0x01,0x01,0x04,0x07,0x05,0x01,0x01,0x05,0x03,
	0x06,0x02,0x05,0x08,0x05,0x01,0x01,0x04,0x07,0x05,
	0x01,0x01,0x05,0x02,0x08,0x01,0x05,0x0b,0x04,0x01,
	0x02,0x02,0x08,0x04,0x02,0x01,0x04,0x03,0x07,0x03,
	0x07,0x03,0x01,0x05,0x05,0x01,0x01,0x03,0x07,0x03,
	0x01,0x01,0x02,0x01,0x03,0x01,0x01,0x02,0x08,0x02,
	0x02,0x01,0x04,0x03,0x03,0x06,0x05,0x01,0x02,0x02,
	0x04,0x01,0x03,0x04,0x08,0x01,0x0d,0x02,0x04,0x01,
	0x04,0x07,0x01,0x03,0x04,0x01,0x01,0x01,0x01,0x02,
	0x03,0x01,0x04,0x03,0x08,0x03,0x01,0x01,0x06,0x01,
	0x09,0x01,0x05,0x01,0x01,0x04,0x01,0x06,0x07,0x01,
	0x01,0x01,0x01,0x01,0x06,0x04,0x01,0x01,0x08,0x01,
	0x01,0x01,0x08,0x02,0x0e,0x01,0x0a,0x07,0x06,0x01,
	0x01,0x02,0x01,0x01,0x01,0x01,0x06,0x05,0x08,0x03,
	0x0d,0x01,0x18,0x01,0x00,

/* Romeo */
	0x04,0x40,0x06,0x3f,0x01,0x01,0x06,0x12,0x04,0x28,
	0x01,0x01,0x06,0x10,0x08,0x11,0x06,0x09,0x01,0x01,
	0x09,0x0f,0x07,0x0f,0x08,0x05,0x01,0x01,0x0a,0x0d,
	0x0a,0x0e,0x07,0x08,0x08,0x0c,0x0a,0x0c,0x07,0x04,
	0x0d,0x0b,0x0a,0x09,0x07,0x07,0x0c,0x0a,0x07,0x0a,
	0x05,0x09,0x0d,0x0b,0x06,0x0a,0x05,0x09,0x0e,0x07,
	0x01,0x03,0x05,0x0a,0x04,0x09,0x0e,0x0a,0x05,0x09,
	0x05,0x0a,0x0e,0x06,0x01,0x03,0x05,0x05,0x09,0x09,
	0x0e,0x06,0x01,0x01,0x01,0x02,0x04,0x05,0x09,0x07,
	0x10,0x05,0x04,0x01,0x05,0x05,0x05,0x02,0x02,0x06,
	0x0f,0x06,0x09,0x06,0x05,0x0a,0x0d,0x07,0x08,0x06,
	0x06,0x09,0x0d,0x07,0x08,0x07,0x05,0x0a,0x0c,0x07,
	0x09,0x06,0x05,0x0a,0x0c,0x07,0x09,0x06,0x05,0x0b,
	0x0b,0x07,0x09,0x07,0x04,0x0b,0x0a,0x07,0x09,0x08,
	0x04,0x0b,0x0a,0x07,0x08,0x08,0x05,0x0b,0x09,0x08,
	0x08,0x08,0x04,0x0d,0x08,0x08,0x08,0x08,0x04,0x0d,
	0x09,0x07,0x08,0x07,0x05,0x0d,0x09,0x07,0x01,0x01,
	0x08,0x06,0x05,0x0c,0x09,0x0a,0x08,0x07,0x03,0x0d,
	0x09,0x0d,0x05,0x0e,0x02,0x07,0x0a,0x0e,0x02,0x06,
	0x02,0x14,0x0a,0x01,0x01,0x19,0x03,0x0d,0x0a,0x19,
	0x03,0x0d,0x0b,0x18,0x04,0x0d,0x0a,0x19,0x04,0x0c,
	0x0b,0x19,0x03,0x0e,0x09,0x2b,0x0a,0x0e,0x03,0x05,
	0x01,0x13,0x0b,0x0e,0x06,0x02,0x01,0x15,0x0a,0x01,
	0x01,0x0c,0x03,0x01,0x02,0x01,0x01,0x03,0x01,0x03,
	0x01,0x0d,0x0b,0x02,0x01,0x0b,0x03,0x01,0x02,0x01,
	0x02,0x02,0x01,0x02,0x01,0x0f,0x01,0x01,0x0a,0x01,
	0x01,0x0b,0x01,0x01,0x03,0x01,0x02,0x02,0x01,0x02,
	0x01,0x0f,0x01,0x01,0x0b,0x01,0x02,0x01,0x01,0x06,
	0x01,0x01,0x02,0x01,0x05,0x02,0x01,0x02,0x01,0x12,
	0x01,0x01,0x0a,0x01,0x01,0x02,0x01,0x08,0x01,0x01,
	0x02,0x01,0x03,0x01,0x02,0x01,0x01,0x02,0x01,0x01,
	0x01,0x0e,0x0f,0x01,0x01,0x0b,0x01,0x01,0x07,0x01,
	0x01,0x01,0x01,0x10,0x01,0x01,0x0c,0x01,0x01,0x02,
	0x01,0x08,0x01,0x01,0x02,0x01,0x06,0x01,0x01,0x10,
	0x01,0x01,0x01,0x01,0x01,0x01,0x0b,0x01,0x02,0x01,
	0x01,0x0b,0x02,0x01,0x06,0x01,0x01,0x04,0x01,0x0a,
	0x01,0x04,0x01,0x01,0x0c,0x01,0x02,0x01,0x01,0x08,
	0x01,0x02,0x01,0x01,0x06,0x04,0x01,0x06,0x01,0x0d,
	0x0c,0x01,0x01,0x02,0x01,0x08,0x01,0x02,0x08,0x04,
	0x01,0x06,0x01,0x0d,0x0c,0x02,0x01,0x0b,0x01,0x01,
	0x06,0x01,0x01,0x0b,0x02,0x01,0x01,0x08,0x02,0x01,
	0x0c,0x02,0x01,0x0b,0x08,0x0e,0x01,0x01,0x01,0x09,
	0x01,0x01,0x0d,0x0b,0x01,0x01,0x08,0x0c,0x01,0x0d,
	0x0f,0x02,0x01,0x09,0x01,0x01,0x08,0x09,0x01,0x01,
	0x02,0x0b,0x08,0x05,0x06,0x01,0x02,0x08,0x08,0x01,
	0x01,0x08,0x06,0x0a,0x07,0x07,0x06,0x01,0x02,0x08,
	0x07,0x09,0x06,0x0a,0x07,0x08,0x08,0x09,0x01,0x01,
	0x06,0x08,0x07,0x09,0x06,0x09,0x0c,0x09,0x06,0x08,
	0x06,0x0a,0x04,0x01,0x01,0x0a,0x09,0x02,0x04,0x09,
	0x06,0x08,0x01,0x01,0x04,0x08,0x06,0x09,0x06,0x01,
	0x01,0x05,0x06,0x09,0x06,0x07,0x07,0x08,0x05,0x08,
	0x05,0x0a,0x08,0x05,0x01,0x02,0x05,0x09,0x05,0x08,
	0x06,0x09,0x05,0x09,0x0a,0x05,0x01,0x02,0x01,0x01,
	0x03,0x09,0x05,0x09,0x04,0x08,0x05,0x08,0x0e,0x05,
	0x01,0x03,0x04,0x0a,0x04,0x09,0x04,0x09,0x03,0x09,
	0x05,0x01,0x08,0x05,0x01,0x01,0x01,0x02,0x04,0x09,
	0x04,0x09,0x04,0x0a,0x03,0x0a,0x04,0x03,0x07,0x07,
	0x01,0x01,0x04,0x0a,0x04,0x09,0x05,0x09,0x04,0x0b,
	0x03,0x04,0x06,0x0a,0x05,0x08,0x05,0x0a,0x04,0x0a,
	0x03,0x0b,0x04,0x04,0x06,0x08,0x01,0x01,0x05,0x06,
	0x01,0x01,0x06,0x0a,0x04,0x0b,0x04,0x0b,0x04,0x03,
	0x06,0x0a,0x05,0x0a,0x04,0x0a,0x05,0x0a,0x04,0x0b,
	0x06,0x03,0x04,0x07,0x01,0x03,0x04,0x08,0x01,0x01,
	0x05,0x09,0x03,0x01,0x02,0x08,0x07,0x08,0x0a,0x03,
	0x02,0x07,0x02,0x02,0x05,0x07,0x03,0x02,0x04,0x07,
	0x03,0x0d,0x03,0x0c,0x0b,0x09,0x01,0x02,0x06,0x07,
	0x09,0x08,0x04,0x0c,0x05,0x0b,0x0a,0x08,0x09,0x09,
	0x06,0x0b,0x05,0x0b,0x05,0x0b,0x07,0x0d,0x07,0x0a,
	0x05,0x0c,0x05,0x0c,0x05,0x0a,0x08,0x0b,0x08,0x0a,
	0x06,0x0c,0x04,0x0e,0x04,0x0a,0x08,0x0a,0x08,0x0b,
	0x05,0x0e,0x01,0x0c,0x05,0x0c,0x06,0x0c,0x05,0x0d,
	0x04,0x0b,0x02,0x0e,0x01,0x01,0x02,0x26,0x01,0x00,

/* Sierra */
	0x01,0x80,0xce,0x01,0x15,0x01,0x25,0x01,0x25,0x01,
	0x01,0x01,0x14,0x01,0x0a,0x01,0x0a,0x01,0x03,0x01,
	0x06,0x01,0x07,0x01,0x01,0x01,0x01,0x01,0x0c,0x01,
	0x0b,0x01,0x13,0x01,0x07,0x02,0x03,0x01,0x01,0x01,
	0x04,0x01,0x13,0x01,0x04,0x01,0x0b,0x01,0x3b,0x01,
	0x0c,0x02,0x06,0x01,0x06,0x01,0x02,0x01,0x03,0x01,
	0x2a,0x01,0x07,0x01,0x06,0x01,0x04,0x01,0x10,0x01,
	0x09,0x01,0x01,0x01,0x01,0x01,0x05,0x01,0x01,0x01,
	0x02,0x01,0x09,0x01,0x03,0x01,0x09,0x01,0x03,0x01,
	0x03,0x01,0x01,0x01,0x05,0x01,0x02,0x02,0x04,0x01,
	0x07,0x01,0x07,0x01,0x1a,0x01,0x05,0x01,0x06,0x01,
	0x10,0x01,0x0a,0x02,0x06,0x01,0x06,0x01,0x04,0x01,
	0x04,0x01,0x0b,0x01,0x05,0x03,0x06,0x01,0x0b,0x01,
	0x0e,0x01,0x08,0x01,0x01,0x01,0x06,0x01,0x02,0x01,
	0x18,0x01,0x01,0x01,0x6e,0x01,0x1b,0x09,0x04,0x01,
	0x01,0x06,0x01,0x01,0x0f,0x08,0x0d,0x0d,0x11,0x08,
	0x0e,0x0d,0x02,0x01,0x0c,0x01,0x01,0x08,0x0e,0x0e,
	0x01,0x02,0x0e,0x09,0x0d,0x0f,0x01,0x01,0x0e,0x09,
	0x0e,0x01,0x01,0x0d,0x01,0x02,0x0d,0x09,0x01,0x01,
	0x0e,0x0d,0x02,0x01,0x0e,0x08,0x01,0x02,0x0d,0x0f,
	0x01,0x01,0x02,0x01,0x0b,0x0a,0x0f,0x0e,0x01,0x02,
	0x0d,0x02,0x01,0x08,0x0e,0x0f,0x01,0x02,0x0e,0x0a,
	0x0e,0x10,0x01,0x01,0x02,0x01,0x0b,0x09,0x0f,0x10,
	0x02,0x01,0x0d,0x09,0x10,0x0f,0x02,0x01,0x02,0x01,
	0x09,0x01,0x01,0x08,0x0e,0x01,0x01,0x10,0x01,0x01,
	0x02,0x01,0x09,0x01,0x01,0x08,0x0e,0x11,0x02,0x01,
	0x0b,0x01,0x02,0x08,0x0d,0x12,0x01,0x02,0x01,0x01,
	0x09,0x01,0x01,0x08,0x0c,0x01,0x01,0x05,0x01,0x01,
	0x02,0x08,0x01,0x02,0x0b,0x09,0x0c,0x06,0x06,0x08,
	0x01,0x02,0x0a,0x09,0x0b,0x06,0x08,0x08,0x01,0x01,
	0x09,0x0a,0x09,0x07,0x08,0x09,0x0b,0x08,0x0a,0x06,
	0x0a,0x09,0x0b,0x07,0x09,0x07,0x08,0x0c,0x09,0x04,
	0x01,0x02,0x08,0x02,0x01,0x05,0x0a,0x0c,0x02,0x01,
	0x06,0x01,0x01,0x02,0x01,0x02,0x08,0x01,0x01,0x05,
	0x09,0x01,0x01,0x0c,0x09,0x01,0x01,0x01,0x02,0x01,
	0x08,0x07,0x09,0x02,0x01,0x0b,0x02,0x01,0x06,0x01,
	0x01,0x02,0x01,0x02,0x08,0x05,0x0a,0x02,0x01,0x0b,
	0x02,0x01,0x05,0x02,0x01,0x02,0x01,0x01,0x08,0x05,
	0x09,0x04,0x01,0x0a,0x02,0x01,0x06,0x01,0x01,0x02,
	0x01,0x01,0x08,0x05,0x09,0x04,0x01,0x02,0x01,0x07,
	0x08,0x02,0x01,0x04,0x06,0x07,0x07,0x05,0x02,0x09,
	0x02,0x01,0x04,0x03,0x01,0x04,0x06,0x07,0x08,0x05,
	0x01,0x02,0x01,0x06,0x08,0x02,0x01,0x04,0x06,0x07,
	0x07,0x06,0x01,0x08,0x08,0x02,0x01,0x04,0x06,0x07,
	0x06,0x05,0x04,0x08,0x08,0x02,0x01,0x01,0x01,0x01,
	0x07,0x06,0x06,0x05,0x04,0x07,0x07,0x04,0x01,0x01,
	0x01,0x01,0x06,0x05,0x07,0x05,0x04,0x08,0x08,0x05,
	0x01,0x01,0x04,0x01,0x01,0x05,0x07,0x04,0x06,0x06,
	0x08,0x05,0x07,0x07,0x06,0x05,0x05,0x07,0x08,0x05,
	0x07,0x06,0x06,0x06,0x05,0x07,0x08,0x05,0x07,0x06,
	0x06,0x06,0x05,0x07,0x09,0x04,0x07,0x05,0x08,0x02,
	0x03,0x01,0x04,0x08,0x04,0x01,0x03,0x04,0x08,0x05,
	0x08,0x03,0x02,0x02,0x04,0x08,0x04,0x01,0x03,0x04,
	0x04,0x01,0x03,0x04,0x09,0x03,0x03,0x02,0x03,0x07,
	0x05,0x01,0x03,0x04,0x04,0x01,0x03,0x04,0x09,0x03,
	0x04,0x01,0x04,0x07,0x04,0x01,0x03,0x05,0x08,0x04,
	0x09,0x03,0x09,0x07,0x04,0x01,0x03,0x05,0x05,0x01,
	0x02,0x05,0x09,0x03,0x0a,0x06,0x04,0x01,0x03,0x05,
	0x05,0x01,0x02,0x06,0x08,0x04,0x05,0x02,0x02,0x06,
	0x09,0x05,0x05,0x01,0x03,0x05,0x09,0x03,0x05,0x02,
	0x03,0x06,0x09,0x06,0x08,0x05,0x09,0x04,0x05,0x01,
	0x04,0x06,0x0a,0x05,0x09,0x05,0x0a,0x04,0x02,0x03,
	0x04,0x08,0x09,0x05,0x0a,0x05,0x09,0x04,0x04,0x01,
	0x04,0x0b,0x05,0x01,0x03,0x05,0x0a,0x04,0x0a,0x04,
	0x03,0x02,0x06,0x0b,0x0a,0x05,0x09,0x05,0x0a,0x03,
	0x04,0x01,0x05,0x02,0x03,0x0b,0x05,0x02,0x03,0x05,
	0x09,0x04,0x0a,0x04,0x03,0x02,0x05,0x01,0x04,0x04,
	0x03,0x07,0x0a,0x04,0x0a,0x04,0x0a,0x03,0x04,0x01,
	0x05,0x02,0x03,0x04,0x04,0x09,0x05,0x01,0x03,0x05,
	0x09,0x04,0x09,0x04,0x0a,0x02,0x04,0x02,0x04,0x03,
	0x01,0x08,0x09,0x05,0x09,0x04,0x09,0x03,0x0a,0x03,
	0x04,0x02,0x04,0x0a,0x01,0x03,0x05,0x02,0x02,0x04,
	0x05,0x02,0x02,0x04,0x09,0x03,0x05,0x02,0x03,0x03,
	0x04,0x02,0x04,0x03,0x02,0x04,0x02,0x03,0x05,0x03,
	0x02,0x03,0x05,0x03,0x02,0x03,0x05,0x02,0x03,0x02,
	0x05,0x02,0x04,0x01,0x05,0x02,0x04,0x03,0x04,0x08,
	0x05,0x03,0x02,0x03,0x04,0x04,0x02,0x03,0x04,0x03,
	0x03,0x01,0x05,0x03,0x09,0x02,0x04,0x03,0x07,0x06,
	0x05,0x03,0x01,0x04,0x04,0x04,0x02,0x02,0x06,0x02,
	0x09,0x03,0x09,0x02,0x04,0x04,0x07,0x05,0x05,0x03,
	0x02,0x01,0x01,0x01,0x04,0x04,0x02,0x02,0x05,0x03,
	0x09,0x04,0x09,0x02,0x04,0x02,0x06,0x01,0x01,0x06,
	0x05,0x03,0x02,0x01,0x01,0x01,0x05,0x03,0x09,0x03,
	0x0b,0x02,0x0a,0x02,0x03,0x01,0x0a,0x08,0x04,0x03,
	0x04,0x01,0x05,0x03,0x09,0x03,0x0a,0x01,0x05,0x01,
	0x09,0x04,0x09,0x09,0x05,0x03,0x04,0x01,0x04,0x03,
	0x09,0x04,0x09,0x02,0x05,0x02,0x09,0x03,0x05,0x02,
	0x02,0x02,0x04,0x05,0x05,0x02,0x02,0x01,0x01,0x02,
	0x04,0x03,0x09,0x03,0x0a,0x02,0x11,0x02,0x09,0x02,
	0x05,0x03,0x02,0x01,0x05,0x03,0x0a,0x03,0x09,0x02,
	0x0b,0x02,0x0b,0x01,0x0b,0x01,0x0b,0x03,0x02,0x01,
	0x02,0x01,0x05,0x03,0x04,0x01,0x04,0x03,0x0a,0x02,
	0x0a,0x03,0x2b,0x01,0x03,0x01,0x05,0x03,0x04,0x01,
	0x04,0x03,0x0a,0x03,0x0a,0x02,0x0c,0x01,0x0a,0x01,
	0x0d,0x01,0x0b,0x01,0x05,0x01,0x0b,0x03,0x0a,0x02,
	0x55,0x01,0x00,

/* Tango */
	0x0d,0x1b,0x02,0x06,0x0a,0x08,0x02,0x0b,0x03,0x08,
	0x0d,0x08,0x03,0x08,0x04,0x09,0x0d,0x06,0x01,0x01,
	0x03,0x08,0x04,0x09,0x0e,0x05,0x01,0x01,0x03,0x08,
	0x04,0x07,0x02,0x01,0x0c,0x05,0x02,0x01,0x03,0x07,
	0x05,0x07,0x02,0x01,0x01,0x01,0x09,0x06,0x01,0x01,
	0x03,0x07,0x05,0x08,0x01,0x01,0x01,0x01,0x09,0x08,
	0x02,0x07,0x05,0x08,0x01,0x01,0x02,0x02,0x07,0x08,
	0x02,0x07,0x06,0x07,0x01,0x01,0x02,0x02,0x08,0x07,
	0x02,0x08,0x06,0x08,0x02,0x02,0x08,0x08,0x02,0x07,
	0x06,0x08,0x02,0x02,0x08,0x08,0x02,0x07,0x07,0x08,
	0x01,0x01,0x0a,0x08,0x01,0x03,0x01,0x04,0x01,0x01,
	0x04,0x08,0x01,0x02,0x01,0x01,0x07,0x08,0x02,0x02,
	0x01,0x07,0x03,0x08,0x01,0x02,0x0a,0x08,0x01,0x03,
	0x01,0x06,0x04,0x08,0x01,0x01,0x03,0x01,0x07,0x02,
	0x01,0x05,0x01,0x02,0x01,0x08,0x02,0x02,0x01,0x07,
	0x03,0x01,0x07,0x02,0x01,0x05,0x01,0x02,0x01,0x08,
	0x03,0x01,0x01,0x08,0x02,0x02,0x07,0x02,0x01,0x08,
	0x01,0x08,0x02,0x02,0x01,0x08,0x02,0x01,0x08,0x02,
	0x01,0x08,0x01,0x02,0x01,0x04,0x02,0x01,0x03,0x07,
	0x01,0x03,0x07,0x02,0x01,0x02,0x01,0x09,0x01,0x04,
	0x01,0x01,0x04,0x0a,0x08,0x02,0x01,0x02,0x01,0x05,
	0x01,0x02,0x01,0x02,0x01,0x02,0x01,0x01,0x01,0x01,
	0x01,0x0b,0x08,0x01,0x02,0x0b,0x01,0x02,0x01,0x01,
	0x01,0x01,0x01,0x01,0x02,0x0a,0x08,0x02,0x01,0x0b,
	0x01,0x02,0x01,0x03,0x02,0x01,0x01,0x0b,0x08,0x01,
	0x01,0x02,0x01,0x06,0x01,0x04,0x01,0x02,0x01,0x01,
	0x01,0x01,0x01,0x02,0x01,0x08,0x01,0x02,0x06,0x01,
	0x01,0x02,0x01,0x0b,0x01,0x01,0x02,0x01,0x01,0x01,
	0x01,0x0e,0x06,0x01,0x01,0x02,0x01,0x09,0x01,0x01,
	0x01,0x04,0x01,0x01,0x01,0x01,0x02,0x0b,0x09,0x01,
	0x01,0x09,0x01,0x06,0x01,0x01,0x01,0x02,0x01,0x0b,
	0x01,0x01,0x08,0x11,0x02,0x01,0x02,0x01,0x01,0x0d,
	0x08,0x27,0x09,0x25,0x0a,0x27,0x09,0x11,0x01,0x15,
	0x09,0x11,0x01,0x15,0x0a,0x27,0x0a,0x11,0x01,0x15,
	0x0a,0x27,0x0b,0x10,0x02,0x17,0x09,0x11,0x01,0x01,
	0x01,0x15,0x01,0x01,0x0a,0x15,0x01,0x01,0x02,0x16,
	0x08,0x16,0x05,0x15,0x08,0x1a,0x01,0x19,0x01,0x01,
	0x04,0x3b,0x01,0x1b,0x01,0x1c,0x01,0x08,0x01,0x1a,
	0x02,0x0f,0x02,0x01,0x03,0x07,0x07,0x01,0x01,0x0d,
	0x09,0x12,0x01,0x01,0x04,0x03,0x01,0x01,0x09,0x0e,
	0x09,0x0d,0x01,0x01,0x01,0x06,0x01,0x01,0x0f,0x0b,
	0x09,0x09,0x01,0x01,0x02,0x01,0x01,0x0a,0x08,0x01,
	0x01,0x02,0x05,0x0b,0x08,0x09,0x05,0x0a,0x07,0x07,
	0x07,0x09,0x08,0x08,0x07,0x09,0x07,0x08,0x09,0x09,
	0x07,0x07,0x08,0x09,0x04,0x01,0x01,0x09,0x0e,0x09,
	0x06,0x08,0x06,0x08,0x01,0x01,0x04,0x0b,0x07,0x03,
	0x05,0x09,0x05,0x09,0x06,0x08,0x05,0x08,0x01,0x01,
	0x06,0x07,0x06,0x09,0x05,0x09,0x06,0x08,0x05,0x08,
	0x07,0x06,0x0a,0x05,0x01,0x02,0x05,0x0a,0x05,0x09,
	0x05,0x08,0x06,0x08,0x0a,0x06,0x01,0x02,0x01,0x02,
	0x02,0x0a,0x05,0x09,0x04,0x09,0x04,0x0a,0x05,0x02,
	0x02,0x01,0x03,0x0b,0x04,0x09,0x04,0x0a,0x03,0x0b,
	0x04,0x09,0x04,0x01,0x02,0x04,0x03,0x0b,0x04,0x09,
	0x04,0x0a,0x03,0x0b,0x04,0x0a,0x04,0x01,0x01,0x05,
	0x03,0x0b,0x04,0x0a,0x03,0x0b,0x04,0x0b,0x03,0x0b,
	0x04,0x04,0x05,0x08,0x01,0x02,0x05,0x0a,0x03,0x0b,
	0x04,0x0b,0x04,0x0a,0x05,0x05,0x03,0x0c,0x04,0x0a,
	0x04,0x0b,0x04,0x0b,0x04,0x0a,0x06,0x04,0x03,0x0b,
	0x05,0x0b,0x04,0x0b,0x04,0x0b,0x04,0x0b,0x05,0x04,
	0x03,0x07,0x01,0x03,0x04,0x0c,0x04,0x0c,0x03,0x0c,
	0x03,0x07,0x02,0x01,0x01,0x01,0x05,0x05,0x01,0x08,
	0x01,0x04,0x03,0x08,0x01,0x05,0x02,0x08,0x01,0x05,
	0x01,0x09,0x01,0x02,0x01,0x01,0x01,0x08,0x06,0x01,
	0x02,0x12,0x01,0x01,0x02,0x1a,0x02,0x0e,0x02,0x01,
	0x01,0x0b,0x04,0x14,0x02,0x01,0x02,0x0a,0x02,0x02,
	0x01,0x0b,0x01,0x01,0x01,0x0d,0x04,0x0d,0x04,0x11,
	0x01,0x01,0x01,0x01,0x03,0x1b,0x01,0x0e,0x04,0x0d,
	0x05,0x10,0x01,0x01,0x01,0x01,0x02,0x01,0x01,0x09,
	0x01,0x01,0x01,0x0f,0x01,0x10,0x04,0x0c,0x04,0x12,
	0x01,0x02,0x01,0x58,0x04,0x58,0x02,0x01,0x01,0x00,

/* Uniform */
	0x01,0x01,0x01,0x01,0x04,0x01,0x01,0x18,0x01,0x01,
	0x01,0x17,0x0b,0x01,0x01,0x15,0x01,0x01,0x01,0x01,
	0x02,0x01,0x01,0x13,0x0b,0x03,0x01,0x15,0x04,0x01,
	0x01,0x01,0x01,0x13,0x0c,0x01,0x02,0x01,0x01,0x11,
	0x01,0x01,0x01,0x01,0x03,0x02,0x01,0x11,0x0d,0x01,
	0x01,0x11,0x01,0x01,0x08,0x10,0x0e,0x01,0x01,0x11,
	0x0a,0x0f,0x0d,0x02,0x01,0x0e,0x01,0x01,0x09,0x0e,
	0x0e,0x11,0x0b,0x0e,0x0c,0x01,0x01,0x0f,0x09,0x01,
	0x01,0x0c,0x0c,0x01,0x01,0x0e,0x0a,0x0e,0x0b,0x01,
	0x01,0x0c,0x0c,0x0c,0x0c,0x01,0x01,0x0c,0x0b,0x0c,
	0x0c,0x01,0x01,0x0c,0x0a,0x0c,0x0c,0x01,0x01,0x0c,
	0x09,0x0c,0x0c,0x01,0x02,0x0c,0x09,0x0b,0x0b,0x0f,
	0x08,0x0c,0x0a,0x02,0x01,0x0b,0x0a,0x0a,0x0c,0x01,
	0x01,0x0b,0x08,0x0d,0x0a,0x01,0x01,0x0c,0x07,0x0d,
	0x09,0x01,0x02,0x0b,0x08,0x0d,0x08,0x02,0x01,0x0b,
	0x08,0x0d,0x08,0x01,0x01,0x0c,0x05,0x01,0x02,0x0c,
	0x01,0x01,0x07,0x01,0x01,0x0b,0x03,0x01,0x04,0x0c,
	0x08,0x02,0x01,0x0b,0x02,0x02,0x01,0x0c,0x01,0x02,
	0x08,0x0e,0x02,0x02,0x01,0x01,0x01,0x09,0x02,0x01,
	0x09,0x01,0x01,0x0c,0x01,0x02,0x02,0x01,0x01,0x09,
	0x01,0x02,0x09,0x01,0x01,0x0b,0x02,0x02,0x02,0x01,
	0x01,0x09,0x01,0x02,0x08,0x02,0x01,0x11,0x02,0x10,
	0x0a,0x20,0x0a,0x16,0x01,0x0a,0x0b,0x15,0x01,0x01,
	0x01,0x09,0x0a,0x11,0x01,0x04,0x01,0x0b,0x0b,0x10,
	0x02,0x0f,0x0b,0x0f,0x04,0x0e,0x0b,0x0f,0x02,0x0a,
	0x01,0x04,0x01,0x01,0x06,0x02,0x01,0x0b,0x02,0x03,
	0x02,0x04,0x02,0x0d,0x06,0x02,0x01,0x08,0x01,0x01,
	0x03,0x08,0x02,0x0d,0x06,0x0b,0x01,0x02,0x03,0x04,
	0x01,0x02,0x03,0x0a,0x02,0x01,0x07,0x09,0x03,0x01,
	0x03,0x04,0x02,0x01,0x03,0x0a,0x02,0x01,0x08,0x09,
	0x07,0x05,0x01,0x01,0x05,0x08,0x04,0x01,0x07,0x09,
	0x07,0x05,0x01,0x01,0x06,0x08,0x04,0x02,0x07,0x09,
	0x07,0x07,0x06,0x0a,0x02,0x02,0x09,0x04,0x01,0x04,
	0x07,0x06,0x06,0x0a,0x0f,0x09,0x04,0x01,0x02,0x01,
	0x01,0x04,0x03,0x01,0x02,0x0b,0x10,0x0a,0x05,0x02,
	0x01,0x05,0x01,0x05,0x02,0x09,0x06,0x01,0x09,0x0b,
	0x06,0x01,0x01,0x0c,0x01,0x08,0x07,0x08,0x06,0x11,
	0x01,0x83,0xb3,0x01,0x01,0x0a,0x0e,0x04,0x0c,0x01,
	0x01,0x01,0x09,0x0a,0x09,0x0a,0x09,0x04,0x0b,0x0e,
	0x09,0x09,0x0b,0x04,0x0a,0x0a,0x03,0x05,0x09,0x08,
	0x0c,0x04,0x09,0x09,0x04,0x07,0x09,0x07,0x0d,0x04,
	0x09,0x07,0x06,0x09,0x09,0x07,0x09,0x07,0x0b,0x06,
	0x08,0x09,0x0a,0x06,0x08,0x07,0x0c,0x06,0x08,0x0a,
	0x0a,0x07,0x08,0x06,0x0c,0x06,0x08,0x0a,0x0b,0x06,
	0x09,0x06,0x0c,0x05,0x08,0x0c,0x0a,0x06,0x09,0x06,
	0x0d,0x04,0x09,0x0c,0x0a,0x06,0x09,0x06,0x0e,0x01,
	0x0b,0x0d,0x0b,0x05,0x08,0x07,0x19,0x10,0x0a,0x04,
	0x09,0x06,0x1b,0x09,0x02,0x05,0x0a,0x04,0x09,0x05,
	0x1b,0x07,0x04,0x07,0x09,0x04,0x09,0x05,0x1b,0x07,
	0x04,0x08,0x09,0x04,0x09,0x05,0x18,0x01,0x07,0x04,
	0x02,0x09,0x08,0x04,0x09,0x01,0x02,0x04,0x09,0x02,
	0x08,0x04,0x07,0x05,0x04,0x09,0x07,0x03,0x0c,0x05,
	0x07,0x03,0x0b,0x02,0x07,0x06,0x04,0x09,0x07,0x03,
	0x0b,0x05,0x06,0x03,0x0c,0x04,0x05,0x04,0x05,0x01,
	0x03,0x08,0x06,0x03,0x05,0x01,0x06,0x04,0x05,0x03,
	0x04,0x02,0x07,0x03,0x0a,0x04,0x05,0x0a,0x05,0x04,
	0x04,0x01,0x05,0x04,0x0b,0x03,0x06,0x02,0x04,0x03,
	0x04,0x04,0x04,0x02,0x04,0x0a,0x04,0x04,0x04,0x02,
	0x05,0x04,0x0a,0x03,0x0c,0x02,0x05,0x03,0x03,0x03,
	0x05,0x04,0x01,0x06,0x06,0x03,0x04,0x01,0x05,0x04,
	0x03,0x01,0x06,0x03,0x0b,0x02,0x0b,0x03,0x09,0x0a,
	0x05,0x02,0x04,0x03,0x04,0x04,0x03,0x02,0x05,0x03,
	0x04,0x01,0x06,0x02,0x0b,0x03,0x04,0x01,0x04,0x04,
	0x02,0x05,0x05,0x01,0x04,0x03,0x05,0x03,0x02,0x04,
	0x04,0x03,0x04,0x01,0x06,0x02,0x05,0x01,0x05,0x03,
	0x04,0x01,0x05,0x04,0x02,0x05,0x0b,0x03,0x05,0x02,
	0x02,0x04,0x0b,0x03,0x0b,0x02,0x06,0x01,0x05,0x02,
	0x05,0x02,0x03,0x07,0x0b,0x03,0x0a,0x04,0x0c,0x02,
	0x0d,0x01,0x1a,0x05,0x81,0xc6,0x01,0x00,

/* Victor */
	0x01,0x80,0x89,0x01,0x80,0x88,0x02,0x40,0x01,0x02,
	0x01,0x38,0x01,0x4d,0x03,0x3a,0x0d,0x2c,0x0b,0x02,
	0x01,0x0d,0x07,0x11,0x0c,0x02,0x01,0x09,0x01,0x01,
	0x09,0x0b,0x11,0x01,0x01,0x09,0x01,0x01,0x08,0x09,
	0x11,0x01,0x01,0x09,0x01,0x01,0x06,0x01,0x01,0x08,
	0x10,0x02,0x01,0x09,0x01,0x01,0x08,0x09,0x01,0x01,
	0x0d,0x02,0x01,0x08,0x01,0x01,0x08,0x09,0x01,0x01,
	0x0d,0x01,0x01,0x09,0x01,0x01,0x08,0x0b,0x0c,0x02,
	0x01,0x09,0x01,0x01,0x08,0x0a,0x0c,0x02,0x01,0x09,
	0x01,0x01,0x08,0x08,0x0e,0x01,0x01,0x09,0x01,0x01,
	0x08,0x0a,0x0c,0x01,0x02,0x08,0x01,0x01,0x01,0x01,
	0x06,0x0a,0x01,0x01,0x0b,0x01,0x01,0x08,0x01,0x03,
	0x02,0x01,0x03,0x01,0x01,0x08,0x01,0x01,0x02,0x01,
	0x01,0x01,0x01,0x01,0x02,0x01,0x02,0x02,0x01,0x0f,
	0x07,0x01,0x01,0x0f,0x01,0x01,0x01,0x01,0x01,0x26,
	0x07,0x81,0xe0,0x02,0x02,0x01,0x05,0x01,0x4a,0x01,
	0x0a,0x01,0x0c,0x01,0x52,0x01,0x07,0x01,0x06,0x01,
	0x0b,0x01,0x01,0x01,0x08,0x01,0x24,0x01,0x06,0x01,
	0x1d,0x01,0x01,0x01,0x0b,0x01,0x82,0x8c,0x01,0x01,
	0x01,0x05,0x01,0x1f,0x02,0x04,0x01,0x2b,0x01,0x01,
	0x01,0x02,0x01,0x01,0x02,0x01,0x04,0x12,0x02,0x01,
	0x01,0x13,0x01,0x01,0x0a,0x0e,0x09,0x0f,0x0f,0x0c,
	0x01,0x01,0x09,0x0b,0x05,0x07,0x08,0x02,0x01,0x09,
	0x09,0x0b,0x05,0x09,0x0a,0x0b,0x08,0x0a,0x06,0x09,
	0x0d,0x0c,0x05,0x01,0x01,0x09,0x06,0x0a,0x08,0x03,
	0x06,0x0b,0x08,0x09,0x01,0x01,0x04,0x09,0x09,0x05,
	0x05,0x0c,0x07,0x0b,0x05,0x0b,0x06,0x04,0x07,0x0c,
	0x07,0x09,0x01,0x01,0x06,0x08,0x09,0x06,0x07,0x0a,
	0x09,0x08,0x08,0x09,0x07,0x09,0x06,0x09,0x0a,0x08,
	0x07,0x0b,0x06,0x08,0x09,0x09,0x09,0x09,0x07,0x0b,
	0x06,0x07,0x0b,0x09,0x09,0x09,0x07,0x0b,0x07,0x07,
	0x0b,0x09,0x09,0x0a,0x07,0x0b,0x06,0x07,0x0d,0x09,
	0x07,0x0c,0x06,0x0c,0x06,0x06,0x0f,0x09,0x08,0x0a,
	0x06,0x0d,0x05,0x07,0x07,0x01,0x09,0x08,0x09,0x09,
	0x06,0x0c,0x05,0x09,0x08,0x04,0x06,0x08,0x09,0x08,
	0x05,0x0c,0x05,0x0a,0x06,0x06,0x08,0x08,0x08,0x08,
	0x06,0x0a,0x05,0x0b,0x05,0x0a,0x07,0x07,0x09,0x07,
	0x05,0x0a,0x05,0x0b,0x05,0x0a,0x05,0x03,0x04,0x07,
	0x02,0x03,0x04,0x06,0x04,0x02,0x03,0x06,0x04,0x0b,
	0x03,0x04,0x02,0x06,0x02,0x04,0x04,0x01,0x05,0x06,
	0x03,0x02,0x04,0x05,0x04,0x02,0x04,0x05,0x02,0x03,
	0x04,0x06,0x02,0x04,0x02,0x06,0x01,0x04,0x04,0x04,
	0x05,0x0a,0x05,0x09,0x05,0x0a,0x04,0x0a,0x03,0x0c,
	0x02,0x0a,0x05,0x09,0x05,0x0a,0x04,0x09,0x05,0x0a,
	0x02,0x0b,0x03,0x0b,0x06,0x07,0x01,0x02,0x05,0x09,
	0x04,0x0a,0x04,0x0a,0x03,0x0b,0x03,0x09,0x09,0x06,
	0x01,0x03,0x04,0x0a,0x03,0x0a,0x04,0x0a,0x02,0x0b,
	0x02,0x0b,0x02,0x03,0x05,0x0a,0x04,0x0a,0x04,0x0a,
	0x03,0x0b,0x01,0x0b,0x01,0x0d,0x01,0x05,0x01,0x03,
	0x04,0x09,0x04,0x0a,0x03,0x0a,0x03,0x0b,0x01,0x1f,
	0x01,0x05,0x01,0x02,0x01,0x0a,0x04,0x0a,0x03,0x0b,
	0x01,0x35,0x01,0x0d,0x03,0x0b,0x02,0x49,0x01,0x0a,
	0x03,0x0b,0x02,0x00,

/* Whiskey */
	0x07,0x0f,0x01,0x01,0x05,0x13,0x0f,0x0f,0x09,0x11,
	0x10,0x0e,0x09,0x0d,0x13,0x0d,0x09,0x11,0x0d,0x0d,
	0x0a,0x0c,0x11,0x0b,0x0b,0x0a,0x11,0x0e,0x07,0x01,
	0x01,0x0a,0x10,0x0d,0x08,0x0b,0x10,0x02,0x01,0x09,
	0x09,0x0b,0x10,0x0c,0x09,0x0b,0x0f,0x02,0x01,0x09,
	0x09,0x0a,0x10,0x02,0x01,0x09,0x09,0x0b,0x10,0x01,
	0x01,0x09,0x01,0x01,0x08,0x0a,0x11,0x02,0x01,0x08,
	0x01,0x02,0x07,0x0a,0x0b,0x03,0x03,0x02,0x02,0x0b,
	0x07,0x0a,0x09,0x06,0x06,0x01,0x01,0x0c,0x05,0x0a,
	0x08,0x07,0x0a,0x10,0x03,0x01,0x01,0x07,0x01,0x01,
	0x01,0x01,0x01,0x0a,0x01,0x03,0x02,0x02,0x01,0x01,
	0x01,0x01,0x01,0x1e,0x01,0x02,0x01,0x07,0x01,0x04,
	0x01,0x01,0x01,0x02,0x02,0x01,0x01,0x01,0x01,0x02,
	0x01,0x0e,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
	0x02,0x03,0x01,0x03,0x01,0x04,0x01,0x01,0x01,0x01,
	0x01,0x04,0x01,0x05,0x01,0x04,0x02,0x04,0x02,0x01,
	0x01,0x01,0x01,0x02,0x01,0x03,0x01,0x01,0x01,0x05,
	0x01,0x01,0x01,0x09,0x01,0x02,0x01,0x01,0x01,0x01,
	0x01,0x01,0x01,0x02,0x01,0x01,0x01,0x01,0x01,0x01,
	0x01,0x05,0x01,0x02,0x02,0x01,0x02,0x02,0x01,0x02,
	0x01,0x01,0x01,0x04,0x02,0x01,0x02,0x01,0x01,0x05,
	0x01,0x03,0x03,0x08,0x02,0x01,0x02,0x01,0x02,0x06,
	0x02,0x01,0x02,0x01,0x01,0x09,0x01,0x03,0x01,0x16,
	0x04,0x03,0x01,0x01,0x02,0x05,0x01,0x01,0x01,0x05,
	0x01,0x0b,0x01,0x04,0x01,0x03,0x01,0x01,0x01,0x01,
	0x01,0x03,0x01,0x01,0x01,0x03,0x01,0x01,0x01,0x06,
	0x01,0x01,0x01,0x02,0x01,0x08,0x01,0x09,0x01,0x02,
	0x01,0x01,0x01,0x04,0x01,0x01,0x01,0x09,0x01,0x03,
	0x01,0x0e,0x01,0x05,0x01,0x06,0x04,0x05,0x02,0x02,
	0x01,0x01,0x01,0x0c,0x01,0x07,0x02,0x01,0x01,0x0a,
	0x01,0x01,0x01,0x02,0x01,0x01,0x02,0x02,0x01,0x04,
	0x01,0x01,0x01,0x0f,0x01,0x03,0x04,0x01,0x01,0x04,
	0x01,0x04,0x01,0x01,0x01,0x0b,0x01,0x01,0x01,0x05,
	0x01,0x02,0x01,0x02,0x01,0x0c,0x02,0x01,0x01,0x1c,
	0x03,0x02,0x01,0x01,0x01,0x08,0x01,0x04,0x02,0x07,
	0x01,0x02,0x01,0x01,0x01,0x05,0x01,0x01,0x01,0x07,
	0x01,0x01,0x01,0x04,0x01,0x01,0x02,0x01,0x01,0x01,
	0x03,0x01,0x02,0x01,0x01,0x05,0x01,0x05,0x01,0x04,
	0x01,0x02,0x01,0x03,0x03,0x07,0x01,0x04,0x01,0x02,
	0x01,0x04,0x01,0x01,0x01,0x01,0x02,0x01,0x01,0x0a,
	0x01,0x0c,0x02,0x05,0x01,0x03,0x01,0x01,0x01,0x01,
	0x01,0x01,0x02,0x01,0x01,0x03,0x01,0x01,0x01,0x04,
	0x01,0x01,0x01,0x05,0x01,0x01,0x01,0x03,0x02,0x01,
	0x01,0x05,0x01,0x05,0x01,0x01,0x01,0x02,0x01,0x02,
	0x01,0x01,0x01,0x05,0x01,0x01,0x01,0x02,0x01,0x04,
	0x01,0x02,0x01,0x02,0x01,0x01,0x01,0x03,0x01,0x01,
	0x01,0x02,0x01,0x02,0x01,0x01,0x01,0x02,0x01,0x07,
	0x01,0x01,0x01,0x01,0x01,0x05,0x01,0x0a,0x01,0x02,
	0x01,0x03,0x01,0x01,0x01,0x05,0x01,0x09,0x01,0x03,
	0x01,0x0d,0x01,0x82,0x95,0x01,0x75,0x01,0x01,0x01,
	0x02,0x01,0x05,0x03,0x02,0x01,0x01,0x01,0x12,0x05,
	0x14,0x0c,0x01,0x02,0x01,0x01,0x0e,0x09,0x01,0x01,
	0x0f,0x0e,0x02,0x01,0x01,0x01,0x0d,0x0a,0x02,0x01,
	0x0d,0x10,0x02,0x01,0x02,0x01,0x0d,0x0a,0x0f,0x0c,
	0x01,0x02,0x02,0x01,0x03,0x01,0x02,0x01,0x0c,0x09,
	0x11,0x0c,0x01,0x01,0x02,0x04,0x01,0x02,0x01,0x01,
	0x0c,0x09,0x11,0x01,0x01,0x09,0x06,0x01,0x01,0x02,
	0x03,0x01,0x0f,0x09,0x11,0x01,0x01,0x09,0x08,0x04,
	0x01,0x01,0x02,0x01,0x0d,0x09,0x12,0x09,0x09,0x06,
	0x01,0x01,0x0f,0x09,0x01,0x01,0x0f,0x01,0x01,0x08,
	0x0a,0x01,0x01,0x05,0x01,0x02,0x01,0x01,0x0a,0x01,
	0x01,0x0a,0x13,0x05,0x02,0x01,0x0a,0x01,0x01,0x08,
	0x01,0x01,0x0c,0x01,0x02,0x09,0x13,0x01,0x02,0x02,
	0x10,0x01,0x02,0x02,0x01,0x04,0x01,0x01,0x02,0x01,
	0x0a,0x01,0x01,0x0a,0x01,0x01,0x11,0x01,0x02,0x02,
	0x01,0x02,0x10,0x01,0x01,0x04,0x01,0x03,0x01,0x01,
	0x02,0x01,0x0a,0x01,0x01,0x02,0x01,0x03,0x01,0x02,
	0x02,0x01,0x11,0x01,0x01,0x02,0x17,0x01,0x02,0x02,
	0x01,0x02,0x02,0x02,0x01,0x01,0x0a,0x01,0x01,0x02,
	0x01,0x04,0x01,0x02,0x16,0x01,0x02,0x02,0x02,0x01,
	0x10,0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x01,0x01,
	0x02,0x01,0x01,0x02,0x01,0x01,0x07,0x01,0x01,0x02,
	0x01,0x07,0x01,0x01,0x14,0x01,0x02,0x02,0x02,0x01,
	0x17,0x01,0x01,0x02,0x02,0x01,0x02,0x01,0x09,0x01,
	0x02,0x01,0x01,0x04,0x01,0x02,0x02,0x01,0x17,0x01,
	0x02,0x01,0x1f,0x02,0x01,0x01,0x0a,0x01,0x01,0x01,
	0x02,0x03,0x01,0x02,0x40,0x01,0x01,0x01,0x0f,0x03,
	0x02,0x02,0x01,0x01,0x40,0x01,0x12,0x02,0x02,0x02,
	0x01,0x01,0x42,0x01,0x01,0x01,0x10,0x01,0x01,0x01,
	0x01,0x01,0x47,0x01,0x01,0x01,0x10,0x01,0x01,0x01,
	0x4d,0x01,0x00,

/* X-Ray */
	0x06,0x07,0x03,0x01,0x02,0x08,0x04,0x09,0x04,0x04,
	0x06,0x07,0x06,0x07,0x05,0x08,0x04,0x06,0x07,0x07,
	0x06,0x07,0x05,0x08,0x04,0x06,0x07,0x07,0x06,0x07,
	0x04,0x07,0x05,0x06,0x08,0x07,0x05,0x07,0x05,0x07,
	0x05,0x04,0x01,0x01,0x07,0x07,0x06,0x07,0x05,0x06,
	0x06,0x04,0x01,0x01,0x07,0x07,0x06,0x07,0x04,0x07,
	0x05,0x04,0x01,0x02,0x07,0x07,0x06,0x06,0x05,0x07,
	0x05,0x03,0x02,0x01,0x07,0x07,0x06,0x07,0x04,0x07,
	0x05,0x01,0x01,0x01,0x02,0x02,0x06,0x07,0x06,0x07,
	0x06,0x08,0x02,0x01,0x0c,0x07,0x07,0x07,0x06,0x07,
	0x01,0x02,0x0c,0x09,0x05,0x0b,0x02,0x03,0x02,0x06,
	0x0b,0x0a,0x04,0x01,0x01,0x0b,0x05,0x01,0x02,0x06,
	0x04,0x01,0x03,0x01,0x01,0x82,0x35,0x02,0x10,0x02,
	0x07,0x01,0x04,0x02,0x16,0x01,0x6b,0x01,0x01,0x01,
	0x04,0x01,0x01,0x01,0x01,0x01,0x06,0x01,0x02,0x03,
	0x01,0x01,0x01,0x01,0x01,0x01,0x02,0x01,0x01,0x01,
	0x05,0x01,0x01,0x01,0x02,0x01,0x01,0x01,0x05,0x01,
	0x01,0x02,0x05,0x03,0x01,0x01,0x01,0x01,0x04,0x01,
	0x02,0x01,0x01,0x01,0x01,0x01,0x09,0x01,0x03,0x01,
	0x01,0x01,0x01,0x02,0x03,0x01,0x03,0x01,0x04,0x01,
	0x01,0x02,0x01,0x01,0x03,0x01,0x02,0x01,0x01,0x05,
	0x01,0x01,0x09,0x04,0x01,0x01,0x05,0x01,0x01,0x02,
	0x01,0x01,0x01,0x01,0x01,0x03,0x01,0x01,0x03,0x01,
	0x01,0x01,0x01,0x01,0x0b,0x02,0x04,0x01,0x09,0x01,
	0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
	0x01,0x04,0x01,0x01,0x02,0x01,0x08,0x01,0x01,0x01,
	0x01,0x02,0x0e,0x01,0x01,0x01,0x06,0x01,0x05,0x01,
	0x01,0x01,0x03,0x01,0x02,0x01,0x01,0x01,0x02,0x01,
	0x01,0x01,0x01,0x03,0x01,0x01,0x01,0x02,0x01,0x01,
	0x01,0x01,0x03,0x01,0x01,0x01,0x02,0x01,0x0c,0x01,
	0x03,0x01,0x04,0x01,0x03,0x01,0x04,0x01,0x02,0x02,
	0x01,0x01,0x03,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
	0x04,0x01,0x03,0x01,0x03,0x01,0x05,0x01,0x06,0x02,
	0x01,0x01,0x03,0x01,0x01,0x01,0x02,0x01,0x01,0x02,
	0x06,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
	0x01,0x01,0x01,0x01,0x03,0x01,0x03,0x01,0x01,0x01,
	0x02,0x01,0x02,0x02,0x01,0x01,0x01,0x01,0x01,0x01,
	0x03,0x02,0x01,0x01,0x03,0x01,0x01,0x01,0x01,0x01,
	0x06,0x03,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x01,
	0x02,0x01,0x06,0x01,0x05,0x01,0x01,0x01,0x08,0x01,
	0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x0a,0x01,
	0x08,0x01,0x01,0x01,0x01,0x01,0x04,0x01,0x01,0x01,
	0x01,0x01,0x01,0x01,0x03,0x01,0x01,0x01,0x02,0x01,
	0x01,0x01,0x01,0x01,0x02,0x03,0x07,0x04,0x02,0x01,
	0x01,0x01,0x08,0x01,0x07,0x01,0x02,0x01,0x01,0x01,
	0x01,0x01,0x07,0x01,0x01,0x01,0x08,0x01,0x04,0x01,
	0x03,0x01,0x01,0x01,0x01,0x01,0x05,0x01,0x04,0x01,
	0x0b,0x01,0x02,0x01,0x02,0x01,0x07,0x01,0x01,0x01,
	0x02,0x01,0x01,0x01,0x05,0x01,0x19,0x02,0x13,0x01,
	0x05,0x01,0x01,0x01,0x20,0x01,0x02,0x01,0x3e,0x01,
	0x7d,0x01,0x05,0x03,0x02,0x04,0x14,0x01,0x11,0x01,
	0x06,0x08,0x0d,0x07,0x10,0x01,0x07,0x0a,0x0d,0x0a,
	0x08,0x02,0x04,0x02,0x06,0x0b,0x0d,0x08,0x0a,0x03,
	0x04,0x02,0x06,0x0a,0x0c,0x08,0x0b,0x04,0x02,0x02,
	0x06,0x0a,0x0c,0x08,0x0b,0x04,0x0a,0x0b,0x0b,0x07,
	0x0a,0x05,0x0a,0x0e,0x0b,0x06,0x0a,0x05,0x0a,0x09,
	0x04,0x05,0x0a,0x06,0x09,0x08,0x09,0x06,0x07,0x07,
	0x09,0x07,0x07,0x07,0x09,0x05,0x09,0x09,0x09,0x06,
	0x07,0x08,0x09,0x03,0x09,0x0e,0x08,0x06,0x01,0x01,
	0x04,0x08,0x08,0x04,0x09,0x01,0x02,0x02,0x03,0x09,
	0x07,0x08,0x05,0x01,0x02,0x04,0x09,0x02,0x01,0x02,
	0x05,0x01,0x03,0x02,0x03,0x02,0x02,0x08,0x08,0x04,
	0x01,0x02,0x06,0x01,0x01,0x04,0x08,0x03,0x01,0x02,
	0x09,0x02,0x08,0x09,0x08,0x04,0x01,0x02,0x08,0x04,
	0x0a,0x04,0x08,0x03,0x03,0x01,0x03,0x03,0x01,0x08,
	0x07,0x04,0x01,0x02,0x08,0x05,0x01,0x01,0x07,0x04,
	0x08,0x03,0x08,0x0b,0x08,0x03,0x01,0x02,0x08,0x05,
	0x01,0x01,0x07,0x05,0x08,0x04,0x07,0x03,0x01,0x09,
	0x07,0x07,0x08,0x06,0x08,0x04,0x09,0x05,0x09,0x0a,
	0x07,0x04,0x01,0x02,0x08,0x06,0x08,0x05,0x08,0x06,
	0x08,0x0c,0x07,0x06,0x09,0x06,0x08,0x06,0x08,0x05,
	0x08,0x0d,0x02,0x01,0x04,0x01,0x01,0x04,0x09,0x06,
	0x08,0x06,0x08,0x05,0x09,0x07,0x02,0x05,0x02,0x01,
	0x04,0x01,0x01,0x04,0x01,0x01,0x08,0x05,0x0a,0x04,
	0x0a,0x03,0x0b,0x0d,0x0b,0x04,0x08,0x05,0x0a,0x05,
	0x09,0x03,0x0a,0x03,0x01,0x03,0x02,0x07,0x07,0x01,
	0x01,0x06,0x08,0x05,0x0a,0x04,0x0b,0x04,0x0b,0x0d,
	0x07,0x01,0x01,0x04,0x01,0x01,0x08,0x06,0x0a,0x05,
	0x0a,0x04,0x0b,0x0d,0x0a,0x05,0x09,0x06,0x09,0x06,
	0x0a,0x05,0x09,0x07,0x04,0x01,0x01,0x01,0x0b,0x02,
	0x01,0x01,0x0a,0x05,0x0b,0x05,0x0a,0x05,0x0a,0x07,
	0x01,0x01,0x02,0x01,0x0c,0x06,0x0a,0x04,0x0b,0x05,
	0x0b,0x05,0x0a,0x06,0x08,0x01,0x0c,0x01,0x01,0x03,
	0x0c,0x02,0x0d,0x04,0x0c,0x04,0x0b,0x02,0x01,0x01,
	0x17,0x01,0x01,0x02,0x2d,0x04,0x0d,0x01,0x02,0x01,
	0x18,0x04,0x40,0x01,0x15,0x02,0x59,0x02,0x01,0x01,
	0x80,0x9d,0x01,0x14,0x01,0x00,

/* Yankee */
	0x01,0x20,0x01,0x01,0x01,0x3c,0x01,0x07,0x01,0x36,
	0x01,0x07,0x01,0x01,0x01,0x32,0x01,0x01,0x01,0x02,
	0x01,0x01,0x02,0x01,0x02,0x1b,0x01,0x17,0x01,0x02,
	0x01,0x01,0x02,0x01,0x02,0x01,0x01,0x15,0x04,0x01,
	0x02,0x11,0x08,0x01,0x01,0x02,0x01,0x15,0x08,0x0e,
	0x0c,0x02,0x01,0x01,0x02,0x11,0x08,0x0c,0x14,0x01,
	0x01,0x0c,0x0a,0x0c,0x09,0x04,0x09,0x0c,0x09,0x0a,
	0x06,0x08,0x09,0x0b,0x08,0x09,0x06,0x09,0x0c,0x0a,
	0x06,0x08,0x05,0x0b,0x0f,0x0a,0x06,0x07,0x05,0x09,
	0x12,0x07,0x01,0x01,0x04,0x07,0x01,0x01,0x04,0x08,
	0x05,0x06,0x09,0x07,0x06,0x07,0x05,0x08,0x04,0x06,
	0x09,0x08,0x02,0x01,0x02,0x07,0x06,0x07,0x03,0x07,
	0x09,0x07,0x03,0x02,0x01,0x05,0x01,0x01,0x05,0x08,
	0x03,0x07,0x09,0x07,0x03,0x01,0x01,0x06,0x01,0x01,
	0x04,0x07,0x05,0x06,0x08,0x07,0x03,0x01,0x02,0x07,
	0x05,0x07,0x03,0x07,0x08,0x02,0x01,0x02,0x01,0x01,
	0x03,0x01,0x02,0x07,0x02,0x01,0x02,0x08,0x02,0x02,
	0x01,0x04,0x08,0x06,0x06,0x07,0x02,0x01,0x02,0x08,
	0x02,0x03,0x01,0x02,0x08,0x05,0x01,0x01,0x02,0x01,
	0x03,0x07,0x02,0x01,0x02,0x07,0x02,0x02,0x01,0x04,
	0x07,0x02,0x01,0x06,0x04,0x07,0x02,0x01,0x02,0x07,
	0x02,0x01,0x03,0x03,0x07,0x02,0x01,0x06,0x03,0x02,
	0x01,0x05,0x01,0x01,0x02,0x08,0x01,0x01,0x04,0x01,
	0x01,0x01,0x07,0x01,0x01,0x07,0x03,0x01,0x01,0x06,
	0x01,0x01,0x02,0x01,0x01,0x08,0x01,0x02,0x03,0x01,
	0x06,0x01,0x02,0x06,0x01,0x01,0x01,0x01,0x02,0x05,
	0x01,0x02,0x01,0x01,0x01,0x08,0x01,0x02,0x01,0x01,
	0x01,0x01,0x06,0x02,0x01,0x06,0x01,0x01,0x01,0x01,
	0x02,0x01,0x01,0x03,0x01,0x02,0x01,0x01,0x01,0x08,
	0x01,0x01,0x02,0x01,0x01,0x01,0x06,0x01,0x01,0x02,
	0x01,0x06,0x01,0x01,0x01,0x01,0x02,0x03,0x01,0x01,
	0x01,0x0a,0x01,0x02,0x03,0x01,0x06,0x01,0x02,0x01,
	0x01,0x06,0x01,0x01,0x01,0x02,0x01,0x01,0x01,0x01,
	0x01,0x01,0x01,0x0b,0x01,0x01,0x01,0x01,0x0a,0x02,
	0x01,0x08,0x01,0x01,0x01,0x01,0x02,0x01,0x01,0x01,
	0x01,0x01,0x01,0x06,0x01,0x03,0x02,0x01,0x09,0x02,
	0x01,0x0c,0x02,0x01,0x01,0x01,0x01,0x01,0x01,0x0b,
	0x0c,0x01,0x01,0x0c,0x01,0x02,0x01,0x01,0x02,0x0c,
	0x01,0x01,0x0c,0x0f,0x05,0x0d,0x0c,0x10,0x05,0x0d,
	0x0c,0x10,0x03,0x0e,0x0e,0x10,0x03,0x0d,0x10,0x20,
	0x06,0x02,0x01,0x07,0x01,0x1d,0x01,0x1a,0x04,0x28,
	0x01,0x82,0x2b,0x01,0x04,0x01,0x03,0x01,0x22,0x01,
	0x80,0x8f,0x01,0x02,0x04,0x01,0x05,0x01,0x01,0x01,
	0x02,0x11,0x01,0x01,0x02,0x01,0x01,0x01,0x01,0x0e,
	0x09,0x01,0x01,0x11,0x09,0x0f,0x0b,0x01,0x02,0x0f,
	0x0a,0x10,0x0d,0x01,0x01,0x0d,0x0d,0x0f,0x01,0x01,
	0x0d,0x01,0x01,0x02,0x01,0x0c,0x0c,0x12,0x10,0x02,
	0x01,0x01,0x01,0x0d,0x09,0x01,0x01,0x13,0x0a,0x05,
	0x04,0x01,0x01,0x02,0x01,0x0c,0x02,0x01,0x09,0x01,
	0x01,0x11,0x0b,0x06,0x03,0x01,0x02,0x01,0x01,0x0f,
	0x07,0x01,0x01,0x02,0x01,0x10,0x09,0x0b,0x03,0x01,
	0x02,0x01,0x01,0x0c,0x01,0x02,0x07,0x01,0x01,0x12,
	0x09,0x0c,0x04,0x02,0x01,0x02,0x01,0x0c,0x01,0x02,
	0x06,0x02,0x01,0x15,0x02,0x01,0x02,0x02,0x01,0x0a,
	0x07,0x01,0x01,0x02,0x01,0x0c,0x02,0x01,0x06,0x02,
	0x01,0x02,0x01,0x13,0x05,0x01,0x01,0x10,0x01,0x03,
	0x01,0x02,0x01,0x0c,0x01,0x02,0x01,0x01,0x04,0x01,
	0x01,0x13,0x01,0x02,0x02,0x01,0x01,0x03,0x01,0x13,
	0x01,0x03,0x01,0x01,0x02,0x0c,0x01,0x01,0x02,0x01,
	0x04,0x01,0x01,0x19,0x01,0x20,0x01,0x02,0x01,0x0a,
	0x01,0x01,0x02,0x01,0x01,0x07,0x01,0x20,0x01,0x19,
	0x01,0x02,0x01,0x0c,0x02,0x01,0x01,0x42,0x01,0x02,
	0x01,0x0c,0x01,0x02,0x01,0x02,0x01,0x27,0x01,0x06,
	0x02,0x13,0x01,0x02,0x01,0x0c,0x01,0x02,0x01,0x30,
	0x01,0x19,0x01,0x0f,0x01,0x02,0x01,0x30,0x01,0x15,
	0x01,0x02,0x01,0x0c,0x01,0x02,0x01,0x02,0x01,0x30,
	0x01,0x15,0x01,0x01,0x01,0x10,0x01,0x01,0x01,0x04,
	0x01,0x43,0x01,0x0f,0x01,0x02,0x03,0x01,0x01,0x01,
	0x01,0x00,

/* Zulu */
	0x01,0x01,0x01,0x01,0x02,0x32,0x01,0x04,0x02,0x01,
	0x02,0x01,0x01,0x30,0x01,0x2b,0x02,0x01,0x01,0x01,
	0x01,0x01,0x01,0x12,0x01,0x02,0x01,0x29,0x01,0x0f,
	0x01,0x01,0x01,0x01,0x02,0x0c,0x01,0x23,0x01,0x06,
	0x01,0x01,0x01,0x01,0x01,0x0a,0x01,0x07,0x03,0x01,
	0x01,0x03,0x01,0x31,0x01,0x01,0x01,0x06,0x01,0x04,
	0x01,0x04,0x01,0x03,0x01,0x03,0x01,0x27,0x01,0x01,
	0x01,0x01,0x01,0x11,0x01,0x05,0x01,0x02,0x01,0x1e,
	0x01,0x01,0x02,0x01,0x01,0x05,0x02,0x03,0x01,0x08,
	0x03,0x09,0x01,0x01,0x01,0x1b,0x01,0x03,0x01,0x03,
	0x01,0x01,0x01,0x04,0x01,0x01,0x01,0x01,0x01,0x02,
	0x01,0x01,0x01,0x03,0x01,0x01,0x01,0x05,0x01,0x01,
	0x01,0x02,0x03,0x1b,0x01,0x02,0x07,0x02,0x01,0x01,
	0x01,0x01,0x01,0x09,0x01,0x04,0x01,0x01,0x01,0x02,
	0x01,0x01,0x01,0x02,0x01,0x1b,0x01,0x02,0x01,0x02,
	0x02,0x04,0x01,0x0a,0x01,0x02,0x01,0x01,0x01,0x05,
	0x01,0x01,0x02,0x12,0x01,0x01,0x01,0x0d,0x01,0x01,
	0x01,0x04,0x01,0x05,0x02,0x05,0x02,0x01,0x04,0x02,
	0x01,0x01,0x01,0x17,0x01,0x06,0x01,0x01,0x01,0x01,
	0x01,0x01,0x04,0x08,0x01,0x01,0x06,0x01,0x01,0x12,
	0x01,0x01,0x01,0x06,0x01,0x02,0x01,0x01,0x01,0x01,
	0x01,0x01,0x01,0x03,0x01,0x04,0x01,0x01,0x02,0x01,
	0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x20,0x03,0x01,
	0x04,0x01,0x01,0x01,0x01,0x01,0x01,0x04,0x06,0x1d,
	0x01,0x05,0x01,0x01,0x03,0x01,0x0a,0x01,0x02,0x11,
	0x01,0x01,0x01,0x0b,0x01,0x01,0x03,0x02,0x01,0x01,
	0x0b,0x10,0x07,0x08,0x03,0x01,0x03,0x01,0x01,0x01,
	0x08,0x0f,0x09,0x04,0x01,0x02,0x06,0x01,0x06,0x02,
	0x01,0x0e,0x08,0x09,0x0b,0x01,0x02,0x0d,0x09,0x08,
	0x0a,0x01,0x01,0x0e,0x08,0x09,0x08,0x01,0x02,0x0d,
	0x09,0x09,0x0a,0x0d,0x09,0x09,0x0a,0x0b,0x01,0x01,
	0x09,0x08,0x0a,0x0b,0x01,0x01,0x09,0x08,0x0a,0x0c,
	0x0a,0x08,0x0a,0x0c,0x09,0x09,0x0a,0x0b,0x09,0x09,
	0x09,0x0c,0x09,0x09,0x09,0x0c,0x09,0x08,0x09,0x0c,
	0x09,0x08,0x0a,0x0b,0x09,0x08,0x0a,0x0b,0x09,0x07,
	0x0a,0x0c,0x09,0x07,0x0a,0x0c,0x09,0x08,0x0a,0x0c,
	0x08,0x08,0x0a,0x0c,0x09,0x07,0x0a,0x0c,0x09,0x08,
	0x0a,0x0c,0x09,0x08,0x0a,0x0c,0x09,0x08,0x0b,0x0b,
	0x09,0x09,0x0a,0x0c,0x09,0x09,0x0a,0x0c,0x09,0x09,
	0x0a,0x0c,0x09,0x09,0x0b,0x0c,0x09,0x0a,0x09,0x0d,
	0x09,0x0a,0x09,0x0c,0x0b,0x0a,0x0a,0x0c,0x0b,0x0a,
	0x09,0x0c,0x0b,0x0b,0x0a,0x0c,0x0a,0x0b,0x0b,0x0c,
	0x0b,0x0c,0x0b,0x0f,0x09,0x0b,0x0b,0x0d,0x0a,0x0a,
	0x0c,0x0c,0x0a,0x0b,0x0b,0x0d,0x0a,0x0b,0x0c,0x0c,
	0x0b,0x0b,0x0c,0x0c,0x0b,0x0c,0x0a,0x0f,0x0a,0x0d,
	0x0b,0x0f,0x09,0x0e,0x0c,0x10,0x0a,0x0e,0x0c,0x01,
	0x01,0x0f,0x0a,0x0f,0x0c,0x01,0x01,0x0f,0x0a,0x0f,
	0x01,0x01,0x0c,0x01,0x01,0x10,0x0b,0x11,0x0b,0x0e,
	0x0a,0x10,0x0f,0x0e,0x01,0x01,0x08,0x10,0x01,0x05,
	0x0d,0x0d,0x0a,0x0e,0x05,0x09,0x09,0x0c,0x0a,0x0b,
	0x08,0x09,0x0b,0x0b,0x0a,0x0b,0x08,0x0a,0x0c,0x0c,
	0x09,0x0b,0x08,0x0a,0x0f,0x0c,0x09,0x0b,0x05,0x0b,
	0x09,0x02,0x07,0x0c,0x09,0x0b,0x06,0x0a,0x08,0x01,
	0x01,0x03,0x07,0x0b,0x0a,0x0b,0x06,0x0b,0x0a,0x03,
	0x07,0x0c,0x09,0x0b,0x07,0x0b,0x09,0x04,0x08,0x0b,
	0x09,0x0b,0x07,0x0c,0x09,0x03,0x09,0x0c,0x09,0x0c,
	0x05,0x0e,0x09,0x06,0x07,0x0c,0x09,0x0d,0x05,0x0d,
	0x09,0x07,0x06,0x0d,0x09,0x0d,0x04,0x0d,0x08,0x08,
	0x08,0x0d,0x09,0x0e,0x02,0x10,0x06,0x09,0x07,0x0e,
	0x09,0x0e,0x03,0x0f,0x07,0x0b,0x05,0x0e,0x09,0x0e,
	0x05,0x0e,0x09,0x09,0x06,0x0e,0x09,0x0d,0x06,0x0e,
	0x09,0x08,0x01,0x01,0x06,0x0e,0x09,0x0e,0x06,0x0e,
	0x08,0x0a,0x07,0x0e,0x0a,0x0e,0x07,0x0e,0x07,0x0c,
	0x07,0x0e,0x09,0x0f,0x06,0x11,0x07,0x0c,0x01,0x01,
	0x01,0x01,0x01,0x10,0x08,0x12,0x05,0x10,0x08,0x11,
	0x02,0x10,0x09,0x10,0x06,0x0f,0x08,0x14,0x01,0x11,
	0x07,0x12,0x05,0x11,0x07,0x27,0x07,0x10,0x03,0x03,
	0x01,0x13,0x05,0x2b,0x04,0x16,0x01,0x15,0x02,0x01,
	0x01,0x12,0x01,0x1b,0x03,0x2a,0x01,0x81,0x8d,0x02,
	0x00
};

static unsigned short natox[128] = {
/* controls */	NULLPOS,	NULLPOS,	NULLPOS,	NULLPOS,
		NULLPOS,	NULLPOS,	NULLPOS,	NULLPOS,
		NULLPOS,	NULLPOS,	NULLPOS,	NULLPOS,
		NULLPOS,	NULLPOS,	NULLPOS,	NULLPOS,
		NULLPOS,	NULLPOS,	NULLPOS,	NULLPOS,
		NULLPOS,	NULLPOS,	NULLPOS,	NULLPOS,
		NULLPOS,	NULLPOS,	NULLPOS,	NULLPOS,
		NULLPOS,	NULLPOS,	NULLPOS,	NULLPOS,
/* 32 ' ' */	NATOWORD,
/* 33 '!' */	NATOALERT,
/* 34 '"' */	NULLPOS,
/* 35 '#' */	NULLPOS,
/* 36 '$' */	NULLPOS,
/* 37 '%' */	NULLPOS,
/* 38 '&' */	NULLPOS,
/* 39 ''' */	NULLPOS,
/* 40 '(' */	NULLPOS,
/* 41 ')' */	NULLPOS,
/* 42 '*' */	NULLPOS,
/* 43 '+' */	NULLPOS,
/* 44 ',' */	NATOWORD,
/* 45 '-' */	NULLPOS,
/* 46 '.' */	NATOALERT,
/* 47 '/' */	NULLPOS,
/* 48 '0' */	zeroPOS,
/* 49 '1' */	onePOS,
/* 50 '2' */	twoPOS,
/* 51 '3' */	threePOS,
/* 52 '4' */	fourPOS,
/* 53 '5' */	fivePOS,
/* 54 '6' */	sixPOS,
/* 55 '7' */	sevenPOS,
/* 56 '8' */	eightPOS,
/* 57 '9' */	ninePOS,
/* 58 ':' */	NULLPOS,
/* 59 ';' */	NULLPOS,
/* 60 '<' */	NULLPOS,
/* 61 '=' */	NULLPOS,
/* 62 '>' */	NULLPOS,
/* 63 '?' */	NATOALERT,
/* 64 '@' */	NULLPOS,
/* 65 'A' */	alphaPOS,
/* 66 'B' */	bravoPOS,
/* 67 'C' */	charliePOS,
/* 68 'D' */	deltaPOS,
/* 69 'E' */	echoPOS,
/* 70 'F' */	foxtrotPOS,
/* 71 'G' */	golfPOS,
/* 72 'H' */	hotelPOS,
/* 73 'I' */	indiaPOS,
/* 74 'J' */	julietPOS,
/* 75 'K' */	kiloPOS,
/* 76 'L' */	limaPOS,
/* 77 'M' */	mikePOS,
/* 78 'N' */	novemberPOS,
/* 79 'O' */	oscarPOS,
/* 80 'P' */	papaPOS,
/* 81 'Q' */	quebecPOS,
/* 82 'R' */	romeoPOS,
/* 83 'S' */	sierraPOS,
/* 84 'T' */	tangoPOS,
/* 85 'U' */	uniformPOS,
/* 86 'V' */	victorPOS,
/* 87 'W' */	whiskeyPOS,
/* 88 'X' */	xrayPOS,
/* 89 'Y' */	yankeePOS,
/* 90 'Z' */	zuluPOS,
/* 91 '[' */	NULLPOS,
/* 92 '\' */	NULLPOS,
/* 93 ']' */	NULLPOS,
/* 94 '^' */	NULLPOS,
/* 95 '_' */	NULLPOS,
/* 96 '`' */	NULLPOS,
/* 97 'a' */	alphaPOS,
/* 98 'b' */	bravoPOS,
/* 99 'c' */	charliePOS,
/* 100 'd' */	deltaPOS,
/* 101 'e' */	echoPOS,
/* 102 'f' */	foxtrotPOS,
/* 103 'g' */	golfPOS,
/* 104 'h' */	hotelPOS,
/* 105 'i' */	indiaPOS,
/* 106 'j' */	julietPOS,
/* 107 'k' */	kiloPOS,
/* 108 'l' */	limaPOS,
/* 109 'm' */	mikePOS,
/* 110 'n' */	novemberPOS,
/* 111 'o' */	oscarPOS,
/* 112 'p' */	papaPOS,
/* 113 'q' */	quebecPOS,
/* 114 'r' */	romeoPOS,
/* 115 's' */	sierraPOS,
/* 116 't' */	tangoPOS,
/* 117 'u' */	uniformPOS,
/* 118 'v' */	victorPOS,
/* 119 'w' */	whiskeyPOS,
/* 120 'x' */	xrayPOS,
/* 121 'y' */	yankeePOS,
/* 122 'z' */	zuluPOS,
/* 123 '{' */	NULLPOS,
/* 124 '|' */	NULLPOS,
/* 125 '}' */	NULLPOS,
/* 126 '~' */	NULLPOS,
/* 127 */	NULLPOS
};


/*	Morse data...
*/
#define	NOMORSE		43
#define	MORSEWORD	44
#define	MORSEALERT	45

static char *morsedata[] = {
/* 0-9 */	"-----",
		".----",
		"..---",
		"...--",
		"....-",
		".....",
		"-....",
		"--...",
		"---..",
		"----.",

/* a-z */	".-",
		"-...",
		"-.-.",
		"-..",
		".",
		"..-.",	
		"--.",
		"....",
		"..",
		".---",
		"-.-",
		".-..",
		"--",
		"-.",
		"---",
		".--.",
		"--.-",
		".-.",
		"...",
		"-",
		"..-",
		"...-",
		".--",
		"-..-",
		"-.--",
		"--..",

/* Special Morse symbols... */
/* 36 */	".-.-.-"	/* period */,
/* 37 */	"--..--"	/* comma */,
/* 38 */	"..--.."	/* question mark */,
/* 39 */	"-..-."		/* slash, fraction bar */,
/* 40 */	".-.-."		/* AR, cross, end of message */,
/* 41 */	"...-.-"	/* end of work */,
/* 42 */	"-...-"		/* double dash, pause */,
		""
};

static char morsex[128] = {
/* controls */	NOMORSE,	NOMORSE,	NOMORSE,	NOMORSE,
		NOMORSE,	NOMORSE,	NOMORSE,	NOMORSE,
		NOMORSE,	NOMORSE,	NOMORSE,	NOMORSE,
		NOMORSE,	NOMORSE,	NOMORSE,	NOMORSE,
		NOMORSE,	NOMORSE,	NOMORSE,	NOMORSE,
		NOMORSE,	NOMORSE,	NOMORSE,	NOMORSE,
		NOMORSE,	NOMORSE,	NOMORSE,	NOMORSE,
		NOMORSE,	NOMORSE,	NOMORSE,	NOMORSE,
/* 32 ' ' */	MORSEWORD,
/* 33 '!' */	MORSEALERT,
/* 34 '"' */	NOMORSE,
/* 35 '#' */	NOMORSE,
/* 36 '$' */	NOMORSE,
/* 37 '%' */	NOMORSE,
/* 38 '&' */	NOMORSE,
/* 39 ''' */	NOMORSE,
/* 40 '(' */	NOMORSE,
/* 41 ')' */	NOMORSE,
/* 42 '*' */	41,
/* 43 '+' */	40,
/* 44 ',' */	37,
/* 45 '-' */	NOMORSE,
/* 46 '.' */	36,
/* 47 '/' */	39,
/* 48 '0' */	0,
/* 49 '1' */	1,
/* 50 '2' */	2,
/* 51 '3' */	3,
/* 52 '4' */	4,
/* 53 '5' */	5,
/* 54 '6' */	6,
/* 55 '7' */	7,
/* 56 '8' */	8,
/* 57 '9' */	9,
/* 58 ':' */	NOMORSE,
/* 59 ';' */	NOMORSE,
/* 60 '<' */	NOMORSE,
/* 61 '=' */	42,
/* 62 '>' */	NOMORSE,
/* 63 '?' */	38,
/* 64 '@' */	NOMORSE,
/* 65 'A' */	10,
/* 66 'B' */	11,
/* 67 'C' */	12,
/* 68 'D' */	13,
/* 69 'E' */	14,
/* 70 'F' */	15,
/* 71 'G' */	16,
/* 72 'H' */	17,
/* 73 'I' */	18,
/* 74 'J' */	19,
/* 75 'K' */	20,
/* 76 'L' */	21,
/* 77 'M' */	22,
/* 78 'N' */	23,
/* 79 'O' */	24,
/* 80 'P' */	25,
/* 81 'Q' */	26,
/* 82 'R' */	27,
/* 83 'S' */	28,
/* 84 'T' */	29,
/* 85 'U' */	30,
/* 86 'V' */	31,
/* 87 'W' */	32,
/* 88 'X' */	33,
/* 89 'Y' */	34,
/* 90 'Z' */	35,
/* 91 '[' */	NOMORSE,
/* 92 '\' */	NOMORSE,
/* 93 ']' */	NOMORSE,
/* 94 '^' */	NOMORSE,
/* 95 '_' */	NOMORSE,
/* 96 '`' */	NOMORSE,
/* 97 'a' */	10,
/* 98 'b' */	11,
/* 99 'c' */	12,
/* 100 'd' */	13,
/* 101 'e' */	14,
/* 102 'f' */	15,
/* 103 'g' */	16,
/* 104 'h' */	17,
/* 105 'i' */	18,
/* 106 'j' */	19,
/* 107 'k' */	20,
/* 108 'l' */	21,
/* 109 'm' */	22,
/* 110 'n' */	23,
/* 111 'o' */	24,
/* 112 'p' */	25,
/* 113 'q' */	26,
/* 114 'r' */	27,
/* 115 's' */	28,
/* 116 't' */	29,
/* 117 'u' */	30,
/* 118 'v' */	31,
/* 119 'w' */	32,
/* 120 'x' */	33,
/* 121 'y' */	34,
/* 122 'z' */	35,
/* 123 '{' */	NOMORSE,
/* 124 '|' */	NOMORSE,
/* 125 '}' */	NOMORSE,
/* 126 '~' */	NOMORSE,
/* 127 */	NOMORSE
};


#ifndef	USEIOCTL

__inline__ static unsigned char
inb(register unsigned short port)
{
	register unsigned char value;

	__asm__ __volatile__ ("inb %w1,%0":"=a" (value):"Nd" (port));
	return(value);
}

__inline__ static void
outb(register unsigned char value,
register unsigned short int port)
{
	__asm__ volatile ("outb %b0,%w1": :"a" (value), "Nd" (port));
}

__inline__ static void
cli()
{
	__asm__ volatile ("cli");
}

__inline__ static void
sti()
{
	__asm__ volatile ("sti");
}

#endif

static unsigned int
until(register unsigned int when)
{
	struct timeval tv;
	register unsigned int now;

	for (;;) {
		if (gettimeofday(&tv, 0) != 0) {
			/* Call didn't work...  return immediately */
			return(0);
		}

		/* The following computation will overflow...
		   but it will not make any difference
		*/
		now = ((unsigned int) tv.tv_usec) +
		      (1000000U * ((unsigned int) tv.tv_sec));
		if (now >= when) {
			return(now);
		} else if ((when - now) > 0x7fffffffU) {
			return(now);
		}

		/* Long enough time left to usleep? */
		if (now > when) now -= when; else now = (when - now);
		if (now > 0x7fffffffU) now = (0xffffffffU - now);
		if (now > SYSTICKS) {
			usleep(now - SYSTICKS);
		}

#ifdef NOTNOW
		now += SYSTICKS;
		if (now >= when) {
		} else if ((when - now) > 0x7fffffffU) {
		} else {
			/* Give job scheduler a chance... */
			usleep(1);
		}
#endif
	}
}


static void
shutup(int signum)
{
#ifdef	USEIOCTL
	ioctl(consolefd, KIOCSOUND, 0);
#else
	/* Timer2 sound control off */
	outb((inb(0x61) & ~3), 0x61);
#endif
	exit(1);
}

static void
tone(register int freq,
register unsigned int msec)
{
	register unsigned int now = until(0);

#ifndef	FORCETOGGLE
#ifdef	USEIOCTL
	register int t = (freq ? ((TIMERPERSEC + (freq >> 1)) / freq) : 0);
	ioctl(consolefd, KIOCSOUND, t);

	/* Delay for the specified time in ms */
	until(now + (msec * (TICKSPERSEC / 1000)));
#else
	if (freq > 0) {
		/* Convert t from frequency to wavelength */
		register int t = ((TIMERPERSEC + (freq >> 1)) / freq);

		/* Timer2 sound control on */
		cli();
		outb((inb(0x61) | 0x03), 0x61);
		outb(0xd2, 0x43);	/* Mode2, load LS */
		outb(t, 0x42);		/* Out frequency LS */
		outb(0xe2, 0x43);	/* Mode2, load MS */
		outb((t >> 8), 0x42);	/* Out frequency MS */
		sti();
	} else {
		/* Timer2 sound control off */
		outb((inb(0x61) & ~3), 0x61);
	}

	/* Delay for the specified time in ms */
	until(now + (msec * (TICKSPERSEC / 1000)));
#endif
#else
	/* Force dumb toggling of the speaker bit... */
	register unsigned int done = (now + (msec * (TICKSPERSEC / 1000)));
	register int datum = (inb(0x61) & ~0x03);

	if (freq > 0) {
		/* Convert t from frequency to wavelength */
		register unsigned int t = ((TICKSPERSEC + (freq >> 1)) / freq);
		register unsigned int flip;

		do {
			/* Flip the PC speaker state */
			outb((datum ^= 0x02), 0x61);

			flip = (now + t);
			now = until(flip);
		} while (now < done);
	} else {
		until(done);
	}

	/* Always exit with speaker off */
	outb(datum, 0x61);
#endif
}


static void
alert(register int c)
{
	register int i, j;

	switch (c) {
	case '!':
		for (j=0; j<5; ++j) {
			for (i=220; i<=(8*220); i+=128) tone(i, 40);
			for (i=(8*220); i>=220; i-=128) tone(i, 40);
		}
		break;
	case '?':
		tone(440, 500);
		for (i=440; i<=880; i+=40) tone(i, 40);
		break;
	case '.':
		/* Essentially the standard console beep,
		   but 4X as long
		*/
		tone(750, (4 * 125));
	}
	tone(0, 0);
}

static void
nato(register int c)
{
	register unsigned int now;
	register int x;
	register unsigned char *p;
	register unsigned int when;
	register unsigned char datum;

	/* Get time reference */
	now = until(0);
	
	x = natox[c];
	if (x >= NULLPOS) {
		if (x == NATOALERT) {
			alert(c);
		} else if (x == NATOWORD) {
			until(now + WORDTICKS);
		}
		return;
	}
	p = &(natodata[x]);

	/* Force kerning time */
	when = (now + KERNTICKS);

#ifndef	USEIOCTL
	/* Get base value for control of the PC speaker */
	datum = (inb(0x61) & ~0x03);
#else
	datum = 0;
#endif
	while (*p) {
		register int t;

		/* Delay for previous speaker cone position */
		now = until(when);

#ifndef	USEIOCTL
		/* Flip the PC speaker state */
		outb((datum ^= 0x02), 0x61);
#else
		/* Flip the PC speaker state */
		if (datum = !datum) {
			ioctl(consolefd, KIOCSOUND, 30000);
		} else {
			ioctl(consolefd, KIOCSOUND, 0);
		}
#endif

		/* Determine delay for this position */
		t = *p;
		if ((t & 128) != 0) {
			t = (((int) (t & 0x7f)) << 8);
			t += *(++p);
		}
		when = now + (t * SAMPLETICKS);
		++p;
	}

	/* Delay for previous speaker cone position */
	now = until(when);

#ifndef	USEIOCTL
	/* Flip the PC speaker cone to 0 position */
	outb((datum & ~0x03), 0x61);
#else
	ioctl(consolefd, KIOCSOUND, 0);
#endif

	/* And wait for 1/2 intercharacter (kerning) time */
	until(now + KERNTICKS);
}

static void
morse(register int c)
{
	register int x;
	register char *m;

	x = morsex[c];
	if (x >= NOMORSE) {
		if (x == MORSEALERT) {
			alert(c);
		} else if (x == MORSEWORD) {
			/* Word space next to letters...
			   so discount by char space
			*/
			tone(0, ((MORSEWORDSP - MORSECHARSP) * sdot));
		}
		return;
	}
	m = morsedata[x];

	/* 1/2 of a Morse letter space on each side */
	tone(0, ((MORSECHARSP * sdot) >> 1));

	/* Play the tones... */
	while (*m) {
		/* Morse dot or dash */
		tone(freq, ((*m == '.') ? dot : (MORSEDASH * dot)));

		/* Morse intra-symbol space */
		tone(0, (MORSESEP * dot));
		++m;
	}

	/* 1/2 of a Morse letter space on each side */
	tone(0, ((MORSECHARSP * sdot) >> 1));
}

static char lextype[128] = {
/* controls */	0,	0,	0,	0,
		0,	0,	0,	0,
		0,	0,	' ',	0,
		0,	0,	0,	0,
		0,	0,	0,	0,
		0,	0,	0,	0,
		0,	0,	0,	0,
		0,	0,	0,	0,
/* 32 ' ' */	' ',
/* 33 '!' */	'!',
/* 34 '"' */	0,
/* 35 '#' */	0,
/* 36 '$' */	0,
/* 37 '%' */	'%',
/* 38 '&' */	0,
/* 39 ''' */	0,
/* 40 '(' */	'(',
/* 41 ')' */	')',
/* 42 '*' */	'*',
/* 43 '+' */	'+',
/* 44 ',' */	',',
/* 45 '-' */	'-',
/* 46 '.' */	'.',
/* 47 '/' */	'/',
/* 48 '0' */	'0',
/* 49 '1' */	'1',
/* 50 '2' */	'2',
/* 51 '3' */	'3',
/* 52 '4' */	'4',
/* 53 '5' */	'5',
/* 54 '6' */	'6',
/* 55 '7' */	'7',
/* 56 '8' */	'8',
/* 57 '9' */	'9',
/* 58 ':' */	0,
/* 59 ';' */	';',
/* 60 '<' */	'(',
/* 61 '=' */	'=',
/* 62 '>' */	')',
/* 63 '?' */	'?',
/* 64 '@' */	'@',
/* 65 'A' */	'A',
/* 66 'B' */	'B',
/* 67 'C' */	'C',
/* 68 'D' */	'D',
/* 69 'E' */	'E',
/* 70 'F' */	'F',
/* 71 'G' */	'G',
/* 72 'H' */	'H',
/* 73 'I' */	'I',
/* 74 'J' */	'J',
/* 75 'K' */	'K',
/* 76 'L' */	'L',
/* 77 'M' */	'M',
/* 78 'N' */	'N',
/* 79 'O' */	'O',
/* 80 'P' */	'P',
/* 81 'Q' */	'Q',
/* 82 'R' */	'R',
/* 83 'S' */	'S',
/* 84 'T' */	'T',
/* 85 'U' */	'U',
/* 86 'V' */	'V',
/* 87 'W' */	'W',
/* 88 'X' */	'X',
/* 89 'Y' */	'Y',
/* 90 'Z' */	'Z',
/* 91 '[' */	'(',
/* 92 '\' */	0,
/* 93 ']' */	')',
/* 94 '^' */	0,
/* 95 '_' */	'_',
/* 96 '`' */	0,
/* 97 'a' */	'A',
/* 98 'b' */	'B',
/* 99 'c' */	'C',
/* 100 'd' */	'D',
/* 101 'e' */	'E',
/* 102 'f' */	'F',
/* 103 'g' */	'G',
/* 104 'h' */	'H',
/* 105 'i' */	'I',
/* 106 'j' */	'J',
/* 107 'k' */	'K',
/* 108 'l' */	'L',
/* 109 'm' */	'M',
/* 110 'n' */	'N',
/* 111 'o' */	'O',
/* 112 'p' */	'P',
/* 113 'q' */	'Q',
/* 114 'r' */	'R',
/* 115 's' */	'S',
/* 116 't' */	'T',
/* 117 'u' */	'U',
/* 118 'v' */	'V',
/* 119 'w' */	'W',
/* 120 'x' */	'X',
/* 121 'y' */	'Y',
/* 122 'z' */	'Z',
/* 123 '{' */	'(',
/* 124 '|' */	0,
/* 125 '}' */	')',
/* 126 '~' */	'~',
/* 127 */	0
};

static void
addlex(register int c)
{
	/* Is there space for this character? */
	if (inputlen >= (MAXINPUT-1)) return;

	/* Is c lexically valid? */
	if ((c = lextype[c & 0x7f]) > 0) {
		/* Compress space sequences into single spaces */
		if ((c != ' ') ||
		    (inputlen == 0) ||
		    (inputbuf[inputlen-1] == ' ')) {
			/* Put it in the buffer */
			inputbuf[inputlen++] = c;
		}
	}
}

static void
addstr(register char *p,
register int len)
{
	/* Insert a string into the input buffer */
	while ((--len >= 0) && *p) {
		addlex(*(p++));
	}
}

static int
token(void)
{
	return((pc >= inputlen) ? 0 : inputbuf[pc]);
}

static int
digit(register int c)
{
	if ((c >= '0') &&
	    (c <= '9')) {
		return(c - '0');
	}
	return(-1);
}

static int
number(void)
{
	register int count = 0;

	while (token() == ' ') ++pc;
	for (;;) {
		register int d = digit(token());

		if (d != -1) {
			count = (count * 10) + d;
		} else {
			while (token() == ' ') ++pc;
			return(count);
		}

		++pc;
	}
}

static int
repeats(void)
{
	/* Eat white space, if any */
	while (token() == ' ') ++pc;

	if (token() == '*') {
		++pc;
		return(-1);
	}

	return(number());
}

static int
phrase(void)
{
	register int begin, end, count, freqhz;

	if (token() == '(') {
		begin = ++pc;
		if (!phrase()) return(0);
		if (token() == ')') {
			++pc;
			if (!(count = repeats())) return(0);
			end = pc;
			while ((count == -1) || (--count > 0)) {
				pc = begin;
				phrase();
			}
			pc = end;
		}
		return(1);
	}

	/* Must be ordinary text... */
	for (;;) {
		switch (token()) {
		case 0:		return(0);
		case ')':	return(1);
		case '(':	if (!phrase()) return(0);
				break;
		case '_':	++pc;
				msecdelay = number();
				while (token() == ' ') ++pc;
				break;
		case '~':	++pc;
				freqhz = number();
				while (token() == ' ') ++pc;
				if (freqhz > 0) {
					tone(freqhz, msecdelay);
					tone(0, 0ULL);
				} else {
					tone(0, msecdelay);
				}
				break;
		case ';':	++pc;
				tone(0, msecdelay);
				break;
		case '!':	++pc;
				alert('!');
				break;
		case '-':	++pc;
				usenato = 0;
				morse(' ');
				break;
		case '@':	++pc;
				usenato = 1;
				nato(' ');
				break;
		case '%':	++pc;
				usenato = !usenato;
				if (usenato) nato(' '); else morse(' ');
				break;
		default:	if (usenato) nato(token()); else morse(token());
				++pc;
		}
	}
}

int
main(register int argc,
register char **argv)
{
	register int readstdin = 1;

#ifdef	USEIOCTL
	if ((consolefd = open("/dev/console", O_NOCTTY)) < 0) exit(1);
#else
	/* Get port access */
	if (iopl(3) != 0) exit(1);
#endif

	/* Read command line options and/or input words */
	if (argc > 1) {
		register int i;

		for (i=1; i<argc; ++i) {
			if (*argv[i] == '-') {
				/* A command line option... */
				register int c;
				register char *p = (argv[i] + 1);

				switch (*p) {
				case '-':
					/* Force read of stdin */
					readstdin |= 2;
					break;
				case 'f':
					/* Farsworth dot length for WPM */
					dot = 0;
					while ((c = digit(*(++p))) != -1) {
						dot = (dot * 10) + c;
					}
					dot = MORSEDOT(dot);
					break;
				case 'h':
					/* Set Morse frequency in Hz */
					freq = 0;
					while ((c = digit(*(++p))) != -1) {
						freq = (freq * 10) + c;
					}
					break;
				case 'n':
					/* Hostname prefix */
					gethostname((p = &(inputbuf[inputlen])),
						    (MAXINPUT-2-inputlen));
					while (*p && (*p != '.')) ++p;
					*p = ' ';
					p[1] = 0;
					addstr(&(inputbuf[inputlen]),
					       (MAXINPUT-2-inputlen));
					readstdin &= ~1;
					break;
				case 'v':
					/* Version */
					addstr(VERSION, 9);
					readstdin &= ~1;
					break;
				case 'w':
					/* Dot length for WPM */
					sdot = 0;
					while ((c = digit(*(++p))) != -1) {
						sdot = (sdot * 10) + c;
					}
					sdot = MORSEDOT(sdot);
					break;
				}
			} else {
				/* A command line input word... */
				register int j = 0;
				register int c;

				/* Had a word of input */
				readstdin &= ~1;

				/* Catenate */
				addstr(argv[i], 0x7fffffff);

				/* Word break after each argument */
				addlex(' ');
			}
		}
	}

	/* Correct for Farnsworth usage */
	if (dot == 0) {
		dot = sdot;
	} else if (dot < sdot) {
		/* Correct based on "PARIS ";
		   19/50 dot times are used for spaces
		*/
		sdot = (((sdot * 50) - (dot * 31)) / 19);
	}

	/* Where is our input? */
	if (readstdin != 0) {
		/* Read input from stdin */
		register int i;
		register char *p;

		do {
			p = &(inputbuf[inputlen]);
			i = read(0, p, (&(inputbuf[MAXINPUT]) - p));
			addstr(p, i);
		} while (i > 0);
	}

	/* If we die now, shutup sound */
	signal(SIGINT,  shutup);
	signal(SIGTERM, shutup);
	signal(SIGQUIT, shutup);
	signal(SIGTSTP, shutup);

	/* Interpret the now-buffered input */
	while (phrase()) ;

	/* All's well that ends well... */
	exit(0);
}
